<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    Woocommerce_Ultimate_Points_And_Rewards
 * @subpackage Woocommerce_Ultimate_Points_And_Rewards/public
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'MWB_WPR_Front_End' ) ) {

	/**
	 * This is class for managing front end points and reward functionality
	 *
	 * @name    MWB_WPR_Front_End
	 * @category Class
	 * @author   makewebbetter <webmaster@makewebbetter.com>
	 */
	class MWB_WPR_Front_End {

		/**
		 * This is construct of class where all action and filter is defined
		 *
		 * @name __construct
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function __construct() {

			add_action( 'plugins_loaded', array( $this, 'mwb_wpr_load_woocommerce' ) );
		}

		/**
		 * This load plugin after load woocommerce.
		 *
		 * @name mwb_wpr_load_woocommerce
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_load_woocommerce() {
			if ( function_exists( 'WC' ) ) {

				$general_settings = get_option( 'mwb_wpr_settings_gallery', true );
				$enable_mwb_wpr   = isset( $general_settings['enable_mwb_wpr'] ) ? intval( $general_settings['enable_mwb_wpr'] ) : 0;
				if ( $enable_mwb_wpr ) {
					$this->add_hooks_and_filters();
				}
			}
		}

		/**
		 * This contains hooks and filter of plugin.
		 *
		 * @name add_hooks_and_filters
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function add_hooks_and_filters() {
			add_action( 'mwb_wpr_digit_registration', array( $this, 'mwb_wpr_new_customer_digit_registered' ) );
			add_action( 'user_register', array( $this, 'mwb_wpr_new_customer_registerd' ), 10, 2 );
			add_action( 'woocommerce_single_product_summary', array( $this, 'mwb_display_product_points' ), 7 );
			add_filter( 'mwb_wgm_price_meta_data', array( $this, 'mwb_wpr_wgm_price_meta_data' ), 10, 4 );
			add_filter( 'woocommerce_add_cart_item_data', array( $this, 'mwb_wpr_woocommerce_add_cart_item_data' ), 10, 4 );
			add_filter( 'woocommerce_get_item_data', array( $this, 'mwb_wpr_woocommerce_get_item_data' ), 10, 2 );
			add_action( 'woocommerce_order_status_changed', array( $this, 'mwb_wpr_woocommerce_order_status_changed' ), 10, 3 );
			add_filter( 'woocommerce_account_menu_items', array( $this, 'mwb_wpr_points_dashboard' ) );
			add_action( 'woocommerce_account_points_endpoint', array( $this, 'mwb_wpr_account_points' ) );
			add_action( 'woocommerce_account_view-log_endpoint', array( $this, 'mwb_wpr_account_viewlog' ) );

			if ( WC()->version < '3.0.0' ) {
				add_action( 'woocommerce_add_order_item_meta', array( $this, 'mwb_wpr_woocommerce_add_order_item_meta' ), 10, 2 );
				add_action( 'woocommerce_order_add_coupon', array( $this, 'mwb_wpr_woocommerce_order_add_coupon' ), 10, 5 );
			} else {

				add_action( 'woocommerce_checkout_create_order_line_item', array( $this, 'mwb_wpr_woocommerce_add_order_item_meta_version_3' ), 10, 4 );
			}

			add_action( 'init', array( $this, 'mwb_wpr_add_my_account_endpoint' ) );
			add_filter( 'woocommerce_product_review_comment_form_args', array( $this, 'mwb_wpr_woocommerce_comment_point' ), 10, 1 );
			add_action( 'woocommerce_before_customer_login_form', array( $this, 'mwb_wpr_woocommerce_signup_point' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'mwb_wpr_wp_enqueue_scripts' ), 10, 1 );
			add_action( 'wp_ajax_mwb_wpr_generate_custom_coupon', array( $this, 'mwb_wpr_generate_custom_coupon' ) );

			add_action( 'wp_ajax_nopriv_mwb_wpr_generate_custom_coupon', array( $this, 'mwb_wpr_generate_custom_coupon' ) );
			add_action( 'wp_ajax_mwb_wpr_generate_original_coupon', array( $this, 'mwb_wpr_generate_original_coupon' ) );
			add_action( 'wp_ajax_nopriv_mwb_wpr_generate_original_coupon', array( $this, 'mwb_wpr_generate_original_coupon' ) );
			add_action( 'comment_post', array( $this, 'mwb_comment_insert_into_database' ), 10, 3 );
			add_filter( 'woocommerce_update_cart_action_cart_updated', array( $this, 'mwb_update_cart_points' ) );
			add_filter( 'woocommerce_get_price_html', array( $this, 'mwb_wpr_user_level_discount_on_price' ), 999, 2 );
			add_action( 'woocommerce_before_calculate_totals', array( $this, 'mwb_wpr_woocommerce_before_calculate_totals' ), 999, 1 );
			add_action( 'woocommerce_before_add_to_cart_button', array( $this, 'mwb_wpr_woocommerce_before_add_to_cart_button' ), 999, 1 );
			add_filter( 'woocommerce_thankyou_order_received_text', array( $this, 'mwb_wpr_woocommerce_thankyou' ), 10, 2 );
			add_filter( 'woocommerce_order_item_display_meta_key', array( $this, 'mwb_wpr_woocommerce_order_item_display_meta_key' ), 10, 1 );
			add_filter( 'woocommerce_hidden_order_itemmeta', array( $this, 'mwb_wpr_woocommerce_hidden_order_itemmeta' ), 10, 1 );
			add_action( 'wp_ajax_mwb_wpr_sharing_point_to_other', array( $this, 'mwb_wpr_sharing_point_to_other' ) );
			add_action( 'wp_ajax_nopriv_mwb_wpr_sharing_point_to_other', array( $this, 'mwb_wpr_sharing_point_to_other' ) );
			add_action( 'wp_ajax_mwb_wpr_append_variable_point', array( $this, 'mwb_wpr_append_variable_point' ) );
			add_action( 'wp_ajax_nopriv_mwb_wpr_append_variable_point', array( $this, 'mwb_wpr_append_variable_point' ) );
			add_action( 'wp_ajax_mwb_pro_purchase_points_only', array( $this, 'mwb_pro_purchase_points_only' ) );
			add_action( 'wp_ajax_nopriv_mwb_pro_purchase_points_only', array( $this, 'mwb_pro_purchase_points_only' ) );

			add_action( 'woocommerce_cart_calculate_fees', array( $this, 'mwb_wpr_woocommerce_cart_calculate_fees' ) );
			add_action( 'wp_loaded', array( $this, 'mwb_wpr_referral_link_using_cookie' ) );
			add_action( 'woocommerce_cart_actions', array( $this, 'mwb_wpr_woocommerce_cart_coupon' ) );
			add_action( 'wp_ajax_mwb_wpr_apply_fee_on_cart_subtotal', array( $this, 'mwb_wpr_apply_fee_on_cart_subtotal' ) );
			add_action( 'woocommerce_cart_calculate_fees', array( $this, 'mwb_wpr_woocommerce_cart_custom_points' ) );
			add_action( 'woocommerce_before_cart_contents', array( $this, 'mwb_wpr_woocommerce_before_cart_contents' ) );
			add_action( 'woocommerce_blocks_enqueue_cart_block_scripts_after', array( $this, 'mwb_wpr_woocommerce_before_cart_contents' ) );
			add_filter( 'woocommerce_cart_totals_fee_html', array( $this, 'mwb_wpr_woocommerce_cart_totals_fee_html' ), 10, 2 );
			add_action( 'wp_ajax_mwb_wpr_remove_cart_point', array( $this, 'mwb_wpr_remove_cart_point' ) );
			add_action( 'woocommerce_before_main_content', array( $this, 'mwb_wpr_woocommerce_before_main_content' ) );
			add_action( 'woocommerce_order_status_changed', array( $this, 'mwb_wpr_woocommerce_order_status_cancel' ), 10, 3 );
			add_filter( 'woocommerce_cart_totals_get_fees_from_cart_taxes', array( $this, 'mwb_wpr_fee_tax_calculation' ), 10, 3 );
			// MWB Custom Work.
			add_filter( 'woocommerce_add_to_cart_validation', array( $this, 'mwb_wpr_woocommerce_add_to_cart_validation' ), 10, 3 );
			add_filter( 'woocommerce_variable_price_html', array( $this, 'mwb_woocommerce_variable_price_html' ), 10, 2 );
			add_filter( 'wc_get_template', array( $this, 'mwb_overwrite_form_temp' ), 10, 2 );
			add_filter( 'woocommerce_cart_contents_changed', array( $this, 'mwb_wpr_woocommerce_content_change' ) );

			// custom start.
			$enable = get_option( 'notify_user_enable_plug', 'yes' );
			if ( 'yes' === $enable ) {
				add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_styles' ) );
				add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
				add_action( 'wp_footer', array( $this, 'notify_user_load_popup_html' ) );
			}
			// shortcode to view apply points section on cart and checkout page.
			add_action( 'wp_loaded', array( $this, 'mwb_wpr_generate_shortcode' ) );
			// show apply points section when avada theme is activated.
			add_action( 'woocommerce_before_checkout_form', array( $this, 'mwb_wpr_add_apply_form_form' ), 10, 1 );
			// awarded user on the basis of his no. of order place.
			add_action( 'wp_loaded', array( $this, 'mwb_wpr_awarded_user_number_order_place' ), 10 );
			// wallet compatibility.
			add_action( 'mwb_wpr_add_wallet_content', array( $this, 'mwb_wpr_render_wallet_content' ), 10, 1 );
			add_action( 'wp_ajax_mwb_wpr_points_to_wallet_transfer', array( $this, 'mwb_wpr_tranfer_points_to_wallet' ) );
			add_action( 'wp_ajax_nopriv_mwb_wpr_points_to_wallet_transfer', array( $this, 'mwb_wpr_tranfer_points_to_wallet' ) );

			// WOOCS.
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
			if ( is_plugin_active( 'woocommerce-currency-switcher/index.php' ) ) {

				add_filter( 'mwb_par_show_conversion_price', array( $this, 'mwb_par_conversion_price_callback' ), 10, 1 );
				add_filter( 'mwb_par_convert_base_price_diffrent_currency', array( $this, 'mwb_par_convert_diffrent_currency_base_price_callback' ), 10, 1 );
				add_filter( 'mwb_par_convert_same_currency_base_price', array( $this, 'mwb_par_convert_same_currency_base_price_callback' ), 10, 2 );
			}

			// subscription show message.
			add_action( 'mwb_wpr_add_wallet_content', array( $this, 'mwb_wpr_render_subs_message' ), 10, 1 );
			add_action( 'woocommerce_blocks_enqueue_cart_block_scripts_after', array( $this, 'mwb_wpr_enqueue_cart_block' ) );
		}

		// custom code.
		/**
		 * Register the stylesheets for the public-facing side of the site.
		 *
		 * @since    1.0.0
		 */
		public function enqueue_styles() {
			wp_enqueue_style( 'woocommerce public', plugin_dir_url( __FILE__ ) . 'css/notify-user-public.css', array(), '2.7.1' );
			wp_enqueue_style( 'jquery_ui', plugin_dir_url( __FILE__ ) . 'modal/css/jquery-ui.css', array(), '2.7.1' );
			wp_enqueue_style( 'material_style', plugin_dir_url( __FILE__ ) . 'modal/css/material.indigo-pink.min.css', array(), '2.7.1' );
			wp_enqueue_style( 'material_modal', plugin_dir_url( __FILE__ ) . 'modal/css/material-modal.css', array(), '2.7.1' );
			wp_enqueue_style( 'material_icons', plugin_dir_url( __FILE__ ) . 'modal/css/icon.css', array(), '2.7.1' );
			wp_enqueue_style( 'modal_style', plugin_dir_url( __FILE__ ) . 'modal/css/style.css', array(), '2.7.1' );
		}

		/**
		 * Register the JavaScript for the public-facing side of the site.
		 *
		 * @since    1.0.0
		 */
		public function enqueue_scripts() {
			wp_enqueue_script( 'jquery-ui-draggable' );
			wp_enqueue_script( 'woocommerce script', plugin_dir_url( __FILE__ ) . 'js/notify-user-public.js', array( 'jquery', 'jquery-ui-draggable' ), '2.7.1', false );
			wp_enqueue_script( 'mwb_materal_modal_min', plugin_dir_url( __FILE__ ) . 'modal/js/material-modal.min.js', array( 'jquery' ), '2.7.1', true );
			wp_enqueue_script( 'mwb_materal_modal', plugin_dir_url( __FILE__ ) . 'modal/js/material.min.js', array(), '2.7.1' );
		}

		// custom code.
		/**
		 * This function is used to hide the order Item Meta
		 *
		 * @param  array $order_items       item order.
		 * @name mwb_wpr_woocommerce_hidden_order_itemmeta
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_hidden_order_itemmeta( $order_items ) {
			array_push( $order_items, 'Purchasing Option' );
			return $order_items;
		}

		/**
		 * This function is used to establish the compatibility between PAR and GC
		 *
		 * @param      string $item_meta       Meta data.
		 * @param      string $the_cart_data      cart data.
		 * @param      string $product_id      product data.
		 * @param      string $variation_id      varation data.
		 * @name mwb_wpr_wgm_price_meta_data
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_wgm_price_meta_data( $item_meta, $the_cart_data, $product_id, $variation_id ) {
			if ( ! empty( sanitize_text_field( wp_unslash( $_REQUEST['quantity'] ) ) ) && sanitize_text_field( wp_unslash( $_REQUEST['quantity'] ) ) && null !== sanitize_text_field( wp_unslash( $_REQUEST['quantity'] ) ) ) {
				$quantity = (int) $_REQUEST['quantity'];
			} else {
				$quantity = 1;
			}
			$user_id                 = get_current_user_ID();
			$get_points              = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			$product_types           = wp_get_object_terms( $product_id, 'product_type' );
			$check_enable            = get_post_meta( $product_id, 'mwb_product_points_enable', 'no' );
			$general_settings        = get_option( 'mwb_wpr_settings_gallery', true );
			$mwb_wpr_set_preferences = isset( $general_settings['mwb_wpr_set_preferences'] ) ? $general_settings['mwb_wpr_set_preferences'] : 'to_both';
			$enable_purchase_points  = isset( $general_settings['enable_purchase_points'] ) ? intval( $general_settings['enable_purchase_points'] ) : 0;

			if ( 'yes' === $check_enable ) {
				if ( 'to_assign_point' === $mwb_wpr_set_preferences || 'to_both' === $mwb_wpr_set_preferences ) {
					if ( isset( $variation_id ) && ! empty( $variation_id ) && $variation_id > 0 ) {
						$get_product_points          = get_post_meta( $variation_id, 'mwb_wpr_variable_points', 1 );
						$item_meta['mwb_wpm_points'] = (int) $get_product_points * (int) $quantity;
					} else {
						$get_product_points          = get_post_meta( $product_id, 'mwb_points_product_value', 1 );
						$item_meta['mwb_wpm_points'] = (int) $get_product_points * (int) $quantity;
					}
				}
			}
			if ( $enable_purchase_points ) {
				$value_check                 = isset( $_POST['message-send'] ) ? sanitize_text_field( wp_unslash( $_POST['message-send'] ) ) : '';
				$mwb_wpr_pro_cost_to__points = ! empty( $_POST['mwb_wpr_pro_cost_to_points'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_wpr_pro_cost_to_points'] ) ) : '';

				$item_meta['pro_mwb_pur_by_points_single_qty_val'] = $mwb_wpr_pro_cost_to__points;
				$item_meta['pro_mwb_purchase__by_points_qty']      = $quantity;
				$mwb_wpr_pro_cost_to__points                       = (int) $mwb_wpr_pro_cost_to__points * $quantity;
				if ( wp_verify_nonce( $value_check, 'custom-action' ) ) {
					if ( ! empty( $mwb_wpr_pro_cost_to__points ) ) {
						if ( $mwb_wpr_pro_cost_to__points >= $get_points ) {
							$item_meta['pro_purchase_by_points'] = $get_points;
						} else {
							$item_meta['pro_purchase_by_points'] = $mwb_wpr_pro_cost_to__points;
						}
					}
				}
			}
			return $item_meta;

		}

		/**
		 * This function is used to edit comment template for points
		 *
		 * @name mwb_wpr_woocommerce_signup_point
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_signup_point() {
			$mwb_wpr_notification_color   = get_option( 'mwb_wpr_notification_color', '#55b3a5' );
			$mwb_wpr_get_general_settings = get_option( 'mwb_wpr_settings_gallery', true );
			if ( isset( $mwb_wpr_get_general_settings['enable_mwb_signup'] ) && isset( $mwb_wpr_get_general_settings['enable_mwb_signup'] ) == 1 ) {
				$mwb_wpr_signup_value = isset( $mwb_wpr_get_general_settings['mwb_signup_value'] ) ? intval( $mwb_wpr_get_general_settings['mwb_signup_value'] ) : 1;
				$enable_mwb_signup    = isset( $mwb_wpr_get_general_settings['enable_mwb_signup'] ) ? intval( $mwb_wpr_get_general_settings['enable_mwb_signup'] ) : 0;
				if ( $enable_mwb_signup ) {
					?>
					<div class="woocommerce-message">
						<?php
						//phpcs:disable.
						echo esc_html__( 'You will get ', 'woocommerce-ultimate-points-and-rewards' ) . esc_html( $mwb_wpr_signup_value ) . esc_html__( ' points for SignUp', 'woocommerce-ultimate-points-and-rewards' );
						?>
					</div>
					<?php
				}
			}
			// daily login points notice.
			$mwb_wpr_settings_gallery    = get_option( 'mwb_wpr_settings_gallery', array() );
			$mwb_wpr_settings_gallery    = ! empty( $mwb_wpr_settings_gallery ) && is_array( $mwb_wpr_settings_gallery ) ? $mwb_wpr_settings_gallery : array();
			$mwb_wpr_enable_daily_login  = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_enable_daily_login'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_enable_daily_login'] : 0;
			$mwb_wpr_daily__login_points = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_daily__login_points'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_daily__login_points'] : 1;
			if ( 1 == $mwb_wpr_enable_daily_login ) {
				?>
				<div class="woocommerce-message">
				<?php
				//phpcs:disable.
				echo esc_html__( 'Earn ', 'woocommerce-ultimate-points-and-rewards' ) . esc_html( $mwb_wpr_daily__login_points ) . esc_html__( ' points on the basis of Daily Login', 'woocommerce-ultimate-points-and-rewards' );
				?>
				</div>
				<?php
			}
		}

		/**
		 * This function is used to edit comment template for points
		 *
		 * @param      string $comment_data       comment data.
		 * @name mwb_wpr_woocommerce_comment_point
		 * @return array
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_comment_point( $comment_data ) {
			$mwb_wpr_get_general_settings = get_option( 'mwb_wpr_settings_gallery', true );
			$user_id                      = get_current_user_ID();
			if ( isset( $mwb_wpr_get_general_settings['enable_mwb_comment'] ) && 1 === $mwb_wpr_get_general_settings['enable_mwb_comment'] && isset( $user_id ) && ! empty( $user_id ) ) {
				$mwb_wpr_comment_value          = isset( $mwb_wpr_get_general_settings['mwb_comment_value'] ) ? intval( $mwb_wpr_get_general_settings['mwb_comment_value'] ) : 1;
				$comment_data['comment_field'] .= '<p class="comment-mwb-wpr-points-comment"><label>' . __( 'You will get ', 'woocommerce-ultimate-points-and-rewards' ) . $mwb_wpr_comment_value . __( ' points for product review', 'woocommerce-ultimate-points-and-rewards' ) . '</p>';
			}
			return $comment_data;
		}

		/**
		 * This function is used to update cart points.
		 *
		 * @param      string $cart_updated       update cart.
		 * @name mwb_update_cart_points
		 * @return array
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_update_cart_points( $cart_updated ) {
			if ( $cart_updated ) {

				$nonce      = ! empty( $_REQUEST['woocommerce-cart-nonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['woocommerce-cart-nonce'] ) ) : '';
				$cart       = WC()->session->get( 'cart' );
				$user_id    = get_current_user_ID();
				$get_points = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
				if ( wp_verify_nonce( $nonce, 'woocommerce-cart' ) ) {
					if ( isset( $_POST['cart'] ) && null != $_POST['cart'] && isset( $cart ) && null != $cart ) {
						$cart_update = ! empty( $_POST['cart'] ) ? map_deep( wp_unslash( $_POST['cart'] ), 'sanitize_text_field' ) : '';

						if ( ! empty( $cart_update ) && is_array( $cart_update ) ) {
							foreach ( $cart_update as $key => $value ) {

								if ( isset( WC()->cart->cart_contents[ $key ]['product_meta'] ) ) {
									if ( isset( WC()->cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpm_points'] ) ) {

										$product = wc_get_product( $cart[ $key ]['product_id'] );
										if ( isset( $product ) && ! empty( $product ) ) {
											if ( $this->mwb_wpr_check_whether_product_is_variable( $product ) ) {
												if ( isset( $cart[ $key ]['variation_id'] ) && ! empty( $cart[ $key ]['variation_id'] ) ) {
													$get_product_points = get_post_meta( $cart[ $key ]['variation_id'], 'mwb_wpr_variable_points', 1 );
												}
											} else {
												if ( isset( $cart[ $key ]['product_id'] ) && ! empty( $cart[ $key ]['product_id'] ) ) {
													$get_product_points = get_post_meta( $cart[ $key ]['product_id'], 'mwb_points_product_value', 1 );
												}
											}
										}
										WC()->cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpm_points'] = (int) $get_product_points * (int) $value['qty'];
									}
									// MWB CUSTOM CODE.
									if ( isset( WC()->cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] ) ) {

										$product = wc_get_product( $cart[ $key ]['product_id'] );
										if ( $this->mwb_wpr_check_whether_product_is_variable( $product ) ) {

											if ( isset( $cart[ $key ]['variation_id'] ) && ! empty( $cart[ $key ]['variation_id'] ) ) {

												$mwb_variable_purchase_value = get_post_meta( $cart[ $key ]['variation_id'], 'mwb_wpr_variable_points_purchase', true );
											}
											$total_pro_pnt = (int) $mwb_variable_purchase_value * (int) $value['qty'];

											if ( isset( $total_pro_pnt ) && ! empty( $total_pro_pnt ) && $get_points >= $total_pro_pnt ) {
												WC()->cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] = $total_pro_pnt;
											} else {

												wc_add_notice( __( 'You cant purchase that much quantity for Free', 'woocommerce-ultimate-points-and-rewards' ), 'error' );
												WC()->cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] = 0;
											}
										} else {

											if ( isset( $cart[ $key ]['product_id'] ) && ! empty( $cart[ $key ]['product_id'] ) ) {
												$get_product_points = get_post_meta( $cart[ $key ]['product_id'], 'mwb_points_product_purchase_value', true );
											}
											$total_pro_pnt = (int) $get_product_points * (int) $value['qty'];
											if ( isset( $total_pro_pnt ) && ! empty( $total_pro_pnt ) && $get_points >= $total_pro_pnt ) {
												WC()->cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] = (int) $get_product_points * (int) $value['qty'];
											} else {

												wc_add_notice( __( 'You cant purchase that much quantity for Free', 'woocommerce-ultimate-points-and-rewards' ), 'error' );
												WC()->cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] = 0;
											}
										}
									}
								}
							}
						}
					}
				}
			}
			return $cart_updated;
		}

		/**
		 * This function is used to save comment points.
		 *
		 * @param      string $comment_id       comment_id.
		 * @param      string $comment_approved       Approved comment.
		 * @param      string $commentdata       comment data.
		 * @name mwb_comment_insert_into_database
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_comment_insert_into_database( $comment_id, $comment_approved, $commentdata ) {
			global $post;
			if ( $comment_approved ) {
				$general_settings      = get_option( 'mwb_wpr_settings_gallery', true );
				$coupon_settings_array = get_option( 'mwb_wpr_coupons_gallery', array() );
				$enable_mwb_comment    = isset( $general_settings['enable_mwb_comment'] ) ? intval( $general_settings['enable_mwb_comment'] ) : 0;
				if ( $enable_mwb_comment ) {
					$today_date                   = date_i18n( 'Y-m-d h:i:sa' );
					$mwb_comment_value            = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;
					$mwb_refer_value              = isset( $general_settings['mwb_refer_value'] ) ? intval( $general_settings['mwb_refer_value'] ) : 1;
					$mwb_per_currency_spent_value = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) ? intval( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) : 1;
					$get_points                   = (int) get_user_meta( $commentdata['user_ID'], 'mwb_wpr_points', true );
					$get_detail_point             = get_user_meta( $commentdata['user_ID'], 'points_details', true );

					if ( isset( $get_detail_point['comment'] ) && ! empty( $get_detail_point['comment'] ) ) {
						$comment_arr                   = array(
							'comment' => $mwb_comment_value,
							'date'    => $today_date,
						);
						$get_detail_point['comment'][] = $comment_arr;

					} else {
						if ( ! is_array( $get_detail_point ) ) {
							$get_detail_point = array();
						}
						$comment_arr = array(
							'comment' => $mwb_comment_value,
							'date'    => $today_date,
						);

						$get_detail_point['comment'][] = $comment_arr;
					}
					update_user_meta( $commentdata['user_ID'], 'mwb_wpr_points', $mwb_comment_value + $get_points );
					update_user_meta( $commentdata['user_ID'], 'points_details', $get_detail_point );
					$user                      = get_user_by( 'ID', $commentdata['user_ID'] );
					$user_email                = $user->user_email;
					$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
					if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
						$total_points               = $mwb_comment_value + $get_points;
						$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
						$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_comment_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_comment_email_subject'] : '';
						$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_comment_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_comment_email_discription_custom_id'] : '';
						$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_comment_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription  = str_replace( '[Total Points]', $total_points, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription  = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription  = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
						$user                       = get_user_by( 'email', $user_email );
						$user_name                  = $user->user_firstname;
						$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );

						if ( $mwb_wpr_notificatin_enable ) {
							$headers = array( 'Content-Type: text/html; charset=UTF-8' );
							wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
						}
					}
				}
			}
		}

		/**
		 * This function is used to generate coupon of total points.
		 *
		 * @name mwb_wpr_generate_original_coupon
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_generate_original_coupon() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$response['result']  = false;
			$response['message'] = __( 'Coupon generation error.', 'woocommerce-ultimate-points-and-rewards' );
			if ( isset( $_POST['user_id'] ) && ! empty( $_POST['user_id'] ) ) {

				$user_id           = sanitize_text_field( wp_unslash( $_POST['user_id'] ) );
				$get_points        = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
				$coupon_settings   = get_option( 'mwb_wpr_coupons_gallery', true );
				$mwb_coupon_length = ( isset( $coupon_settings['mwb_coupon_length'] ) && null !== $coupon_settings['mwb_coupon_length'] ) ? intval( $coupon_settings['mwb_coupon_length'] ) : 5;
				$tot_points        = ( isset( $get_points ) && null !== $get_points ) ? (int) $get_points : 0;

				if ( $tot_points ) {

					$couponnumber         = wpswing_cc_coupon_generator( $mwb_coupon_length );
					$coupon_redeem_price  = ( isset( $coupon_settings['coupon_redeem_price'] ) && null !== $coupon_settings['coupon_redeem_price'] ) ? $coupon_settings['coupon_redeem_price'] : 1;
					$coupon_redeem_points = ( isset( $coupon_settings['coupon_redeem_points'] ) && null !== $coupon_settings['coupon_redeem_points'] ) ? intval( $coupon_settings['coupon_redeem_points'] ) : 1;
					$coupon_redeem_price  = str_replace( wc_get_price_decimal_separator(), '.', strval( $coupon_redeem_price ) );
					$couponamont          = ( $get_points * $coupon_redeem_price ) / $coupon_redeem_points;
					$couponamont          = str_replace( '.', wc_get_price_decimal_separator(), strval( $couponamont ) );

					if ( $this->mwb_wpr_create_points_coupon( $couponnumber, $couponamont, $user_id, $get_points ) ) {
						$user_log         = get_user_meta( $user_id, 'mwb_wpr_user_log', true );
						$response['html'] = '<table class="woocommerce-MyAccount-points shop_table shop_table_responsive my_account_points account-points-table">
						<thead>
							<tr>
								<th class="points-points">
									<span class="nobr">' . __( 'Points', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
								<th class="points-code">
									<span class="nobr">' . __( 'Coupon Code', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
								<th class="points-amount">
									<span class="nobr">' . __( 'Coupon Amount', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
								<th class="points-left">
									<span class="nobr">' . __( 'Amount Left', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
								<th class="points-expiry">
									<span class="nobr">' . __( 'Expiry', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
							</tr>
						</thead>
						<tbody>';

						foreach ( $user_log as $key => $mwb_user_log ) {
							$response['html'] .= '<tr class="points">';
							foreach ( $mwb_user_log as $column_id => $column_name ) {
								$response['html'] .= '<td class="points-' . esc_attr( $column_id ) . '" >';
								if ( 'left' === $column_id ) {
									$mwb_split         = explode( '#', $key );
									$column_name       = get_post_meta( $mwb_split[1], 'coupon_amount', true );
									$response['html'] .= get_woocommerce_currency_symbol() . $column_name;
								} elseif ( 'expiry' === $column_id ) {
									if ( WC()->version < '3.0.6' ) {

										$column_name       = get_post_meta( $mwb_split[1], 'expiry_date', true );
										$response['html'] .= $column_name;
									} else {
										$column_name = get_post_meta( $mwb_split[1], 'date_expires', true );
										if ( ! empty( $column_name ) ) {
											$dt                = new DateTime( "@$column_name" );
											$response['html'] .= $dt->format( 'Y-m-d' );
										} else {
											$response['html'] .= esc_html_e( 'No Expiry', 'woocommerce-ultimate-points-and-rewards' );
										}
									}
								} else {
									$response['html'] .= $column_name;
								}
								$response['html'] .= '</td>';
							}
							$response['html'] .= '</tr>';
						}
						$response['html'] .= '</tbody>
						</table>';
						$response['result']    = true;
						$response['message']   = __( 'Your points are converted to coupon', 'woocommerce-ultimate-points-and-rewards' );
						$get_points            = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
						$response['points']    = $get_points;
					}
				}
			}
			echo json_encode( $response );
			wp_die();
		}

		/**
		 * This function is used to generate coupon for custom points.
		 *
		 * @name mwb_wpr_generate_custom_coupon
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_generate_custom_coupon() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$response['result']  = false;
			$response['message'] = __( 'Coupon generation error.', 'woocommerce-ultimate-points-and-rewards' );
			if ( isset( $_POST['points'] ) && ! empty( $_POST['points'] ) ) {

				$value_user_id     = isset( $_POST['user_id'] ) ? sanitize_text_field( wp_unslash( $_POST['user_id'] ) ) : '';
				$user_id           = $value_user_id;
				$get_points        = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
				$custom_points     = sanitize_text_field( wp_unslash( $_POST['points'] ) );
				$coupon_settings   = get_option( 'mwb_wpr_coupons_gallery', true );
				$mwb_coupon_length = ( isset( $coupon_settings['mwb_coupon_length'] ) && null !== $coupon_settings['mwb_coupon_length'] ) ? intval( $coupon_settings['mwb_coupon_length'] ) : 5;

				if ( $custom_points <= $get_points ) {

					$couponnumber         = wpswing_cc_coupon_generator( $mwb_coupon_length );
					$coupon_redeem_price  = ( isset( $coupon_settings['coupon_redeem_price'] ) && null !== $coupon_settings['coupon_redeem_price'] ) ? $coupon_settings['coupon_redeem_price'] : 1;
					$coupon_redeem_points = ( isset( $coupon_settings['coupon_redeem_points'] ) && null !== $coupon_settings['coupon_redeem_points'] ) ? intval( $coupon_settings['coupon_redeem_points'] ) : 1;
					$coupon_redeem_price  = str_replace( wc_get_price_decimal_separator(), '.', strval( $coupon_redeem_price ) );
					$couponamont          = ( $custom_points * $coupon_redeem_price ) / $coupon_redeem_points;
					$couponamont          = str_replace( '.', wc_get_price_decimal_separator(), strval( $couponamont ) );

					if ( $this->mwb_wpr_create_points_coupon( $couponnumber, $couponamont, $user_id, $custom_points ) ) {
						$user_log         = get_user_meta( $user_id, 'mwb_wpr_user_log', true );
						$response['html'] = '<table class="woocommerce-MyAccount-points shop_table shop_table_responsive my_account_points account-points-table">
						<thead>
							<tr>
								<th class="points-points">
									<span class="nobr">' . __( 'Points', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
								<th class="points-code">
									<span class="nobr">' . __( 'Coupon Code', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
								<th class="points-amount">
									<span class="nobr">' . __( 'Coupon Amount', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
								<th class="points-left">
									<span class="nobr">' . __( 'Amount Left', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
								<th class="points-expiry">
									<span class="nobr">' . __( 'Expiry', 'woocommerce-ultimate-points-and-rewards' ) . '</span>
								</th>
							</tr>
						</thead>
						<tbody>';
						foreach ( $user_log as $key => $mwb_user_log ) {
							$response['html'] .= '<tr class="points">';
							foreach ( $mwb_user_log as $column_id => $column_name ) {
								$response['html'] .= '<td class="points-' . esc_attr( $column_id ) . '" >';
								$mwb_split         = explode( '#', $key );
								if ( 'left' === $column_id ) {
									$column_name       = get_post_meta( $mwb_split[1], 'coupon_amount', true );
									$response['html'] .= get_woocommerce_currency_symbol() . $column_name;
								} elseif ( 'expiry' === $column_id ) {
									if ( WC()->version < '3.0.6' ) {

										$column_name       = get_post_meta( $mwb_split[1], 'expiry_date', true );
										$response['html'] .= $column_name;
									} else {
										$column_name = get_post_meta( $mwb_split[1], 'date_expires', true );
										if ( ! empty( $column_name ) ) {
											$dt                = new DateTime( "@$column_name" );
											$response['html'] .= $dt->format( 'Y-m-d' );
										} else {
											$response['html'] .= esc_html__( 'No Expiry', 'woocommerce-ultimate-points-and-rewards' );
										}
									}
								} else {
									$response['html'] .= $column_name;
								}
								$response['html'] .= '</td>';
							}
							$response['html'] .= '</tr>';
						}
						$response['html'] .= '</tbody>
						</table>';
						$response['result']    = true;
						$response['message']   = __( 'Your points are converted to coupon', 'woocommerce-ultimate-points-and-rewards' );
						$get_points            = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
						$response['points']    = $get_points;
					}
				} else {
					$response['result']  = false;
					$response['message'] = __( 'Points cannot be greater than your current points', 'woocommerce-ultimate-points-and-rewards' );
				}
			}
			echo json_encode( $response );
			wp_die();
		}

		/**
		 * This function is used to enque scripts.
		 *
		 * @name mwb_wpr_wp_enqueue_scripts
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_wp_enqueue_scripts() {
			$coupon_settings            = get_option( 'mwb_wpr_coupons_gallery', array() );
			$mwb_wpr_notification_color = get_option( 'mwb_wpr_notification_color', '#55b3a5' );
			$mwb_minimum_points_value   = isset( $coupon_settings['mwb_minimum_points_value'] ) ? $coupon_settings['mwb_minimum_points_value'] : 50;
			$mwb_wpr_cart_points_rate   = get_option( 'mwb_wpr_cart_points_rate', 1 );
			$mwb_wpr_cart_price_rate    = get_option( 'mwb_wpr_cart_price_rate', 1 );
			$mwb_wpr_make_readonly      = get_option( 'mwb_wpr_make_readonly', 0 );
			$mwb_user_current_points    = (int) get_user_meta( get_current_user_id(), 'mwb_wpr_points', true );
			$mwb_user_current_points    = ! empty( $mwb_user_current_points ) ? $mwb_user_current_points : 0;
			$mwb_wpr                    = array(
				'ajaxurl'                   => admin_url( 'admin-ajax.php' ),
				'message'                   => __( 'Please enter valid points', 'woocommerce-ultimate-points-and-rewards' ),
				'minimum_points'            => $mwb_minimum_points_value,
				'confirmation_msg'          => __( 'Do you really want to upgrade your user level as this process will deduct the required points from your account?', 'woocommerce-ultimate-points-and-rewards' ),
				'minimum_points_text'       => __( 'Minimum Points Require To Convert Points To Coupon is ', 'woocommerce-ultimate-points-and-rewards' ) . $mwb_minimum_points_value,
				'mwb_wpr_custom_notice'     => __( 'Number of Point you had entered will get deducted from your Account', 'woocommerce-ultimate-points-and-rewards' ),
				'mwb_wpr_nonce'             => wp_create_nonce( 'mwb-wpr-verify-nonce' ),
				'mwb_wpr_cart_points_rate'  => $mwb_wpr_cart_points_rate,
				'mwb_wpr_cart_price_rate'   => $mwb_wpr_cart_price_rate,
				'make_readonly'             => $mwb_wpr_make_readonly,
				'not_allowed'               => __( 'Please enter some valid points!', 'woocommerce-ultimate-points-and-rewards' ),
				'notification_color'        => $mwb_wpr_notification_color,
				'mwb_points'                => esc_html__( 'Points', 'woocommerce-ultimate-points-and-rewards' ),
				'mwb_wallet_invalid_msg'    => esc_html__( 'Enter points is invalid', 'woocommerce-ultimate-points-and-rewards' ),
				'mwb_user_current_points'   => $mwb_user_current_points,
				'is_cart_redeem_enable'     => get_option( 'mwb_wpr_custom_points_on_cart', 0 ),
				'is_checkout_redeem_enable' => get_option( 'mwb_wpr_apply_points_checkout', 0 ),
			);
			wp_register_script( 'mwb_wpr_clipboard', MWB_WPR_URL . 'assets/js/dist/clipboard.min.js', array( 'jquery' ), '2.7.1' );
			wp_localize_script( 'mwb_wpr_clipboard', 'mwb_wpr', $mwb_wpr );
			wp_enqueue_script( 'mwb_wpr_clipboard' );
			wp_register_script( 'mwb_wpr_points_acounts', MWB_WPR_JS_LOAD_PUBLIC, array( 'jquery' ), '2.7.1' );
			wp_localize_script( 'mwb_wpr_points_acounts', 'mwb_wpr', $mwb_wpr );
			wp_enqueue_script( 'mwb_wpr_points_acounts' );
			wp_enqueue_style( 'mwb_wpr_front_end_css', MWB_WPR_URL . 'assets/css/public/woocommerce-ultimate-points-public.min.css', array(), '2.7.1' );
			wp_enqueue_style( 'mwb_wpr_front_end_css', MWB_WPR_URL . 'assets/css/public/font-awesome.min.css', array(), '2.7.1' );
		}

		/**
		 * This function is used to maintain coupon value of latest version of woocommerce.
		 *
		 * @param string $item_id item_id.
		 * @param object $item    item.
		 * @return void
		 */
		public function mwb_wpr_woocommerce_order_add_coupon_woo_latest_version( $item_id, $item ) {
			if ( get_class( $item ) == 'WC_Order_Item_Coupon' ) {
				$mwp_wpr_coupon_code = $item->get_code();
				$the_coupon          = new WC_Coupon( $mwp_wpr_coupon_code );
				if ( isset( $the_coupon ) ) {
					$mwp_wpr_discount_amount     = $item->get_discount();
					$mwp_wpr_discount_amount_tax = $item->get_discount_tax();
					$mwp_wpr_coupon_id           = $the_coupon->get_id();
					$pointscoupon                = get_post_meta( $mwp_wpr_coupon_id, 'mwb_wpr_points_coupon', true );
					if ( ! empty( $pointscoupon ) ) {
						$amount         = get_post_meta( $mwp_wpr_coupon_id, 'coupon_amount', true );
						$total_discount = $mwp_wpr_discount_amount + $mwp_wpr_discount_amount_tax;
						if ( $amount < $total_discount ) {
							$remaining_amount = 0;
						} else {
							$remaining_amount = $amount - $total_discount;
						}
						if ( ! empty( $amount ) ) {

							update_post_meta( $mwp_wpr_coupon_id, 'coupon_amount_before_use', $amount );
						}
						update_post_meta( $mwp_wpr_coupon_id, 'coupon_amount', $remaining_amount );
					}
				}
			}
		}

		/**
		 * This function is used to maintain coupon according to woocommerce previous version.
		 *
		 * @param      string $order_id       order id.
		 * @param      string $item_id       item id.
		 * @param      string $coupon_code       coupon code.
		 * @param      string $discount_amount       discount amount.
		 * @param      string $discount_amount_tax       discount amount tax.
		 * @name mwb_wpr_woocommerce_order_add_coupon
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_order_add_coupon( $order_id, $item_id, $coupon_code, $discount_amount, $discount_amount_tax ) {
			 $the_coupon = new WC_Coupon( $coupon_code );
			if ( isset( $the_coupon->id ) ) {
				$coupon_id    = $the_coupon->id;
				$pointscoupon = get_post_meta( $coupon_id, 'mwb_wpr_points_coupon', true );
				if ( ! empty( $pointscoupon ) ) {
					$amount         = get_post_meta( $coupon_id, 'coupon_amount', true );
					$total_discount = $discount_amount + $discount_amount_tax;
					if ( $amount < $total_discount ) {
						$remaining_amount = 0;
					} else {
						$remaining_amount = $amount - $total_discount;
					}
					update_post_meta( $coupon_id, 'coupon_amount', $remaining_amount );
				}
			}
		}

		/**
		 * This function is used to generate coupon according to points.
		 *
		 * @param      int $couponnumber       coupon number.
		 * @param      int $couponamont       coupon amount.
		 * @param      int $user_id       user id.
		 * @param      int $points       user points.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_create_points_coupon( $couponnumber, $couponamont, $user_id, $points ) {

			$coupon_code        = $couponnumber; // Code.
			$amount             = (int) $couponamont; // Amount.
			$discount_type      = 'fixed_cart';
			$coupon_description = __( 'Points And Reward - User ID#', 'woocommerce-ultimate-points-and-rewards' ) . $user_id;

			$coupon = array(
				'post_title'   => $coupon_code,
				'post_content' => $coupon_description,
				'post_status'  => 'publish',
				'post_author'  => $user_id,
				'post_type'    => 'shop_coupon'
			);

			$new_coupon_id = wp_insert_post($coupon);

			if ( ! empty( $new_coupon_id ) ) {

				$coupon_obj = new WC_Coupon( $new_coupon_id );
				$coupon_obj->save();

				$coupon_settings = get_option( 'mwb_wpr_coupons_gallery', true );
				$individual_use  = ! empty( $coupon_settings['enable_coupon_individual'] ) ? $coupon_settings['enable_coupon_individual'] : 'no';
				$free_shipping   = ! empty( $coupon_settings['enable_coupon_free_shipping'] ) ? $coupon_settings['enable_coupon_free_shipping'] : 'no';
				$coupon_expiry   = ! empty( $coupon_settings['coupon_expiry'] ) ? $coupon_settings['coupon_expiry'] : 1;
				$coupon_minspend = ! empty( $coupon_settings['coupon_minspend'] ) ? $coupon_settings['coupon_minspend'] : '';
				$coupon_maxspend = ! empty( $coupon_settings['coupon_maxspend'] ) ? $coupon_settings['coupon_maxspend'] : '';
				$usage_limit     = ! empty( $coupon_settings['usage_limit'] ) ? $coupon_settings['usage_limit'] : '';
				$todaydate       = date_i18n( 'Y-m-d' );
				$user            = get_userdata( $user_id );

				if ( 1 == $individual_use ) {

					$individual_use = 'yes';
				} else {

					$individual_use = 'no';
				}

				if ( 1 == $free_shipping ) {

					$free_shipping = 'yes';
				} else {

					$free_shipping = 'no';
				}

				if ( $coupon_expiry > 0 ) {
					$expirydate = date_i18n( 'Y-m-d', strtotime( "$todaydate +$coupon_expiry day" ) );
				} else {
					$expirydate = '';
				}

				$expirydate = strtotime( $expirydate );

				if ( $coupon_minspend > 0 ) {

					$coupon_minspend = $coupon_minspend;
				} else {

					$coupon_minspend = '';
				}

				if ( $coupon_maxspend > 0 ) {

					$coupon_maxspend = $coupon_maxspend;
				} else {

					$coupon_maxspend = '';
				}

				if ( $usage_limit > 0 ) {

					$usage_limit = $usage_limit;
				} else {

					$usage_limit = '';
				}

				update_post_meta( $new_coupon_id, 'discount_type', $discount_type );
				update_post_meta( $new_coupon_id, 'coupon_amount', $amount );
				update_post_meta( $new_coupon_id, 'date_expires', $expirydate );
				update_post_meta( $new_coupon_id, 'individual_use', $individual_use );
				update_post_meta( $new_coupon_id, 'usage_limit', $usage_limit );
				update_post_meta( $new_coupon_id, 'free_shipping', $free_shipping );
				update_post_meta( $new_coupon_id, 'minimum_amount', $coupon_minspend );
				update_post_meta( $new_coupon_id, 'maximum_amount', $coupon_maxspend );
				update_post_meta( $new_coupon_id, 'mwb_wpr_points_coupon', $user_id );

				// update coupon original amount.
				$wps_coupon_static_amount = get_post_meta( $new_coupon_id, 'mwb_coupon_static_amount', true );
				if ( empty( $wps_coupon_static_amount ) ) {

					update_post_meta( $new_coupon_id, 'mwb_coupon_static_amount', $amount );
				}

				// save created coupon for user view.

				$user_log = get_user_meta( $user_id, 'mwb_wpr_user_log', true );
				$user_log = ! empty( $user_log ) && is_array( $user_log ) ? $user_log : array();
				if ( empty( $user_log ) ) {
					$user_log = array();
					$user_log[ 'mwb_wpr_' . $coupon_code . '#' . $new_coupon_id ] = array(
						'points'  => $points,
						'code'    => $coupon_code,
						'camount' => get_woocommerce_currency_symbol() . $amount,
						'left'    => get_woocommerce_currency_symbol() . $amount,
						'expiry'  => $expirydate,
					);
				} else {
					$user_log[ 'mwb_wpr_' . $coupon_code . '#' . $new_coupon_id ] = array(
						'points'  => $points,
						'code'    => $coupon_code,
						'camount' => get_woocommerce_currency_symbol() . $amount,
						'left'    => get_woocommerce_currency_symbol() . $amount,
						'expiry'  => $expirydate,
					);
				}
				update_user_meta( $user_id, 'mwb_wpr_user_log', $user_log );

				// create points log for user.
				if ( empty( $expirydate ) ) {
					$expirydate = __( 'No Expiry', 'woocommerce-ultimate-points-and-rewards' );
				}

				$get_points          = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
				$available_points    = $get_points - (int) $points;
				$coupon_point_detail = get_user_meta( $user_id, 'points_details', true );
				$coupon_point_detail = ! empty( $coupon_point_detail ) && is_array( $coupon_point_detail ) ? $coupon_point_detail : array();
				$today_date          = date_i18n( 'Y-m-d h:i:sa' );

				if ( isset( $coupon_point_detail['Coupon_details'] ) && ! empty( $coupon_point_detail['Coupon_details'] ) ) {
					$coupon_array                            = array(
						'Coupon_details' => $points,
						'date'           => $today_date,
					);
					$coupon_point_detail['Coupon_details'][] = $coupon_array;
				} else {
					if ( ! is_array( $coupon_point_detail ) ) {
						$coupon_point_detail = array();
					}
					$coupon_array                            = array(
						'Coupon_details' => $points,
						'date'           => $today_date,
					);
					$coupon_point_detail['Coupon_details'][] = $coupon_array;
				}
				update_user_meta( $user_id, 'mwb_wpr_points', $available_points );
				update_user_meta( $user_id, 'points_details', $coupon_point_detail );
			}

			return true;
		}

		/**
		 * This function is used to cunstruct Points Tab in MY ACCOUNT Page.
		 *
		 * @name mwb_wpr_add_my_account_endpoint
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_add_my_account_endpoint() {
			flush_rewrite_rules( true );
			add_rewrite_endpoint( 'points', EP_PAGES );
			add_rewrite_endpoint( 'view-log', EP_PAGES );
		}

		/**
		 * This function is used to get user_id to get points in MY ACCOUNT Page Points Tab.
		 *
		 * @name mwb_wpr_account_points
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_account_points() {
			$user_ID = get_current_user_ID();
			$user    = new WP_User( $user_ID );
			require plugin_dir_path( __FILE__ ) . 'mwb-wpr-points-template.php';
		}

		/**
		 * This function is used to include the working of View_point_log
		 *
		 * @name mwb_wpr_account_viewlog
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_account_viewlog() {
			$user_ID = get_current_user_ID();
			$user    = new WP_User( $user_ID );
			require plugin_dir_path( __FILE__ ) . 'mwb-wpr-points-log-template.php';
		}

		/**
		 * This function is used to set User Role to see Points Tab in MY ACCOUNT Page.
		 *
		 * @param      string $items       Items.
		 * @name mwb_wpr_points_dashboard
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_points_dashboard( $items ) {
			$user_ID                 = get_current_user_ID();
			$user                    = new WP_User( $user_ID );
			$general_settings        = get_option( 'mwb_wpr_settings_gallery', true );
			$mwb_wpr_points_tab_text = isset( $general_settings['mwb_wpr_points_tab_text'] ) ? $general_settings['mwb_wpr_points_tab_text'] : __( 'Points', 'woocommerce-ultimate-points-and-rewards' );
			if ( empty( $mwb_wpr_points_tab_text ) ) {
				$mwb_wpr_points_tab_text = __( 'Points', 'woocommerce-ultimate-points-and-rewards' );
			}

			$logout = $items['customer-logout'];
			unset( $items['customer-logout'] );
			$items['points']          = $mwb_wpr_points_tab_text;
			$items['customer-logout'] = $logout;
			return $items;
		}

		/**
		 * This function is used to check is order total is enable or not
		 *
		 * @name check_enable_offer
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @return true/false
		 */
		public function check_enable_offer() {
			$is_enable            = false;
			$thankyouorder_enable = get_option( 'mwb_wpr_thankyouorder_enable', false );
			if ( ! empty( $thankyouorder_enable ) && 'on' === $thankyouorder_enable ) {
				$is_enable = true;
			}
			return $is_enable;
		}

		/**
		 * This function is used to calculate the order total points from the order
		 *
		 * @param  int $order_id   order ID.
		 * @param  int $user_id   User ID.
		 * @name calculate_points
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function calculate_points( $order_id, $user_id ) {

			$thankyouorder_min = get_option( 'mwb_wpr_thankyouorder_minimum', array() );
			$thankyouorder_max = get_option( 'mwb_wpr_thankyouorder_maximum', array() );

			$thankyouorder_value = get_option( 'mwb_wpr_thankyouorder_current_type', array() );
			$order               = wc_get_order( $order_id );
			$order_total         = $order->get_total();
			$order_total         = apply_filters( 'mwb_par_convert_same_currency_base_price', $order_total, $order_id );
			$total_points        = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			if ( empty( $total_points ) ) {
				$total_points = 0;
			}

			if ( is_array( $thankyouorder_value ) && ! empty( $thankyouorder_value ) ) {
				foreach ( $thankyouorder_value as $key => $value ) {

					if ( isset( $thankyouorder_min[ $key ] ) &&
						! empty( $thankyouorder_min[ $key ] ) &&
						isset( $thankyouorder_max[ $key ] ) &&
						! empty( $thankyouorder_max[ $key ] ) ) {

						if ( $thankyouorder_min[ $key ] <= $order_total &&
							$order_total <= $thankyouorder_max[ $key ] ) {
							$mwb_wpr_point = (int) $thankyouorder_value[ $key ];
							$total_points  = $total_points + $mwb_wpr_point;

						}
					} elseif ( isset( $thankyouorder_min[ $key ] ) &&
					! empty( $thankyouorder_min[ $key ] ) &&
					empty( $thankyouorder_max[ $key ] ) ) {
						if ( $thankyouorder_min[ $key ] <= $order_total ) {
							$mwb_wpr_point = (int) $thankyouorder_value[ $key ];
							$total_points  = $total_points + $mwb_wpr_point;
						}
					}
				}
			}
			if ( ! empty( $total_points ) ) {
				update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
			}
			if ( ! empty( $mwb_wpr_point ) ) {
				$this->generate_points_log( $user_id, $mwb_wpr_point );
				$this->send_mail_order_total( $user_id, $mwb_wpr_point );
			}
		}

		/**
		 * This function is used to generate points log of the order total
		 *
		 * @param      int $user_id       User ID.
		 * @param      int $purchase_value       Purchase Value.
		 * @name generate_points_log
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function generate_points_log( $user_id, $purchase_value ) {
			$mwb_referral_purchase_value = $purchase_value;
			$ref_product_detail_points   = get_user_meta( $user_id, 'points_details', true );
			$today_date                  = date_i18n( 'Y-m-d h:i:sa' );
			if ( isset( $ref_product_detail_points['points_on_order'] ) && ! empty( $ref_product_detail_points['points_on_order'] ) ) {
				$ref_pro_array                                  = array(
					'points_on_order' => $mwb_referral_purchase_value,
					'date'            => $today_date,
				);
				$ref_product_detail_points['points_on_order'][] = $ref_pro_array;
			} else {
				if ( ! is_array( $ref_product_detail_points ) ) {
					$ref_product_detail_points = array();
				}
				$ref_pro_array                                  = array(
					'points_on_order' => $mwb_referral_purchase_value,
					'date'            => $today_date,
				);
				$ref_product_detail_points['points_on_order'][] = $ref_pro_array;
			}
			update_user_meta( $user_id, 'points_details', $ref_product_detail_points );
		}

		/**
		 * This function is used to send mail for the order total point.
		 *
		 * @param      int $user_id       user ID.
		 * @param      int $points       points.
		 * @name send_mail_order_total
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function send_mail_order_total( $user_id, $points ) {
			$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
			$total_points              = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			$user                      = get_user_by( 'ID', $user_id );
			$user_email                = $user->user_email;
			if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
				$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
				$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_point_on_order_total_range_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_point_on_order_total_range_subject'] : '';
				$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_point_on_order_total_range_desc'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_point_on_order_total_range_desc'] : '';
				$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_points, $mwb_wpr_email_discription );
				$mwb_wpr_email_discription  = str_replace( '[ORDERTOTALPOINT]', $points, $mwb_wpr_email_discription );
				$user                       = get_user_by( 'email', $user_email );
				$user_name                  = $user->user_firstname;
				$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
				if ( $mwb_wpr_notificatin_enable ) {
					$headers = array( 'Content-Type: text/html; charset=UTF-8' );
					wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
				}
			}
		}

		/**
		 * This function is used to give product points to user if order status of Product is complete and processing.
		 *
		 * @param      int    $order_id       order id.
		 * @param      string $old_status       old status.
		 * @param      string $new_status       new status.
		 * @name mwb_wpr_woocommerce_order_status_changed
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_order_status_changed( $order_id, $old_status, $new_status ) {
			if ( $old_status != $new_status ) {
				$mwb_wpr_one_email                   = false;
				$points_key_priority_high            = false;
				$item_points                         = 0;
				$today_date                          = date_i18n( 'Y-m-d h:i:sa' );
				$general_settings                    = get_option( 'mwb_wpr_settings_gallery', true );
				$coupon_settings_array               = get_option( 'mwb_wpr_coupons_gallery', array() );
				$mwb_wpr_coupon_conversion_enable    = $this->is_order_conversion_enabled();
				$mwb_comment_value                   = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;
				$mwb_refer_value                     = isset( $general_settings['mwb_refer_value'] ) ? intval( $general_settings['mwb_refer_value'] ) : 1;
				$mwb_per_currency_spent_value        = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) ? intval( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) : 1;
				$mwb_wpr_set_preferences             = isset( $general_settings['mwb_wpr_set_preferences'] ) ? $general_settings['mwb_wpr_set_preferences'] : 'to_both';
				$mwb_referral_purchase_limit         = isset( $general_settings['mwb_referral_purchase_limit'] ) ? intval( $general_settings['mwb_referral_purchase_limit'] ) : 0;
				$mwb_wpr_general_referal_order_limit = isset( $general_settings['mwb_wpr_general_referal_order_limit'] ) ? intval( $general_settings['mwb_wpr_general_referal_order_limit'] ) : 1;
				$mwb_wpr_notificatin_array           = get_option( 'mwb_wpr_notificatin_array', true );
				if ( 'completed' === $new_status ) {

					$order      = wc_get_order( $order_id );
					$user_id    = absint( $order->get_user_id() );
					$user       = get_user_by( 'ID', $user_id );
					$user_email = $user->user_email;
					// =======custmization============
					if ( $this->check_enable_offer() ) {

						$this->calculate_points( $order_id, $user_id );
					}
					// =======Endcustmization============
					if ( isset( $user_id ) && ! empty( $user_id ) ) {

						$mwb_wpr_ref_noof_order = (int) get_user_meta( $user_id, 'mwb_wpr_no_of_orders', true );
						if ( isset( $mwb_wpr_ref_noof_order ) && ! empty( $mwb_wpr_ref_noof_order ) ) {
							++$mwb_wpr_ref_noof_order;
							update_user_meta( $user_id, 'mwb_wpr_no_of_orders', $mwb_wpr_ref_noof_order );
						} else {
							update_user_meta( $user_id, 'mwb_wpr_no_of_orders', 1 );
						}
					}
					foreach ( $order->get_items() as $item_id => $item ) {
						$woo_ver = WC()->version;
						if ( $woo_ver < '3.0.0' ) {
							if ( isset( $item['item_meta']['Points'] ) && ! empty( $item['item_meta']['Points'] ) ) {
								// hpos.
								$itempointsset = mwb_par_hpos_get_meta_data( $order_id, "$order_id#$item_id#set", true );
								if ( 'set' === $itempointsset ) {
									continue;
								}

								$item_points += (int) $item['item_meta']['Points'][0];
								$product      = $order->get_product_from_item( $item );

								$product_id   = $product->id;
								$check_enable = get_post_meta( $product_id, 'mwb_product_points_enable', 'no' );

								if ( 'to_assign_point' === $mwb_wpr_set_preferences || 'to_both' === $mwb_wpr_set_preferences ) {
									$mwb_wpr_one_email = true;
								}
								if ( $mwb_wpr_coupon_conversion_enable ) {
									$points_key_priority_high = true;
								}
							}
							$mwb_referral_purchase_enable = isset( $general_settings['mwb_referral_purchase_enable'] ) ? intval( $general_settings['mwb_referral_purchase_enable'] ) : 0;
							$mwb_referral_purchase_value  = isset( $general_settings['mwb_referral_purchase_value'] ) ? intval( $general_settings['mwb_referral_purchase_value'] ) : 1;
							if ( $mwb_referral_purchase_enable ) {
								$user_id                = $order->get_user_id();
								$mwb_wpr_ref_noof_order = get_user_meta( $user_id, 'mwb_wpr_no_of_orders', true );
								$refer_id               = get_user_meta( $user_id, 'user_visit_through_link', true );
								$refer_user             = get_user_by( 'ID', $refer_id );
								$refer_user_email       = $refer_user->user_email;

								if ( 0 === $mwb_referral_purchase_limit ) {
									if ( isset( $refer_id ) && ! empty( $refer_id ) ) {
										$prev_points_of_ref_userid = (int) get_user_meta( $refer_id, 'mwb_wpr_points', true );

										$update_points             = $prev_points_of_ref_userid + $mwb_referral_purchase_value;
										$ref_product_detail_points = get_user_meta( $refer_id, 'points_details', true );

										if ( isset( $ref_product_detail_points['ref_product_detail'] ) && ! empty( $ref_product_detail_points['ref_product_detail'] ) ) {
											$ref_pro_array                                     = array(
												'ref_product_detail' => $mwb_referral_purchase_value,
												'date' => $today_date,
												'refered_user' => $user_id,
											);
											$ref_product_detail_points['ref_product_detail'][] = $ref_pro_array;
										} else {
											if ( ! is_array( $ref_product_detail_points ) ) {
												$ref_product_detail_points = array();
											}
											$ref_pro_array                                     = array(
												'ref_product_detail' => $mwb_referral_purchase_value,
												'date' => $today_date,
												'refered_user' => $user_id,
											);
											$ref_product_detail_points['ref_product_detail'][] = $ref_pro_array;
										}
										update_user_meta( $refer_id, 'points_details', $ref_product_detail_points );
										update_user_meta( $refer_id, 'mwb_wpr_points', $update_points );
										if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
											$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
											$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_subject'] : '';
											$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_discription_custom_id'] : '';
											$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_referral_purchase_value, $mwb_wpr_email_discription );
											$mwb_wpr_email_discription  = str_replace( '[Total Points]', $update_points, $mwb_wpr_email_discription );
											$mwb_wpr_email_discription  = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
											$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );
											$mwb_wpr_email_discription  = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
											$user                       = get_user_by( 'email', $refer_user_email );
											$user_name                  = $user->user_firstname;
											$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
											if ( $mwb_wpr_notificatin_enable ) {
												$headers = array( 'Content-Type: text/html; charset=UTF-8' );
												wc_mail( $refer_user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
											}
										}
									}
								} else {
									if ( $mwb_wpr_ref_noof_order <= $mwb_wpr_general_referal_order_limit ) {
										if ( isset( $refer_id ) && ! empty( $refer_id ) ) {
											$prev_points_of_ref_userid = (int) get_user_meta( $refer_id, 'mwb_wpr_points', true );

											$update_points             = $prev_points_of_ref_userid + $mwb_referral_purchase_value;
											$ref_product_detail_points = get_user_meta( $refer_id, 'points_details', true );

											if ( isset( $ref_product_detail_points['ref_product_detail'] ) && ! empty( $ref_product_detail_points['ref_product_detail'] ) ) {
												$ref_pro_array                                     = array(
													'ref_product_detail' => $mwb_referral_purchase_value,
													'date' => $today_date,
												);
												$ref_product_detail_points['ref_product_detail'][] = $ref_pro_array;
											} else {
												if ( ! is_array( $ref_product_detail_points ) ) {
													$ref_product_detail_points = array();
												}
												$ref_pro_array                                     = array(
													'ref_product_detail' => $mwb_referral_purchase_value,
													'date' => $today_date,
												);
												$ref_product_detail_points['ref_product_detail'][] = $ref_pro_array;
											}

											update_user_meta( $refer_id, 'points_details', $ref_product_detail_points );
											update_user_meta( $refer_id, 'mwb_wpr_points', $update_points );
											if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
												$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
												$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_subject'] : '';
												$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_discription_custom_id'] : '';
												$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_referral_purchase_value, $mwb_wpr_email_discription );
												$mwb_wpr_email_discription  = str_replace( '[Total Points]', $update_points, $mwb_wpr_email_discription );
												$mwb_wpr_email_discription  = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
												$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );
												$mwb_wpr_email_discription  = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
												$user                       = get_user_by( 'email', $refer_user_email );
												$user_name                  = $user->user_firstname;
												$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
												if ( $mwb_wpr_notificatin_enable ) {
													$headers = array( 'Content-Type: text/html; charset=UTF-8' );
													wc_mail( $refer_user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
												}
											}
										}
									}
								}
							}
						} else {
							$mwb_wpr_items = $item->get_meta_data();
							foreach ( $mwb_wpr_items as $key => $mwb_wpr_value ) {
								if ( 'to_assign_point' === $mwb_wpr_set_preferences || 'to_both' === $mwb_wpr_set_preferences ) {
									if ( isset( $mwb_wpr_value->key ) && ! empty( $mwb_wpr_value->key ) && ( 'Points' === $mwb_wpr_value->key ) ) {
										// hpos.
										$itempointsset = mwb_par_hpos_get_meta_data( $order_id, "$order_id#$mwb_wpr_value->id#set", true );
										if ( 'set' === $itempointsset ) {
											continue;
										}
										$item_points      += (int) $mwb_wpr_value->value;
										$mwb_wpr_one_email = true;
										$product_id        = $item->get_product_id();
										$check_enable      = get_post_meta( $product_id, 'mwb_product_points_enable', 'no' );
										if ( 'yes' === $check_enable ) {
											// hpos.
											mwb_par_hpos_update_meta_data( $order_id, "$order_id#$mwb_wpr_value->id#set", 'set' );
										}
										if ( $mwb_wpr_coupon_conversion_enable ) {
											$points_key_priority_high = true;
										}
									}
								}
							}
						}
					}
					if ( $mwb_wpr_one_email && 'yes' === $check_enable && isset( $item_points ) && ! empty( $item_points ) ) {
						$get_product_points = get_post_meta( $product_id, 'mwb_points_product_value', 1 );
						$user_id            = absint( $order->get_user_id() );
						if ( ! empty( $user_id ) ) {
							$user                  = get_user_by( 'ID', $user_id );
							$user_email            = $user->user_email;
							$get_points            = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
							$product_detail_points = get_user_meta( $user_id, 'points_details', true );
							if ( isset( $product_detail_points['product_details'] ) && ! empty( $product_detail_points['product_details'] ) ) {

								$pro_array                                  = array(
									'product_details' => $item_points,
									'date'            => $today_date,
								);
								$product_detail_points['product_details'][] = $pro_array;
							} else {
								if ( ! is_array( $product_detail_points ) ) {
									$product_detail_points = array();
								}
								$pro_array                                  = array(
									'product_details' => $item_points,
									'date'            => $today_date,
								);
								$product_detail_points['product_details'][] = $pro_array;
							}
							$total_points = $get_points + $item_points;
							update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
							update_user_meta( $user_id, 'points_details', $product_detail_points );
							if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
								$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
								$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_product_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_product_email_subject'] : '';
								$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_product_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_product_email_discription_custom_id'] : '';
								$mwb_wpr_email_discription  = str_replace( '[Points]', $item_points, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[Total Points]', $total_points, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
								$user                       = get_user_by( 'email', $user_email );
								$user_name                  = $user->user_firstname;
								$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
								if ( $mwb_wpr_notificatin_enable ) {
									$headers = array( 'Content-Type: text/html; charset=UTF-8' );
									wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
								}
							}
						}
					}
					$general_settings            = get_option( 'mwb_wpr_settings_gallery', true );
					$mwb_referral_purchase_value = isset( $general_settings['mwb_referral_purchase_value'] ) ? intval( $general_settings['mwb_referral_purchase_value'] ) : 1;
					$order_total                 = $order->get_total();
					$order_total                 = str_replace( wc_get_price_decimal_separator(), '.', strval( $order_total ) );

					// check if order total is greater than zero.
					if ( $order_total > 0 ) {
						$order_total = apply_filters( 'mwb_par_convert_same_currency_base_price', $order_total, $order_id );
						// check per currency is enable or not.
						if ( $mwb_wpr_coupon_conversion_enable ) {
							if ( 'to_per_currency' === $mwb_wpr_set_preferences || 'to_both' === $mwb_wpr_set_preferences || ! $points_key_priority_high ) {
								// hpos.
								$item_conversion_id_set = mwb_par_hpos_get_meta_data( $order_id, "$order_id#item_conversion_id", true );
								if ( 'set' !== $item_conversion_id_set ) {
									$mwb_wpr_coupon_conversion_price  = $coupon_settings_array['mwb_wpr_coupon_conversion_price'];
									$mwb_wpr_coupon_conversion_points = $coupon_settings_array['mwb_wpr_coupon_conversion_points'];
									$mwb_comment_value                = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;
									$mwb_refer_value                  = isset( $general_settings['mwb_refer_value'] ) ? intval( $general_settings['mwb_refer_value'] ) : 1;
									$user_id                          = $order->get_user_id();
									$get_points                       = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
									$pro_conversion_points            = get_user_meta( $user_id, 'points_details', true );
									$today_date                       = date_i18n( 'Y-m-d h:i:sa' );
									$user                             = get_user_by( 'ID', $user_id );
									$user_email                       = $user->user_email;
									$points_calculation               = round( ( $order_total * $mwb_wpr_coupon_conversion_points ) / $mwb_wpr_coupon_conversion_price );
									$total_points                     = intval( $points_calculation + $get_points );
									if ( isset( $pro_conversion_points['pro_conversion_points'] ) && ! empty( $pro_conversion_points['pro_conversion_points'] ) ) {
										$pro_array                                        = array();
										$pro_array                                        = array(
											'pro_conversion_points' => $points_calculation,
											'date' => $today_date,
										);
										$pro_conversion_points['pro_conversion_points'][] = $pro_array;
									} else {
										if ( ! is_array( $pro_conversion_points ) ) {
											$pro_conversion_points = array();
										}
										$pro_array                                        = array(
											'pro_conversion_points' => $points_calculation,
											'date' => $today_date,
										);
										$pro_conversion_points['pro_conversion_points'][] = $pro_array;
									}
									update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
									update_user_meta( $user_id, 'points_details', $pro_conversion_points );
									// hpos.
									mwb_par_hpos_update_meta_data( $order_id, 'mwb_wpr_per_currency_awarded_points', $points_calculation );
									mwb_par_hpos_update_meta_data( $order_id, "$order_id#item_conversion_id", 'set' );
									if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
										$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
										$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_amount_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_amount_email_subject'] : '';
										$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_amount_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_amount_email_discription_custom_id'] : '';
										$mwb_wpr_email_discription  = str_replace( '[Points]', $points_calculation, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[Total Points]', $total_points, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );
										$user                       = get_user_by( 'email', $user_email );
										$user_name                  = $user->user_firstname;
										$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
										if ( $mwb_wpr_notificatin_enable ) {
											$headers = array( 'Content-Type: text/html; charset=UTF-8' );
											wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
										}
									}
								}
							}
						}
					}

					// Referral Purchase Point Feature Conditions.
					$mwb_referral_purchase_enable = isset( $general_settings['mwb_referral_purchase_enable'] ) ? intval( $general_settings['mwb_referral_purchase_enable'] ) : 0;
					$mwb_referral_purchase_value  = isset( $general_settings['mwb_referral_purchase_value'] ) ? intval( $general_settings['mwb_referral_purchase_value'] ) : 1;
					if ( $mwb_referral_purchase_enable ) {
						$user_id                = $order->get_user_id();
						$mwb_wpr_ref_noof_order = get_user_meta( $user_id, 'mwb_wpr_no_of_orders', true );
						$refer_id               = get_user_meta( $user_id, 'user_visit_through_link', true );
						$refer_user             = get_user_by( 'ID', $refer_id );
						if ( ! empty( $refer_user ) ) {
							$refer_user_email = $refer_user->user_email;
						}

						if ( 0 === $mwb_referral_purchase_limit ) {
							if ( isset( $refer_id ) && ! empty( $refer_id ) ) {

								$today_date                = date_i18n( 'Y-m-d h:i:sa' );
								$prev_points_of_ref_userid = (int) get_user_meta( $refer_id, 'mwb_wpr_points', true );

								$update_points             = $prev_points_of_ref_userid + $mwb_referral_purchase_value;
								$ref_product_detail_points = get_user_meta( $refer_id, 'points_details', true );

								if ( isset( $ref_product_detail_points['ref_product_detail'] ) && ! empty( $ref_product_detail_points['ref_product_detail'] ) ) {
									$ref_pro_array                                     = array(
										'ref_product_detail' => $mwb_referral_purchase_value,
										'date'         => $today_date,
										'refered_user' => $user_id,
									);
									$ref_product_detail_points['ref_product_detail'][] = $ref_pro_array;
								} else {
									if ( ! is_array( $ref_product_detail_points ) ) {
										$ref_product_detail_points = array();
									}
									$ref_pro_array                                     = array(
										'ref_product_detail' => $mwb_referral_purchase_value,
										'date'         => $today_date,
										'refered_user' => $user_id,
									);
									$ref_product_detail_points['ref_product_detail'][] = $ref_pro_array;
								}

								update_user_meta( $refer_id, 'points_details', $ref_product_detail_points );
								update_user_meta( $refer_id, 'mwb_wpr_points', $update_points );
								if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
									$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
									$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_subject'] : '';
									$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_discription_custom_id'] : '';
									$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_referral_purchase_value, $mwb_wpr_email_discription );
									$mwb_wpr_email_discription  = str_replace( '[Total Points]', $update_points, $mwb_wpr_email_discription );
									$mwb_wpr_email_discription  = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
									$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );
									$mwb_wpr_email_discription  = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
									$user                       = get_user_by( 'email', $refer_user_email );
									$user_name                  = $user->user_firstname;
									$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
									if ( $mwb_wpr_notificatin_enable ) {
										$headers = array( 'Content-Type: text/html; charset=UTF-8' );
										wc_mail( $refer_user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
									}
								}
							}
						} else {

							if ( isset( $mwb_wpr_ref_noof_order ) && ! empty( $mwb_wpr_ref_noof_order ) && $mwb_wpr_ref_noof_order <= $mwb_wpr_general_referal_order_limit ) {
								if ( isset( $refer_id ) && ! empty( $refer_id ) ) {

									$today_date                = date_i18n( 'Y-m-d h:i:sa' );
									$prev_points_of_ref_userid = (int) get_user_meta( $refer_id, 'mwb_wpr_points', true );

									$update_points             = $prev_points_of_ref_userid + $mwb_referral_purchase_value;
									$ref_product_detail_points = get_user_meta( $refer_id, 'points_details', true );

									if ( isset( $ref_product_detail_points['ref_product_detail'] ) && ! empty( $ref_product_detail_points['ref_product_detail'] ) ) {
										$ref_pro_array                                     = array(
											'ref_product_detail' => $mwb_referral_purchase_value,
											'date'         => $today_date,
											'refered_user' => $user_id,
										);
										$ref_product_detail_points['ref_product_detail'][] = $ref_pro_array;
									} else {
										if ( ! is_array( $ref_product_detail_points ) ) {
											$ref_product_detail_points = array();
										}
										$ref_pro_array                                     = array(
											'ref_product_detail' => $mwb_referral_purchase_value,
											'date'         => $today_date,
											'refered_user' => $user_id,
										);
										$ref_product_detail_points['ref_product_detail'][] = $ref_pro_array;
									}

									update_user_meta( $refer_id, 'points_details', $ref_product_detail_points );
									update_user_meta( $refer_id, 'mwb_wpr_points', $update_points );
									if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
										$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
										$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_subject'] : '';
										$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_purchase_email_discription_custom_id'] : '';
										$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_referral_purchase_value, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[Total Points]', $update_points, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
										$user                       = get_user_by( 'email', $refer_user_email );
										$user_name                  = $user->user_firstname;
										$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
										if ( $mwb_wpr_notificatin_enable ) {
											$headers = array( 'Content-Type: text/html; charset=UTF-8' );
											wc_mail( $refer_user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
										}
									}
								}
							}
						}
					}
				}
			}
		}

		/**
		 * This function is used to save item points in time of order according to woocommerce 3.0.
		 *
		 * @param      object $item       Item.
		 * @param      string $cart_key       cart.
		 * @param      object $values       values.
		 * @param      string $order       order.
		 * @name mwb_wpr_woocommerce_add_order_item_meta_version_3
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_add_order_item_meta_version_3( $item, $cart_key, $values, $order ) {

			if ( isset( $values['product_meta'] ) ) {
				foreach ( $values['product_meta'] ['meta_data'] as $key => $val ) {
					$order_val = stripslashes( $val );
					if ( $val ) {
						if ( 'mwb_wpm_points' === $key ) {
							$item->add_meta_data( 'Points', $order_val );
						}
						if ( 'pro_purchase_by_points' === $key ) {
							$item->add_meta_data( 'Purchasing Option', $order_val );
						}
						if ( 'mwb_wpr_purchase_point_only' === $key ) {
							$item->add_meta_data( 'Purchased By Points', $order_val );
						}
					}
				}
			}
		}

		/**
		 * This function is used to save item points in time of order according to previous woocommerce version.
		 *
		 * @param      string $item_id       The name of the plugin.
		 * @param      object $cart_item       The name of the plugin.
		 * @name mwb_wpr_woocommerce_add_order_item_meta
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_add_order_item_meta( $item_id, $cart_item ) {
			if ( isset( $cart_item ['product_meta'] ) ) {
				foreach ( $cart_item ['product_meta'] ['meta_data'] as $key => $val ) {
					$order_val = stripslashes( $val );
					if ( $val ) {
						if ( 'mwb_wpm_points' === $key ) {
							wc_add_order_item_meta( $item_id, 'Points', $order_val );
						}
						if ( 'pro_purchase_by_points' === $key ) {
							wc_add_order_item_meta( $item_id, 'Purchasing Option', $order_val );
						}
					}
				}
			}
		}

		/**
		 * This function is used to show item poits in time of order .
		 *
		 * @param      object $item_meta       meta item.
		 * @param      object $existing_item_meta       meta item.
		 * @name mwb_wpr_woocommerce_get_item_data
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_get_item_data( $item_meta, $existing_item_meta ) {

			if ( isset( $existing_item_meta ['product_meta']['meta_data'] ) ) {
				if ( $existing_item_meta ['product_meta']['meta_data'] ) {
					foreach ( $existing_item_meta['product_meta'] ['meta_data'] as $key => $val ) {
						if ( 'mwb_wpm_points' === $key ) {
							$item_meta [] = array(
								'name'  => __( 'Points', 'woocommerce-ultimate-points-and-rewards' ),
								'value' => stripslashes( $val ),
							);
						}
						if ( 'mwb_wpr_purchase_point_only' === $key ) {

							$item_meta [] = array(
								'name'  => __( 'Purchased By Points', 'woocommerce-ultimate-points-and-rewards' ),
								'value' => stripslashes( $val ),
							);
						}
					}
					$item_meta = apply_filters( 'mwb_wpm_product_item_meta', $item_meta, $key, $val );
				}
			}
			return $item_meta;
		}

		/**
		 * This function is used to save points in add to cart session0.
		 *
		 * @param      string $the_cart_data       Data.
		 * @param      string $product_id       Data.
		 * @param      string $variation_id       Data.
		 * @param      string $quantity       Data.
		 * @name mwb_wpr_woocommerce_add_cart_item_data
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_add_cart_item_data( $the_cart_data, $product_id, $variation_id, $quantity ) {
			$value_cart = isset( $_REQUEST['quantity'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['quantity'] ) ) : '';
			if ( isset( $value_cart ) && $value_cart && null !== $value_cart ) {

				$quantity = (int) $_REQUEST['quantity'];
			} else {

				$quantity = 1;
			}
			$user_id                 = get_current_user_ID();
			$get_points              = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			$product_types           = wp_get_object_terms( $product_id, 'product_type' );
			$check_enable            = get_post_meta( $product_id, 'mwb_product_points_enable', 'no' );
			$general_settings        = get_option( 'mwb_wpr_settings_gallery', true );
			$mwb_wpr_set_preferences = isset( $general_settings['mwb_wpr_set_preferences'] ) ? $general_settings['mwb_wpr_set_preferences'] : 'to_both';
			$enable_purchase_points  = isset( $general_settings['enable_purchase_points'] ) ? intval( $general_settings['enable_purchase_points'] ) : 0;

			if ( 'yes' === $check_enable ) {
				if ( 'to_assign_point' === $mwb_wpr_set_preferences || 'to_both' === $mwb_wpr_set_preferences ) {
					if ( isset( $variation_id ) && ! empty( $variation_id ) && $variation_id > 0 ) {

						$get_product_points          = get_post_meta( $variation_id, 'mwb_wpr_variable_points', 1 );
						$item_meta['mwb_wpm_points'] = (int) $get_product_points * (int) $quantity;
					} else {

						$get_product_points          = get_post_meta( $product_id, 'mwb_points_product_value', 1 );
						$item_meta['mwb_wpm_points'] = (int) $get_product_points * (int) $quantity;
					}
					$the_cart_data ['product_meta'] = array( 'meta_data' => $item_meta );
				}
			}

			if ( $enable_purchase_points ) {
				$value_check                 = ! empty( $_POST['message-send'] ) ? sanitize_text_field( wp_unslash( $_POST['message-send'] ) ) : '';
				$mwb_wpr_pro_cost__to_points = ! empty( $_POST['mwb_wpr_pro_cost_to_points'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_wpr_pro_cost_to_points'] ) ) : '';

				$item_meta['pro_mwb_pur_by_points_single_qty_val'] = $mwb_wpr_pro_cost__to_points;
				$item_meta['pro_mwb_purchase__by_points_qty']      = $quantity;
				$mwb_wpr_pro_cost__to_points                       = (int) $mwb_wpr_pro_cost__to_points * $quantity;
				if ( wp_verify_nonce( $value_check, 'custom-action' ) ) {
					if ( ! empty( $mwb_wpr_pro_cost__to_points ) ) {
						if ( $mwb_wpr_pro_cost__to_points >= $get_points ) {

							$item_meta['pro_purchase_by_points'] = $get_points;
						} else {

							$item_meta['pro_purchase_by_points'] = $mwb_wpr_pro_cost__to_points;
						}
						$the_cart_data ['product_meta'] = array( 'meta_data' => $item_meta );
					}
				}
			}

			// MWB Custom Work.
			$_product                       = wc_get_product( $product_id );
			$enable_product_purchase_points = get_post_meta( $product_id, 'mwb_product_purchase_points_only', true );
			$mwb_product_purchase_value     = get_post_meta( $product_id, 'mwb_points_product_purchase_value', true );
			$prod_type                      = $_product->get_type();
			if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {
				if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) && ( 'simple' === $prod_type ) ) {
					$mwb_product_purchase_value = (int) $mwb_product_purchase_value * $quantity;
					if ( $mwb_product_purchase_value >= $get_points ) {

						$item_meta['mwb_wpr_purchase_point_only'] = $get_points;
						$the_cart_data ['product_meta']           = array( 'meta_data' => $item_meta );
					} else {

						$item_meta['mwb_wpr_purchase_point_only'] = $mwb_product_purchase_value;
						$the_cart_data ['product_meta']           = array( 'meta_data' => $item_meta );
					}
				}
			}

			// Custom Work for Variable Product.
			if ( $this->mwb_wpr_check_whether_product_is_variable( $_product ) ) {
				$mwb_wpr_parent_id              = wp_get_post_parent_id( $variation_id );
				$enable_product_purchase_points = get_post_meta( $mwb_wpr_parent_id, 'mwb_product_purchase_points_only', true );
				$mwb_product_purchase_value     = get_post_meta( $variation_id, 'mwb_wpr_variable_points_purchase', true );
				if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {

					if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) ) {
						$mwb_product_purchase_value = (int) $mwb_product_purchase_value * $quantity;
						if ( is_user_logged_in() ) {
							if ( $mwb_product_purchase_value >= $get_points ) {

								$item_meta['mwb_wpr_purchase_point_only'] = $get_points;
								$the_cart_data ['product_meta']           = array( 'meta_data' => $item_meta );
							} else {

								$item_meta['mwb_wpr_purchase_point_only'] = $mwb_product_purchase_value;
								$the_cart_data ['product_meta']           = array( 'meta_data' => $item_meta );
							}
						}
					}
				}
			}
			// End of Custom Work.
			return $the_cart_data;
		}

		/**
		 * This function is used to show item points in product discription page.
		 *
		 * @name mwb_display_product_points
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_display_product_points() {
			global $post;
			$mwb_wpr_notification_color = get_option( 'mwb_wpr_notification_color', '#55b3a5' );
			$product                    = wc_get_product( $post->ID );
			$product_is_variable        = $this->mwb_wpr_check_whether_product_is_variable( $product );
			$check_enable               = get_post_meta( $post->ID, 'mwb_product_points_enable', 'no' );
			$general_settings           = get_option( 'mwb_wpr_settings_gallery', true );
			$mwb_wpr_set_preferences    = isset( $general_settings['mwb_wpr_set_preferences'] ) ? $general_settings['mwb_wpr_set_preferences'] : 'to_both';
			$mwb_wpr_assign_pro_text    = isset( $general_settings['mwb_wpr_assign_pro_text'] ) ? $general_settings['mwb_wpr_assign_pro_text'] : __( 'Earn', 'woocommerce-ultimate-points-and-rewards' );
			if ( 'yes' === $check_enable ) {
				if ( 'to_assign_point' === $mwb_wpr_set_preferences || 'to_both' === $mwb_wpr_set_preferences ) {
					if ( ! $product_is_variable ) {
						$get_product_points = get_post_meta( $post->ID, 'mwb_points_product_value', 1 );

						echo '<span class=mwb_wpr_product_point style=background-color:' . esc_attr( $mwb_wpr_notification_color ) . '>' . wp_kses_post( $mwb_wpr_assign_pro_text ) . ': ' . esc_attr( $get_product_points );
						esc_attr_e( ' Points', 'woocommerce-ultimate-points-and-rewards' );
						echo '</span>';
					} elseif ( $product_is_variable ) {
						$get_product_points = '<span class=mwb_wpr_variable_points></span>';
						echo "<span class=mwb_wpr_product_point  style='display:none;background-color:" . esc_attr( $mwb_wpr_notification_color ) . "'>" . wp_kses_post( $mwb_wpr_assign_pro_text ) . ': ' . wp_kses_post( $get_product_points );
						esc_attr_e( ' Points', 'woocommerce-ultimate-points-and-rewards' );
						echo '</span>';
					}
				}
			}
		}

		/**
		 * Points update in time of new user registeration.
		 *
		 * @param      string $customer_id       Data.
		 * @param      string $new_customer_data       Data.
		 * @name mwb_wpr_new_customer_registerd
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_new_customer_registerd( $customer_id, $new_customer_data ) {
			if ( get_user_by( 'ID', $customer_id ) ) {
				$general_settings      = get_option( 'mwb_wpr_settings_gallery', true );
				$coupon_settings_array = get_option( 'mwb_wpr_coupons_gallery', array() );
				$enable_mwb_signup     = isset( $general_settings['enable_mwb_signup'] ) ? intval( $general_settings['enable_mwb_signup'] ) : 0;

				if ( $enable_mwb_signup ) {
					$mwb_signup_value                 = isset( $general_settings['mwb_signup_value'] ) ? intval( $general_settings['mwb_signup_value'] ) : 1;
					$mwb_comment_value                = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;
					$mwb_refer_value                  = isset( $general_settings['mwb_refer_value'] ) ? intval( $general_settings['mwb_refer_value'] ) : 1;
					$mwb_per_currency_spent_value     = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) ? intval( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) : 1;
					$today_date                       = date_i18n( 'Y-m-d h:i:sa' );
					$points_details['registration'][] = array(
						'registration' => $mwb_signup_value,
						'date'         => $today_date,
					);
					update_user_meta( $customer_id, 'mwb_wpr_points', $mwb_signup_value );
					update_user_meta( $customer_id, 'points_details', $points_details );
					$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
					if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
						$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
						$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_signup_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_signup_email_subject'] : '';
						$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_signup_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_signup_email_discription_custom_id'] : '';
						$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_signup_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription  = str_replace( '[Total Points]', $mwb_signup_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription  = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription  = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
						$user                       = get_user_by( 'email', $new_customer_data['user_email'] );
						$user_name                  = $user->user_firstname;
						$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
						if ( $mwb_wpr_notificatin_enable ) {
							$headers = array( 'Content-Type: text/html; charset=UTF-8' );
							wc_mail( $new_customer_data['user_email'], $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
						}
					}
				} else {
					update_option( 'mwb_wpr_user_imported', false );
					update_user_meta( $customer_id, 'mwb_wpr_signup', 'disable' );
				}
				$enable_mwb_refer  = isset( $general_settings['enable_mwb_refer'] ) ? intval( $general_settings['enable_mwb_refer'] ) : 0;
				$mwb_comment_value = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;

				$mwb_per_currency_spent_value = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) ? intval( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) : 1;
				$mwb_refer_value              = isset( $general_settings['mwb_refer_value'] ) ? intval( $general_settings['mwb_refer_value'] ) : 1;
				$mwb_refer_min                = isset( $general_settings['mwb_refer_min'] ) ? intval( $general_settings['mwb_refer_min'] ) : 1;
				$mwb_referral_purchase_enable = isset( $general_settings['mwb_referral_purchase_enable'] ) ? intval( $general_settings['mwb_referral_purchase_enable'] ) : 0;
				$mwb_refer_value_disable      = isset( $general_settings['mwb_wpr_general_refer_value_disable'] ) ? intval( $general_settings['mwb_wpr_general_refer_value_disable'] ) : 0;

				if ( $enable_mwb_refer ) {
					$cookie_val   = isset( $_COOKIE['mwb_wpr_cookie_set'] ) ? sanitize_text_field( wp_unslash( $_COOKIE['mwb_wpr_cookie_set'] ) ) : '';
					$retrive_data = $cookie_val;
					if ( ! empty( $retrive_data ) ) {
						$args['meta_query'] = array(
							array(
								'key'     => 'mwb_points_referral',
								'value'   => trim( $retrive_data ),
								'compare' => '==',
							),
						);
						$user_data          = get_users( $args );

						$user_id             = $user_data[0]->data->ID;
						$user                = get_user_by( 'ID', $user_id );
						$user_email          = $user->user_email;
						$get_referral        = get_user_meta( $user_id, 'mwb_points_referral', true );
						$get_referral_invite = get_user_meta( $user_id, 'mwb_points_referral_invite', true );

						// Custom work by MWB.
						$custom_ref_pnt = get_user_meta( $user_id, 'mwb_custom_points_referral_invite', true );
						// End of custom work.
						if ( isset( $get_referral ) && null !== $get_referral && isset( $get_referral_invite ) && null !== $get_referral_invite ) {
							if ( $get_referral_invite < $mwb_refer_min ) {
								$get_referral_invite = (int) $get_referral_invite;
								update_user_meta( $user_id, 'mwb_points_referral_invite', $get_referral_invite + 1 );
								update_user_meta( $customer_id, 'user_visit_through_link', $user_id );
								$custom_ref_pnt = (int) $custom_ref_pnt;
								update_user_meta( $user_id, 'mwb_custom_points_referral_invite', $custom_ref_pnt + 1 );
								$this->mwb_wpr_destroy_cookie();
							}
							$get_referral_invite = get_user_meta( $user_id, 'mwb_points_referral_invite', true );
							if ( $get_referral_invite == $mwb_refer_min ) {
								// As soon as user get the Points, counter will re-initialised.
								update_user_meta( $user_id, 'mwb_points_referral_invite', 0 );
								if ( ! $mwb_refer_value_disable ) {
									$today_date          = date_i18n( 'Y-m-d h:i:sa' );
									$get_points          = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
									$get_referral_detail = get_user_meta( $user_id, 'points_details', true );
									if ( isset( $get_referral_detail['reference_details'] ) && ! empty( $get_referral_detail['reference_details'] ) ) {
										$custom_array                               = array(
											'reference_details' => $mwb_refer_value,
											'date'         => $today_date,
											'refered_user' => $customer_id,
										);
										$get_referral_detail['reference_details'][] = $custom_array;
									} else {
										if ( ! is_array( $get_referral_detail ) ) {
											$get_referral_detail = array();
										}
										$get_referral_detail['reference_details'][] = array(
											'reference_details' => $mwb_refer_value,
											'date'         => $today_date,
											'refered_user' => $customer_id,
										);
									}
									$total_points = $get_points + $mwb_refer_value;

									update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
									update_user_meta( $user_id, 'points_details', $get_referral_detail );
									$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
									if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
										$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
										$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_email_subject'] : '';
										$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_email_discription_custom_id'] : '';
										$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_refer_value, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[Total Points]', $total_points, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );

										$mwb_wpr_email_discription = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
										$user                      = get_user_by( 'email', $user_email );
										$user_name                 = $user->user_firstname;
										$mwb_wpr_email_discription = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
										if ( $mwb_wpr_notificatin_enable ) {
											$headers = array( 'Content-Type: text/html; charset=UTF-8' );
											wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
										}
									}
								}
							}
						}
					}
				}
			}
		}

		/**
		 * Compatible with Digits Plugin
		 *
		 * @param      string $customer_id       Data.
		 * @name mwb_wpr_new_customer_digit_registered
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_new_customer_digit_registered( $customer_id ) {
			$current_user      = get_userdata( $customer_id );
			$current_user_email = $current_user->data->user_email;
			$general_settings   = get_option( 'mwb_wpr_settings_gallery', true );

			$coupon_settings_array = get_option( 'mwb_wpr_coupons_gallery', array() );
			$enable_mwb_signup     = isset( $general_settings['enable_mwb_signup'] ) ? intval( $general_settings['enable_mwb_signup'] ) : 0;

			if ( $enable_mwb_signup ) {
				$mwb_signup_value                 = isset( $general_settings['mwb_signup_value'] ) ? intval( $general_settings['mwb_signup_value'] ) : 1;
				$mwb_comment_value                = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;
				$mwb_refer_value                  = isset( $general_settings['mwb_refer_value'] ) ? intval( $general_settings['mwb_refer_value'] ) : 1;
				$mwb_per_currency_spent_value     = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) ? intval( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) : 1;
				$today_date                       = date_i18n( 'Y-m-d h:i:sa' );
				$points_details['registration'][] = array(
					'registration' => $mwb_signup_value,
					'date'         => $today_date,
				);
				update_user_meta( $customer_id, 'mwb_wpr_points', $mwb_signup_value );
				update_user_meta( $customer_id, 'points_details', $points_details );
				$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
				if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
					$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
					$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_signup_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_signup_email_subject'] : '';
					$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_signup_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_signup_email_discription_custom_id'] : '';
					$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_signup_value, $mwb_wpr_email_discription );
					$mwb_wpr_email_discription  = str_replace( '[Total Points]', $mwb_signup_value, $mwb_wpr_email_discription );
					$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );
					$mwb_wpr_email_discription  = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
					$mwb_wpr_email_discription  = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
					$user                       = get_user_by( 'email', $current_user_email );
					$user_name                  = $user->user_firstname;
					$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
					if ( $mwb_wpr_notificatin_enable ) {
						$headers = array( 'Content-Type: text/html; charset=UTF-8' );
						wc_mail( $current_user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
					}
				}
			} else {
				update_option( 'mwb_wpr_user_imported', false );
			}
			$enable_mwb_refer  = isset( $general_settings['enable_mwb_refer'] ) ? intval( $general_settings['enable_mwb_refer'] ) : 0;
			$mwb_comment_value = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;

			$mwb_per_currency_spent_value = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) ? intval( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) : 1;
			$mwb_refer_value              = isset( $general_settings['mwb_refer_value'] ) ? intval( $general_settings['mwb_refer_value'] ) : 1;
			$mwb_refer_min                = isset( $general_settings['mwb_refer_min'] ) ? intval( $general_settings['mwb_refer_min'] ) : 1;
			$mwb_referral_purchase_enable = isset( $general_settings['mwb_referral_purchase_enable'] ) ? intval( $general_settings['mwb_referral_purchase_enable'] ) : 0;
			$mwb_refer_value_disable      = isset( $general_settings['mwb_wpr_general_refer_value_disable'] ) ? intval( $general_settings['mwb_wpr_general_refer_value_disable'] ) : 0;

			if ( $enable_mwb_refer ) {
				if ( isset( $_GET['pkey'] ) && ! empty( $_GET['pkey'] ) ) {
					$args['meta_query'] = array(
						array(
							'key'     => 'mwb_points_referral',
							'value'   => trim( sanitize_text_field( wp_unslash( $_GET['pkey'] ) ) ),
							'compare' => '==',
						),
					);
					$user_data          = get_users( $args );

					$user_id             = $user_data[0]->data->ID;
					$user                = get_user_by( 'ID', $user_id );
					$user_email          = $user->user_email;
					$get_referral        = get_user_meta( $user_id, 'mwb_points_referral', true );
					$get_referral_invite = get_user_meta( $user_id, 'mwb_points_referral_invite', true );
					if ( isset( $get_referral ) && null !== $get_referral && isset( $get_referral_invite ) && null !== $get_referral_invite ) {
						if ( $get_referral_invite < $mwb_refer_min ) {
							$get_referral_invite = (int) $get_referral_invite;
							update_user_meta( $user_id, 'mwb_points_referral_invite', $get_referral_invite + 1 );
							update_user_meta( $customer_id, 'user_visit_through_link', $user_id );
						}
						$get_referral_invite = get_user_meta( $user_id, 'mwb_points_referral_invite', true );
						if ( $get_referral_invite == $mwb_refer_min ) {
							if ( ! $mwb_refer_value_disable ) {
								$today_date          = date_i18n( 'Y-m-d h:i:sa' );
								$get_points          = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
								$get_referral_detail = get_user_meta( $user_id, 'points_details', true );

								$get_referral_detail['reference_details'][] = array(
									'reference_details' => $mwb_refer_value,
									'date'              => $today_date,
								);

								$total_points = $get_points + $mwb_refer_value;

								update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
								update_user_meta( $user_id, 'points_details', $get_referral_detail );
								$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
								if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
									$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
									$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_email_subject'] : '';
									$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_referral_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_referral_email_discription_custom_id'] : '';
									$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_refer_value, $mwb_wpr_email_discription );
									$mwb_wpr_email_discription  = str_replace( '[Total Points]', $total_points, $mwb_wpr_email_discription );
									$mwb_wpr_email_discription  = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );

									$mwb_wpr_email_discription = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
									$user                      = get_user_by( 'email', $user_email );
									$user_name                 = $user->user_firstname;
									$mwb_wpr_email_discription = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
									if ( $mwb_wpr_notificatin_enable ) {
										$headers = array( 'Content-Type: text/html; charset=UTF-8' );
										wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
									}
								}
							}
						}
					}
				}
			}
		}

		/**
		 * This function will add discounted price for selected products in any     Membership Level.
		 *
		 * @param      object $price       Data.
		 * @param      object $product_data       Data.
		 * @name mwb_wpr_user_level_discount_on_price
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_user_level_discount_on_price( $price, $product_data ) {

			$today_date                = date_i18n( 'Y-m-d' );
			$user_id                   = get_current_user_ID();
			$new_price                 = '';
			$product_id                = $product_data->get_id();
			$product_is_variable       = $this->mwb_wpr_check_whether_product_is_variable( $product_data );
			$reg_price                 = $product_data->get_price();
			$prod_type                 = $product_data->get_type();
			$user_level                = get_user_meta( $user_id, 'membership_level', true );
			$mwb_wpr_mem_expr          = get_user_meta( $user_id, 'membership_expiration', true );
			$membership_settings_array = get_option( 'mwb_wpr_membership_settings', true );
			$mwb_wpr_membership_roles  = isset( $membership_settings_array['membership_roles'] ) && ! empty( $membership_settings_array['membership_roles'] ) ? $membership_settings_array['membership_roles'] : array();
			if ( isset( $user_level ) && ! empty( $user_level ) ) {
				if ( isset( $mwb_wpr_mem_expr ) && ! empty( $mwb_wpr_mem_expr ) && $today_date <= $mwb_wpr_mem_expr ) {
					if ( is_array( $mwb_wpr_membership_roles ) && ! empty( $mwb_wpr_membership_roles ) ) {
						foreach ( $mwb_wpr_membership_roles as $roles => $values ) {

							if ( $user_level == $roles ) {
								if ( is_array( $values['Product'] ) && ! empty( $values['Product'] ) ) {
									if ( in_array( $product_id, $values['Product'] ) && ! $product_is_variable && ! $this->check_exclude_sale_products( $product_data ) ) {
										$new_price = $reg_price - ( $reg_price * $values['Discount'] ) / 100;
										$price     = '<del>' . wc_price( $reg_price ) . $product_data->get_price_suffix() . '</del><ins>' . wc_price( $new_price ) . $product_data->get_price_suffix() . '</ins>';
									}
								} elseif ( ! $this->check_exclude_sale_products( $product_data ) ) {
									$terms = get_the_terms( $product_id, 'product_cat' );
									if ( is_array( $terms ) && ! empty( $terms ) && ! $product_is_variable ) {
										foreach ( $terms as $term ) {
											$cat_id     = $term->term_id;
											$parent_cat = $term->parent;
											if ( in_array( $cat_id, $values['Prod_Categ'] ) || in_array( $parent_cat, $values['Prod_Categ'] ) ) {
												if ( ! empty( $reg_price ) ) {

													$new_price = $reg_price - ( $reg_price * $values['Discount'] ) / 100;
													$price     = '<del>' . wc_price( $reg_price ) . $product_data->get_price_suffix() . '</del><ins>' . wc_price( $new_price ) . $product_data->get_price_suffix() . '</ins>';
												}
											}
										}
									}
								}
							}
						}
					}
				}
			}
			// MWB CUSTOM WORK.
			$enable_product_purchase_points = get_post_meta( $product_id, 'mwb_product_purchase_points_only', true );
			$mwb_product_purchase_value     = get_post_meta( $product_id, 'mwb_points_product_purchase_value', true );

			if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {
				if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) && ( 'simple' === $prod_type ) ) {
					$price = $mwb_product_purchase_value . ' Points';
				}
			}
			// END OF CUSTOM WORK.
			return $price;
		}

		/**
		 * This function will add discounted price in cart page.
		 *
		 * @param      object $cart       Data.
		 * @name mwb_wpr_woocommerce_before_calculate_totals
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_before_calculate_totals( $cart ) {
			global $woocommerce;
			$woo_ver                        = WC()->version;
			$user_id                        = get_current_user_ID();
			$new_price                      = '';
			$today_date                     = date_i18n( 'Y-m-d' );
			$user_level                     = get_user_meta( $user_id, 'membership_level', true );
			$mwb_wpr_mem_expr               = get_user_meta( $user_id, 'membership_expiration', true );
			$get_points                     = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			$membership_settings_array      = get_option( 'mwb_wpr_membership_settings', true );
			$mwb_wpr_membership_roles       = isset( $membership_settings_array['membership_roles'] ) && ! empty( $membership_settings_array['membership_roles'] ) ? $membership_settings_array['membership_roles'] : array();
			$general_settings               = get_option( 'mwb_wpr_settings_gallery', true );

			// MWB Custom Work.
			$user       = wp_get_current_user();
			$user_id    = $user->ID;
			$get_points = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );

			// End of Custom Work.
			foreach ( $cart->cart_contents as $key => $value ) {
				if ( isset( $value ) ) {
					$product_id = $value['product_id'];
					$pro_quant  = $value['quantity'];
					$_product   = wc_get_product( $product_id );
					// ===== Custom work==========
					$enable_product_purchase_points = get_post_meta( $product_id, 'mwb_product_purchase_points_only', true );
					$mwb_product_purchase_value     = get_post_meta( $product_id, 'mwb_points_product_purchase_value', true );
					$user                           = wp_get_current_user();
					$user_id                        = $user->ID;
					$get_points                     = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
					$product_type                   = $_product->get_type();
					if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {
						if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) && ( 'simple' === $product_type ) ) {

							$mwb_product_purchase_value = (int) $mwb_product_purchase_value * $pro_quant;
							if ( $mwb_product_purchase_value >= $get_points ) {

								$cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] = $get_points;
							} else {

								$cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] = $mwb_product_purchase_value;
							}
						}
					}
					// Custom Work for Variable Product.
					if ( $this->mwb_wpr_check_whether_product_is_variable( $_product ) ) {
						$mwb_wpr_parent_id              = wp_get_post_parent_id( $value['variation_id'] );
						$enable_product_purchase_points = get_post_meta( $mwb_wpr_parent_id, 'mwb_product_purchase_points_only', true );
						$mwb_product_purchase_value     = get_post_meta( $value['variation_id'], 'mwb_wpr_variable_points_purchase', true );
						if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {

							if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) ) {
								$mwb_product_purchase_value = (int) $mwb_product_purchase_value * $pro_quant;
								if ( is_user_logged_in() ) {
									if ( $mwb_product_purchase_value >= $get_points ) {

										$cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] = $get_points;
									} else {

										$cart->cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] = $mwb_product_purchase_value;
									}
								}
							}
						}
					}
					// ===== End Custom work==========
					$product_is_variable = $this->mwb_wpr_check_whether_product_is_variable( $_product );
					$reg_price           = $_product->get_price();
					if ( isset( $value['variation_id'] ) && ! empty( $value['variation_id'] ) ) {
						$variation_id     = $value['variation_id'];
						$variable_product = wc_get_product( $variation_id );
						$variable_price   = $variable_product->get_price();
					}
					if ( isset( $mwb_wpr_mem_expr ) && ! empty( $mwb_wpr_mem_expr ) && $today_date <= $mwb_wpr_mem_expr ) {
						if ( 'on' == get_option( 'exclude_membership_discount_on_coupon' ) ) {
							if ( isset( $user_level ) && ! empty( $user_level ) && empty( $woocommerce->cart->applied_coupons ) ) {
								foreach ( $mwb_wpr_membership_roles as $roles => $values ) {
									if ( $user_level == $roles ) {
										if ( is_array( $values['Product'] ) && ! empty( $values['Product'] ) ) {
											if ( in_array( $product_id, $values['Product'] ) && ! $this->check_exclude_sale_products( $_product ) ) {
												if ( ! $product_is_variable ) {
													$new_price = $reg_price - ( $reg_price * $values['Discount'] ) / 100;
													if ( $woo_ver < '3.0.0' ) {
														$value['data']->price = $new_price;
													} else {
														$value['data']->set_price( $new_price );
													}
												} elseif ( $product_is_variable ) {
													$new_price = $variable_price - ( $variable_price * $values['Discount'] ) / 100;
													if ( $woo_ver < '3.0.0' ) {
														$value['data']->price = $new_price;
													} else {
														$value['data']->set_price( $new_price );
													}
												}
											}
										} elseif ( ! $this->check_exclude_sale_products( $_product ) ) {
											$terms = get_the_terms( $product_id, 'product_cat' );
											if ( is_array( $terms ) && ! empty( $terms ) ) {
												foreach ( $terms as $term ) {
													$cat_id     = $term->term_id;
													$parent_cat = $term->parent;
													if ( in_array( $cat_id, $values['Prod_Categ'] ) || in_array( $parent_cat, $values['Prod_Categ'] ) ) {
														if ( ! $product_is_variable ) {
															$new_price = $reg_price - ( $reg_price * $values['Discount'] ) / 100;
															if ( $woo_ver < '3.0.0' ) {
																$value['data']->price = $new_price;
															} else {
																$value['data']->set_price( $new_price );
															}
														} elseif ( $product_is_variable ) {
															$new_price = $variable_price - ( $variable_price * $values['Discount'] ) / 100;
															if ( $woo_ver < '3.0.0' ) {
																$value['data']->price = $new_price;
															} else {
																$value['data']->set_price( $new_price );
															}
														}
													}
												}
											}
										}
									}
								}
							}
						} else {
							if ( isset( $user_level ) && ! empty( $user_level ) ) {
								foreach ( $mwb_wpr_membership_roles as $roles => $values ) {
									if ( $user_level == $roles ) {
										if ( is_array( $values['Product'] ) && ! empty( $values['Product'] ) ) {
											if ( in_array( $product_id, $values['Product'] ) && ! $this->check_exclude_sale_products( $_product ) ) {
												if ( ! $product_is_variable ) {
													$new_price = $reg_price - ( $reg_price * $values['Discount'] ) / 100;
													if ( $woo_ver < '3.0.0' ) {
														$value['data']->price = $new_price;
													} else {
														$value['data']->set_price( $new_price );
													}
												} elseif ( $product_is_variable ) {
													$new_price = $variable_price - ( $variable_price * $values['Discount'] ) / 100;
													if ( $woo_ver < '3.0.0' ) {
														$value['data']->price = $new_price;
													} else {
														$value['data']->set_price( $new_price );
													}
												}
											}
										} elseif ( ! $this->check_exclude_sale_products( $_product ) ) {
											$terms = get_the_terms( $product_id, 'product_cat' );
											if ( is_array( $terms ) && ! empty( $terms ) ) {
												foreach ( $terms as $term ) {
													$cat_id     = $term->term_id;
													$parent_cat = $term->parent;
													if ( in_array( $cat_id, $values['Prod_Categ'] ) || in_array( $parent_cat, $values['Prod_Categ'] ) ) {
														if ( ! $product_is_variable ) {
															$new_price = $reg_price - ( $reg_price * $values['Discount'] ) / 100;
															if ( $woo_ver < '3.0.0' ) {
																$value['data']->price = $new_price;
															} else {
																$value['data']->set_price( $new_price );
															}
														} elseif ( $product_is_variable ) {
															$new_price = $variable_price - ( $variable_price * $values['Discount'] ) / 100;
															if ( $woo_ver < '3.0.0' ) {
																$value['data']->price = $new_price;
															} else {
																$value['data']->set_price( $new_price );
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
					// MWB Custom Work.
					$enable_product_purchase_points = get_post_meta( $product_id, 'mwb_product_purchase_points_only', true );
					$mwb_product_purchase_value     = get_post_meta( $product_id, 'mwb_points_product_purchase_value', true );
					if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points && ! empty( $enable_product_purchase_points ) ) {
						if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) && ( 'simple' === $product_type ) ) {

							$mwb_product_purchase_value = (int) $mwb_product_purchase_value * $pro_quant;
							if ( is_user_logged_in() ) {
								if ( $get_points >= $mwb_product_purchase_value ) {
									$value['data']->set_price( 0 );
								}
							}
						}
					}
					if ( $this->mwb_wpr_check_whether_product_is_variable( $_product ) ) {

						$mwb_wpr_parent_id              = wp_get_post_parent_id( $variation_id );
						$enable_product_purchase_points = get_post_meta( $mwb_wpr_parent_id, 'mwb_product_purchase_points_only', true );
						$mwb_product_purchase_value     = get_post_meta( $variation_id, 'mwb_wpr_variable_points_purchase', true );
						if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {
							if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) ) {

								$mwb_product_purchase_value = (int) $mwb_product_purchase_value * $pro_quant;
								if ( is_user_logged_in() ) {
									if ( $get_points >= $mwb_product_purchase_value ) {
										$value['data']->set_price( 0 );
									}
								}
							}
						}
					}
				}
			}
		}

		/**
		 * This function will add checkbox for purchase the products through points
		 *
		 * @param      object $product       Data.
		 * @name mwb_wpr_woocommerce_before_add_to_cart_button
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_before_add_to_cart_button( $product ) {
			global $product;
			$mwb_wpr_notification_color = get_option( 'mwb_wpr_notification_color', '#55b3a5' );
			$woo_ver                    = WC()->version;

			if ( $woo_ver < '3.0.0' ) {
				$product_id = $product->id;
			} else {
				$product_id = $product->get_id();
			}

			// if purchase through points only enable for this product than return from here.
			if ( 'yes' === get_post_meta( $product_id, 'mwb_product_purchase_points_only', true ) ) {
				
				return;
			}

			$today_date    = date_i18n( 'Y-m-d' );
			$check_disbale = get_post_meta( $product_id, 'mwb_product_purchase_through_point_disable', 'no' );
			if ( empty( $check_disbale ) ) {
				$check_disbale = 'no';
			}

			$_product                       = $product;
			$product_is_variable            = $this->mwb_wpr_check_whether_product_is_variable( $_product );
			$price                          = $_product->get_price();
			$user_ID                        = get_current_user_ID();
			$get_points                     = (int) get_user_meta( $user_ID, 'mwb_wpr_points', true );
			$user_level                     = get_user_meta( $user_ID, 'membership_level', true );
			$mwb_wpr_mem_expr               = get_user_meta( $user_ID, 'membership_expiration', true );
			$general_settings               = get_option( 'mwb_wpr_settings_gallery', true );
			$enable_purchase_points         = isset( $general_settings['enable_purchase_points'] ) ? intval( $general_settings['enable_purchase_points'] ) : 0;
			$mwb_wpr_restrict_pro_by_points = isset( $general_settings['mwb_wpr_restrict_pro_by_points'] ) ? intval( $general_settings['mwb_wpr_restrict_pro_by_points'] ) : 0;
			$mwb_wpr_purchase_product_text  = isset( $general_settings['mwb_wpr_purchase_product_text'] ) ? $general_settings['mwb_wpr_purchase_product_text'] : __( 'Use your Points for purchasing this Product', 'woocommerce-ultimate-points-and-rewards' );
			$mwb_wpr_purchase_points        = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
			$new_price                      = 1;
			$mwb_wpr_product_purchase_price = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
			$membership_settings_array      = get_option( 'mwb_wpr_membership_settings', true );
			$mwb_wpr_membership_roles       = isset( $membership_settings_array['membership_roles'] ) && ! empty( $membership_settings_array['membership_roles'] ) ? $membership_settings_array['membership_roles'] : array();
			$mwb_wpr_categ_list             = is_array( $general_settings['mwb_wpr_restrictions_for_purchasing_cat'] ) && ! empty( $general_settings['mwb_wpr_restrictions_for_purchasing_cat'] ) ? $general_settings['mwb_wpr_restrictions_for_purchasing_cat'] : array();
			if ( $enable_purchase_points && ! $product_is_variable ) {
				if ( ! $mwb_wpr_restrict_pro_by_points && 'no' === $check_disbale ) {
					if ( isset( $user_level ) && ! empty( $user_level ) ) {
						if ( isset( $mwb_wpr_mem_expr ) && ! empty( $mwb_wpr_mem_expr ) && $today_date <= $mwb_wpr_mem_expr ) {
							if ( is_array( $mwb_wpr_membership_roles[ $user_level ] ) && ! empty( $mwb_wpr_membership_roles[ $user_level ] ) ) {
								if ( is_array( $mwb_wpr_membership_roles[ $user_level ]['Product'] ) && ! empty( $mwb_wpr_membership_roles[ $user_level ]['Product'] ) ) {
									if ( in_array( $product_id, $mwb_wpr_membership_roles[ $user_level ]['Product'] ) && ! $this->check_exclude_sale_products( $_product ) ) {
										$new_price = $price - ( $price * $mwb_wpr_membership_roles[ $user_level ]['Discount'] ) / 100;
									} else {
										$new_price = $_product->get_price();
									}
								} else {
									$terms = get_the_terms( $product_id, 'product_cat' );
									if ( is_array( $terms ) && ! empty( $terms ) ) {
										foreach ( $terms as $term ) {
											$cat_id     = $term->term_id;
											$parent_cat = $term->parent;
											if ( ( in_array( $cat_id, $mwb_wpr_membership_roles[ $user_level ]['Prod_Categ'] ) || in_array( $parent_cat, $mwb_wpr_membership_roles[ $user_level ]['Prod_Categ'] ) ) && ! $this->check_exclude_sale_products( $_product ) ) {
												$new_price = $price - ( $price * $mwb_wpr_membership_roles[ $user_level ]['Discount'] ) / 100;
												break;
											} else {
												$new_price = $_product->get_price();
											}
										}
									}
								}
								$points_calculation = ceil( ( $new_price * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price );
								$points_calculation = apply_filters( 'mwb_par_convert_base_price_diffrent_currency', $points_calculation );
								if ( $points_calculation <= $get_points ) {
									?>
										
									<label for="mwb_wpr_pro_cost_to_points">
										<input type="checkbox" name="mwb_wpr_pro_cost_to_points" id="mwb_wpr_pro_cost_to_points" class="input-text" value="<?php echo esc_attr( $points_calculation ); ?>"> <?php echo esc_attr( $mwb_wpr_purchase_product_text ); ?>
									</label>
									<?php $nonce = wp_create_nonce( 'custom-action' ); ?>
									<input type="hidden" name="message-send" value="<?php echo esc_attr( $nonce ); ?>" />
									<input type="hidden" name="mwb_wpr_hidden_points" class="mwb_wpr_hidden_points" value="<?php echo esc_attr( $points_calculation ); ?>">
									<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
										<?php
										esc_attr_e( 'Spend', 'woocommerce-ultimate-points-and-rewards' );
										echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $points_calculation ) . '</span>';
										esc_attr_e( ' Points for Purchasing this Product for Single Quantity', 'woocommerce-ultimate-points-and-rewards' );
										?>
									</p>
									<span class="mwb_wpr_notice"></span>
									<div class="mwb_wpr_enter_some_points" style="display: none;">
										<input type="number" name="mwb_wpr_some_custom_points" id="mwb_wpr_some_custom_points" value="<?php echo esc_attr( $points_calculation ); ?>">
									</div>
									<?php
								} else {
									$extra_need = $points_calculation - $get_points;
									?>

									<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
										<?php
										esc_attr_e( 'You need extra ', 'woocommerce-ultimate-points-and-rewards' );
										echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $extra_need ) . '</span>';
										esc_attr_e( ' Points for get this product for free', 'woocommerce-ultimate-points-and-rewards' );
										?>
									</p>
									<?php
								}
							}
						} else {
							$points_calculation = round( ( $price * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price );
							$points_calculation = apply_filters( 'mwb_par_convert_base_price_diffrent_currency', $points_calculation );
							if ( $points_calculation <= $get_points ) {
								?>
								<?php $nonce = wp_create_nonce( 'custom-action' ); ?>
								<input type="hidden" name="message-send" value="<?php echo esc_attr( $nonce ); ?>" />
								<label for="mwb_wpr_pro_cost_to_points">
									<input type="checkbox" name="mwb_wpr_pro_cost_to_points" id="mwb_wpr_pro_cost_to_points" class="input-text" value="<?php echo esc_attr( $points_calculation ); ?>"> <?php echo esc_attr( $mwb_wpr_purchase_product_text ); ?>
								</label>
								<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
									<?php
									esc_attr_e( 'Spend ', 'woocommerce-ultimate-points-and-rewards' );
									echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $points_calculation ) . '</span>';
									esc_attr_e( ' Points for Purchasing this Product for Single Quantity', 'woocommerce-ultimate-points-and-rewards' );
									?>
								</p>
								<input type="hidden" name="mwb_wpr_hidden_points" class="mwb_wpr_hidden_points" value="<?php echo esc_attr( $points_calculation ); ?>">
								<span class="mwb_wpr_notice"></span>
								<div class="mwb_wpr_enter_some_points" style="display: none;">
									<input type="number" name="mwb_wpr_some_custom_points" id="mwb_wpr_some_custom_points" value="<?php echo esc_attr( $points_calculation ); ?>">
								</div>
								<?php
							} else {
								$extra_need = $points_calculation - $get_points;
								?>
								<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
									<?php
									esc_attr_e( 'You need extra  ', 'woocommerce-ultimate-points-and-rewards' );
									echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $extra_need ) . '</span>';
									esc_attr_e( ' Points for get this product for free', 'woocommerce-ultimate-points-and-rewards' );
									?>
								</p>
								<?php
							}
						}
					} else {
						$points_calculation = round( ( $price * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price );
						$points_calculation = apply_filters( 'mwb_par_convert_base_price_diffrent_currency', $points_calculation );
						if ( $points_calculation <= $get_points ) {
							?>
							<?php $nonce = wp_create_nonce( 'custom-action' ); ?>
									<input type="hidden" name="message-send" value="<?php echo esc_attr( $nonce ); ?>" />
							<label for="mwb_wpr_pro_cost_to_points">
								<input type="checkbox" name="mwb_wpr_pro_cost_to_points" id="mwb_wpr_pro_cost_to_points" class="input-text" value="<?php echo esc_attr( $points_calculation ); ?>"> <?php echo esc_attr( $mwb_wpr_purchase_product_text ); ?>
							</label>
							<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
								<?php
								esc_attr_e( 'Spend ', 'woocommerce-ultimate-points-and-rewards' );
								echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $points_calculation ) . '</span>';
								esc_attr_e( ' Points for Purchasing this Product for Single Quantity', 'woocommerce-ultimate-points-and-rewards' );
								?>
							</p>
							<input type="hidden" name="mwb_wpr_hidden_points" class="mwb_wpr_hidden_points" value="<?php echo esc_attr( $points_calculation ); ?>">
							<span class="mwb_wpr_notice"></span>
							<div class="mwb_wpr_enter_some_points" style="display: none;">
								<input type="number" name="mwb_wpr_some_custom_points" id="mwb_wpr_some_custom_points" value="<?php echo esc_attr( $points_calculation ); ?>">
							</div>
							<?php
						} else {
							$extra_need = $points_calculation - $get_points;
							?>
							<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
								<?php
								esc_attr_e( 'You need extra  ', 'woocommerce-ultimate-points-and-rewards' );
								echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $extra_need ) . '</span>';
								esc_attr_e( ' Points for get this product for free', 'woocommerce-ultimate-points-and-rewards' );
								?>
							</p>
							<?php
						}
					}
				} else {
					if ( 'no' === $check_disbale ) {
						$terms = get_the_terms( $product_id, 'product_cat' );
						if ( is_array( $terms ) && ! empty( $terms ) ) {
							foreach ( $terms as $term ) {
								$cat_id     = $term->term_id;
								$parent_cat = $term->parent;
								if ( in_array( $cat_id, $mwb_wpr_categ_list ) || in_array( $parent_cat, $mwb_wpr_categ_list ) ) {
									if ( isset( $user_level ) && ! empty( $user_level ) ) {
										if ( isset( $mwb_wpr_mem_expr ) && ! empty( $mwb_wpr_mem_expr ) && $today_date <= $mwb_wpr_mem_expr ) {
											if ( is_array( $mwb_wpr_membership_roles[ $user_level ] ) && ! empty( $mwb_wpr_membership_roles[ $user_level ] ) ) {
												if ( is_array( $mwb_wpr_membership_roles[ $user_level ]['Product'] ) && ! empty( $mwb_wpr_membership_roles[ $user_level ]['Product'] ) ) {
													if ( in_array( $product_id, $mwb_wpr_membership_roles[ $user_level ]['Product'] ) && ! $this->check_exclude_sale_products( $_product ) ) {

														$new_price = $price - ( $price * $mwb_wpr_membership_roles[ $user_level ]['Discount'] ) / 100;
													} else {
														$new_price = $_product->get_price();
													}
												} else {
													$terms = get_the_terms( $product_id, 'product_cat' );
													if ( is_array( $terms ) && ! empty( $terms ) ) {
														foreach ( $terms as $term ) {
															$cat_id     = $term->term_id;
															$parent_cat = $term->parent;
															if ( ( in_array( $cat_id, $mwb_wpr_membership_roles[ $user_level ]['Prod_Categ'] ) || in_array( $parent_cat, $mwb_wpr_membership_roles[ $user_level ]['Prod_Categ'] ) ) && ! $this->check_exclude_sale_products( $_product ) ) {
																$new_price = $price - ( $price * $mwb_wpr_membership_roles[ $user_level ]['Discount'] ) / 100;
																break;
															} else {
																$new_price = $_product->get_price();
															}
														}
													}
												}
												$points_calculation = round( ( $new_price * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price );
												$points_calculation = apply_filters( 'mwb_par_convert_base_price_diffrent_currency', $points_calculation );
												if ( $points_calculation <= $get_points ) {

													?>
													<label for="mwb_wpr_pro_cost_to_points">
														<input type="checkbox" name="mwb_wpr_pro_cost_to_points" id="mwb_wpr_pro_cost_to_points" class="input-text" value="<?php echo esc_attr( $points_calculation ); ?>"> <?php echo esc_attr( $mwb_wpr_purchase_product_text ); ?>
														<?php $nonce = wp_create_nonce( 'custom-action' ); ?>
														<input type="hidden" name="message-send" value="<?php echo esc_attr( $nonce ); ?>" />
													</label>
													<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
														<?php
														esc_attr_e( 'Spend ', 'woocommerce-ultimate-points-and-rewards' );
														echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $points_calculation ) . '</span>';
														esc_attr_e( ' Points for Purchasing this Product for Single Quantity', 'woocommerce-ultimate-points-and-rewards' );
														?>
													</p>
													<input type="hidden" name="mwb_wpr_hidden_points" class="mwb_wpr_hidden_points" value="<?php echo esc_attr( $points_calculation ); ?>">
													<span class="mwb_wpr_notice"></span>
													<div class="mwb_wpr_enter_some_points" style="display: none;">
														<input type="number" name="mwb_wpr_some_custom_points" id="mwb_wpr_some_custom_points" value="<?php echo esc_attr( $points_calculation ); ?>">
													</div>
													<?php
												} else {
													$extra_need = $points_calculation - $get_points;
													?>

													<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
														<?php
														esc_attr_e( 'You need extra ', 'woocommerce-ultimate-points-and-rewards' );
														echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $extra_need ) . '</span>';
														esc_attr_e( ' Points for get this product for free', 'woocommerce-ultimate-points-and-rewards' );
														?>
													</p>
													<?php
												}
											}
										} else {
											$points_calculation = round( ( $price * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price );
											$points_calculation = apply_filters( 'mwb_par_convert_base_price_diffrent_currency', $points_calculation );
											if ( $points_calculation <= $get_points ) {
												?>
												<label for="mwb_wpr_pro_cost_to_points">
													<input type="checkbox" name="mwb_wpr_pro_cost_to_points" id="mwb_wpr_pro_cost_to_points" class="input-text" value="<?php echo esc_attr( $points_calculation ); ?>"> <?php echo esc_attr( $mwb_wpr_purchase_product_text ); ?>
													<?php $nonce = wp_create_nonce( 'custom-action' ); ?>
													<input type="hidden" name="message-send" value="<?php echo esc_attr( $nonce ); ?>" />
												</label>
												<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
													<?php
													esc_attr_e( 'Spend ', 'woocommerce-ultimate-points-and-rewards' );
													echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $points_calculation ) . '</span>';
													esc_attr_e( ' Points for Purchasing this Product for Single Quantity', 'woocommerce-ultimate-points-and-rewards' );
													?>
												</p>
												<input type="hidden" name="mwb_wpr_hidden_points" class="mwb_wpr_hidden_points" value="<?php echo esc_attr( $points_calculation ); ?>">
												<span class="mwb_wpr_notice"></span>
												<div class="mwb_wpr_enter_some_points" style="display: none;">
													<input type="number" name="mwb_wpr_some_custom_points" id="mwb_wpr_some_custom_points" value="<?php echo esc_attr( $points_calculation ); ?>">
												</div>
												<?php
											} else {
												$extra_need = $points_calculation - $get_points;
												?>
												<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
													<?php
													esc_attr_e( 'You need extra ', 'woocommerce-ultimate-points-and-rewards' );
													echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $extra_need ) . '</span>';
													esc_attr_e( ' Points for get this product for free', 'woocommerce-ultimate-points-and-rewards' );
													?>
												</p>
												<?php
											}
										}
									} else {
										$points_calculation = round( ( $price * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price );
										$points_calculation = apply_filters( 'mwb_par_convert_base_price_diffrent_currency', $points_calculation );
										if ( $points_calculation <= $get_points ) {
											?>
											<label for="mwb_wpr_pro_cost_to_points">
												<input type="checkbox" name="mwb_wpr_pro_cost_to_points" id="mwb_wpr_pro_cost_to_points" class="input-text" value="<?php echo esc_attr( $points_calculation ); ?>"> <?php echo esc_attr( $mwb_wpr_purchase_product_text ); ?>
												<?php $nonce = wp_create_nonce( 'custom-action' ); ?>
												<input type="hidden" name="message-send" value="<?php echo esc_attr( $nonce ); ?>" />
											</label>
											<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
												<?php
												esc_attr_e( 'Spend ', 'woocommerce-ultimate-points-and-rewards' );
												echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $points_calculation ) . '</span>';
												esc_attr_e( ' Points for Purchasing this Product for Single Quantity', 'woocommerce-ultimate-points-and-rewards' );
												?>
											</p>
											<input type="hidden" name="mwb_wpr_hidden_points" class="mwb_wpr_hidden_points" value="<?php echo esc_attr( $points_calculation ); ?>">
											<span class="mwb_wpr_notice"></span>
											<div class="mwb_wpr_enter_some_points" style="display: none;">
												<input type="number" name="mwb_wpr_some_custom_points" id="mwb_wpr_some_custom_points" value="<?php echo esc_attr( $points_calculation ); ?>">
											</div>
											<?php
										} else {
											$extra_need = $points_calculation - $get_points;
											?>
											<p class="mwb_wpr_purchase_pro_point" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>;">
												<?php
												esc_attr_e( 'You need extra ', 'woocommerce-ultimate-points-and-rewards' );
												echo '<span class=mwb_wpr_when_variable_pro>' . esc_attr( $extra_need ) . '</span>';
												esc_attr_e( ' Points for get this product for free', 'woocommerce-ultimate-points-and-rewards' );
												?>
											</p>
											<?php
										}
									}
									break;
								}
							}
						}
					}
				}
			} elseif ( $enable_purchase_points && $product_is_variable ) {
				echo '<div class="mwb_wpr_variable_pro_pur_using_point" style="display: none;"></div>';
			}
		}

		/**
		 * The function for appends the required/custom message for users to let them know how many points they are going to earn/deduct
		 *
		 * @param      string $thankyou_msg       Data.
		 * @param      object $order       Data.
		 * @name mwb_wpr_woocommerce_thankyou
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_thankyou( $thankyou_msg, $order ) {
			$mwb_wpr_thnku_order_msg             = get_option( 'mwb_wpr_thnku_order_msg', false );
			$mwb_wpr_thnku_order_msg_usin_points = get_option( 'mwb_wpr_thnku_order_msg_usin_points', false );
			$item_points                         = 0;
			$purchasing_points                   = 0;
			$mwb_wpr_coupon_conversion_value     = get_option( 'mwb_wpr_coupons_gallery', array() );
			$mwb_wpr_coupon_conversion_price     = isset( $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_price'] ) ? $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_price'] : 1;
			$mwb_wpr_coupon_conversion_points    = isset( $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_points'] ) ? $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_points'] : 1;
			$order_id                            = $order->get_order_number();
			$user_id                             = $order->get_user_id();
			$get_points                          = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			foreach ( $order->get_items() as $item_id => $item ) {
				$woo_ver = WC()->version;
				if ( $woo_ver < '3.0.0' ) {
					$item_quantity = $order->get_item_meta( $item_id, '_qty', true );
					if ( isset( $item['item_meta']['Points'] ) && ! empty( $item['item_meta']['Points'] ) ) {
						$item_points   = (int) $item['item_meta']['Points'][0];
						$thankyou_msg .= $mwb_wpr_thnku_order_msg;
						$thankyou_msg  = str_replace( '[POINTS]', $item_points, $thankyou_msg );
						$thankyou_msg  = str_replace( '[TOTALPOINT]', $get_points, $thankyou_msg );
					}
					if ( isset( $item['item_meta']['Purchasing Option'] ) && ! empty( $item['item_meta']['Purchasing Option'] ) ) {
						$purchasing_points = (int) $item['item_meta']['Purchasing Option'][0] * $item_quantity;
						$thankyou_msg     .= $mwb_wpr_thnku_order_msg_usin_points;
						$thankyou_msg      = str_replace( '[POINTS]', $purchasing_points, $thankyou_msg );
						$thankyou_msg      = str_replace( '[TOTALPOINT]', $get_points, $thankyou_msg );
					}
				} else {
					$item_quantity = wc_get_order_item_meta( $item_id, '_qty', true );
					$mwb_wpr_items = $item->get_meta_data();
					foreach ( $mwb_wpr_items as $key => $mwb_wpr_value ) {
						if ( isset( $mwb_wpr_value->key ) && ! empty( $mwb_wpr_value->key ) && ( 'Points' === $mwb_wpr_value->key ) ) {
							$item_points        += (int) $mwb_wpr_value->value;
							$check_points_credit = $mwb_wpr_value->key;
						}

						if ( isset( $mwb_wpr_value->key ) && ! empty( $mwb_wpr_value->key ) && ( 'Purchasing Option' === $mwb_wpr_value->key ) ) {
							$purchasing_points += (int) $mwb_wpr_value->value * $item_quantity;
							$thankyou_msg      .= $mwb_wpr_thnku_order_msg_usin_points;
							$thankyou_msg       = str_replace( '[POINTS]', $purchasing_points, $thankyou_msg );
							$thankyou_msg       = str_replace( '[TOTALPOINT]', $get_points, $thankyou_msg );
						}
					}
				}
			}
			if ( isset( $check_points_credit ) && ! empty( $check_points_credit ) && ( 'Points' === $check_points_credit ) ) {
				$thankyou_msg .= $mwb_wpr_thnku_order_msg;
				$thankyou_msg  = str_replace( '[POINTS]', $item_points, $thankyou_msg );
				$thankyou_msg  = str_replace( '[TOTALPOINT]', $get_points, $thankyou_msg );
			}
			// hpos.
			$item_conversion_id_set = mwb_par_hpos_get_meta_data( $order_id, "$order_id#item_conversion_id", true );
			$order_total            = $order->get_total();
			$order_total            = str_replace( wc_get_price_decimal_separator(), '.', strval( $order_total ) );
			$points_calculation     = round( ( $order_total * $mwb_wpr_coupon_conversion_points ) / $mwb_wpr_coupon_conversion_price );
			if ( ! empty( $item_conversion_id_set ) && 'set' === $item_conversion_id_set ) {
				$item_points  += $points_calculation;
				$thankyou_msg .= $mwb_wpr_thnku_order_msg;
				$thankyou_msg  = str_replace( '[POINTS]', $item_points, $thankyou_msg );
				$thankyou_msg  = str_replace( '[TOTALPOINT]', $get_points, $thankyou_msg );
			}
			return $thankyou_msg;
		}

		/**
		 * The function is for let the meta keys translatable
		 *
		 * @param      string $display_key       Data.
		 * @name mwb_wpr_woocommerce_order_item_display_meta_key
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_order_item_display_meta_key( $display_key ) {
			if ( 'Points' === $display_key ) {
				$display_key = __( 'Points', 'woocommerce-ultimate-points-and-rewards' );
			}
			if ( 'Purchasing Option' === $display_key ) {
				$display_key = __( 'Purchasing Option', 'woocommerce-ultimate-points-and-rewards' );
			}
			return $display_key;
		}

		/**
		 * The function is for share the points to other member for same site
		 *
		 * @name mwb_wpr_sharing_point_to_other
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_sharing_point_to_other() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$response['result']   = false;
			$response['message']  = __( 'Error during Point Sharing. Try Again!', 'woocommerce-ultimate-points-and-rewards' );
			$value_shared_points  = isset( $_POST['shared_point'] ) ? sanitize_text_field( wp_unslash( $_POST['shared_point'] ) ) : '';
			$value_user_id        = isset( $_POST['user_id'] ) ? sanitize_text_field( wp_unslash( $_POST['user_id'] ) ) : '';
			$mwb_wpr_shared_point = (int) $value_shared_points;
			$user_id              = $value_user_id;
			$user                 = get_user_by( 'ID', $user_id );
			$sender_email         = $user->user_email;
			$value_email_id       = isset( $_REQUEST['email_id'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['email_id'] ) ) : '';
			$mwb_wpr_email        = $value_email_id;
			if ( isset( $user_id ) && ! empty( $user_id ) && isset( $mwb_wpr_shared_point ) && ! empty( $mwb_wpr_shared_point ) ) {
				if ( isset( $mwb_wpr_email ) && ! empty( $mwb_wpr_email ) ) {
					$providers_points    = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
					$mwb_wpr_receiver    = get_user_by( 'email', $mwb_wpr_email );
					$mwb_wpr_receiver_id = $mwb_wpr_receiver->data->ID;
					if ( isset( $mwb_wpr_receiver ) && ! empty( $mwb_wpr_receiver ) ) {
						if ( $providers_points >= $mwb_wpr_shared_point ) {

							$receivers_points        = (int) get_user_meta( $mwb_wpr_receiver_id, 'mwb_wpr_points', true );
							$receivers_updated_point = $receivers_points + $mwb_wpr_shared_point;
							$receiver_point_detail   = get_user_meta( $mwb_wpr_receiver_id, 'points_details', true );

							$today_date = date_i18n( 'Y-m-d h:i:sa' );

							if ( isset( $receiver_point_detail['Receiver_point_details'] ) && ! empty( $receiver_point_detail['Receiver_point_details'] ) ) {
								$receiver_array                                    = array();
								$receiver_array                                    = array(
									'Receiver_point_details' => $mwb_wpr_shared_point,
									'date'        => $today_date,
									'received_by' => $user_id,
								);
								$receiver_point_detail['Receiver_point_details'][] = $receiver_array;
							} else {
								if ( ! is_array( $receiver_point_detail ) ) {
									$receiver_point_detail = array();
								}
								$receiver_array                                    = array(
									'Receiver_point_details' => $mwb_wpr_shared_point,
									'date'        => $today_date,
									'received_by' => $user_id,
								);
								$receiver_point_detail['Receiver_point_details'][] = $receiver_array;
							}
							update_user_meta( $mwb_wpr_receiver_id, 'points_details', $receiver_point_detail );
							update_user_meta( $mwb_wpr_receiver_id, 'mwb_wpr_points', $receivers_updated_point );
							$providers_updated_point = $providers_points - $mwb_wpr_shared_point;
							$sender_point_detail     = get_user_meta( $user_id, 'points_details', true );
							if ( isset( $sender_point_detail['Sender_point_details'] ) && ! empty( $sender_point_detail['Sender_point_details'] ) ) {
								$sender_array                                  = array();
								$sender_array                                  = array(
									'Sender_point_details' => $mwb_wpr_shared_point,
									'date'                 => $today_date,
									'give_to'              => $mwb_wpr_receiver_id,
								);
								$sender_point_detail['Sender_point_details'][] = $sender_array;
							} else {
								if ( ! is_array( $sender_point_detail ) ) {
									$sender_point_detail = array();
								}
								$sender_array                                  = array(
									'Sender_point_details' => $mwb_wpr_shared_point,
									'date'                 => $today_date,
									'give_to'              => $mwb_wpr_receiver_id,
								);
								$sender_point_detail['Sender_point_details'][] = $sender_array;
							}
							update_user_meta( $user_id, 'points_details', $sender_point_detail );
							update_user_meta( $user_id, 'mwb_wpr_points', $providers_updated_point );
							$available_points          = get_user_meta( $user_id, 'mwb_wpr_points', true );
							$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
							if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
								$total_points               = $receivers_updated_point;
								$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
								$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_point_sharing_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_point_sharing_subject'] : __( 'Received Points Successfully!!', 'woocommerce-ultimate-points-and-rewards' );
								$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_point_sharing_description'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_point_sharing_description'] : __( 'You have received point [RECEIVEDPOINT]', 'woocommerce-ultimate-points-and-rewards' );
								$mwb_wpr_email_discription  = str_replace( '[RECEIVEDPOINT]', $mwb_wpr_shared_point, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[SENDEREMAIL]', $sender_email, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_points, $mwb_wpr_email_discription );
								$user                       = get_user_by( 'email', $mwb_wpr_email );
								$user_name                  = $user->user_firstname;
								$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
								if ( $mwb_wpr_notificatin_enable ) {
									$headers = array( 'Content-Type: text/html; charset=UTF-8' );
									wc_mail( $mwb_wpr_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
								}
							}
							$response['result']           = true;
							$response['message']          = __( 'Points assigned succesfuly', 'woocommerce-ultimate-points-and-rewards' );
							$response['available_points'] = $available_points;

						} else {

							$response['result']  = false;
							$response['message'] = __( 'Entered Point should be less than your Total Point', 'woocommerce-ultimate-points-and-rewards' );
						}
					} else {

						$response['result']  = false;
						$response['message'] = __( 'Please Enter Valid Email', 'woocommerce-ultimate-points-and-rewards' );
					}
				} else {

					$response['result']  = false;
					$response['message'] = __( 'Please Enter Email', 'woocommerce-ultimate-points-and-rewards' );
				}
			} else {

				$response['result']  = false;
				$response['message'] = __( 'Please fill Required fields', 'woocommerce-ultimate-points-and-rewards' );
			}
			echo json_encode( $response );
			wp_die();
		}

		/**
		 * The function is convert the points and add this to in the ofrm of Fee.
		 *
		 * @param      object $cart       Data.
		 * @name mwb_wpr_woocommerce_cart_calculate_fees
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_cart_calculate_fees( $cart ) {

			$general_settings               = get_option( 'mwb_wpr_settings_gallery', true );
			$enable_purchase_points         = isset( $general_settings['enable_purchase_points'] ) ? intval( $general_settings['enable_purchase_points'] ) : 0;
			$mwb_wpr_purchase_points        = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
			$mwb_wpr_discount_bcz_pnt       = 0;
			$mwb_wpr_pnt_fee_added          = false;
			$mwb_wpr_product_purchase_price = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
			$user_id                        = get_current_user_ID();
			$purchase__by_points_amount     = 0;
			$get_points                     = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			if ( ! empty( $cart ) ) {
				foreach ( $cart->cart_contents as $key => $value ) {
					if ( ! empty( $value ) ) {

						$pro_quant  = $value['quantity'];
						if ( $enable_purchase_points ) {

							// manage points when quantity is update.
							if ( isset( $value['product_meta']['meta_data']['pro_purchase_by_points'] ) && ! empty( $value['product_meta']['meta_data']['pro_purchase_by_points'] ) ) {
								
								$pro_mwb_pur_by_points_single_qty_val = ! empty( $value['product_meta']['meta_data']['pro_mwb_pur_by_points_single_qty_val'] ) ? $value['product_meta']['meta_data']['pro_mwb_pur_by_points_single_qty_val'] : 1;
								$pro_mwb_purchase__by_points_qty      = ! empty( $value['product_meta']['meta_data']['pro_mwb_purchase__by_points_qty'] ) ? $value['product_meta']['meta_data']['pro_mwb_purchase__by_points_qty'] : 0;
								if ( $pro_quant < $pro_mwb_purchase__by_points_qty ) {

									$purchase_by_points_qty     = $pro_mwb_purchase__by_points_qty - $pro_quant;
									$purchase__by_points_amount = (int) $pro_mwb_pur_by_points_single_qty_val * $purchase_by_points_qty;
									$purchase__by_points_amount = (int) $value['product_meta']['meta_data']['pro_purchase_by_points'] - $purchase__by_points_amount;
									$mwb_wpr_about_to_pay       = ( $purchase__by_points_amount / $mwb_wpr_purchase_points * $mwb_wpr_product_purchase_price );
								} else {

									$mwb_wpr_about_to_pay = ( $value['product_meta']['meta_data']['pro_purchase_by_points'] / $mwb_wpr_purchase_points * $mwb_wpr_product_purchase_price );
								}
								$mwb_wpr_discount_bcz_pnt = $mwb_wpr_discount_bcz_pnt + $mwb_wpr_about_to_pay;
								$mwb_wpr_pnt_fee_added    = true;
							}
						}
					}
				}

				$mwb_only_points_purchase = 0;
				if ( ! empty( WC()->cart ) && ! empty( WC()->cart->get_cart() ) ) {
					foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
						if ( isset( $cart_item['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] ) && ! empty( $cart_item['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] ) ) {

							$mwb_only_points_purchase += $cart_item['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] * $cart_item['quantity'];
						}
					}
				}

				$get_points = (int) $get_points - $mwb_only_points_purchase;

				if ( $get_points > 0 && $mwb_wpr_pnt_fee_added ) {
					// Testing.
					$convert_in_point = ( $mwb_wpr_discount_bcz_pnt * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price;
					if ( $convert_in_point > $get_points ) {

						$mwb_wpr_about_to_pay = (int) ( $get_points / $mwb_wpr_purchase_points * $mwb_wpr_product_purchase_price );

						// updating values to manage points when product purchase through points.
						update_option( 'mwb_par_check_points_discount_applied_amount', $mwb_wpr_about_to_pay );

						$mwb_wpr_about_to_pay = apply_filters( 'mwb_par_show_conversion_price', $mwb_wpr_about_to_pay );
						$cart->add_fee( 'Point Discount', -$mwb_wpr_about_to_pay, true, '' );
					} else {

						// updating values to manage points when product purchase through points.
						update_option( 'mwb_par_check_points_discount_applied_amount', $mwb_wpr_about_to_pay );

						$mwb_wpr_discount_bcz_pnt = apply_filters( 'mwb_par_show_conversion_price', $mwb_wpr_discount_bcz_pnt );
						$cart->add_fee( 'Point Discount', -$mwb_wpr_discount_bcz_pnt, true, '' );
					}
				} else {

					// updating values to manage points when product purchase through points.
					update_option( 'mwb_par_check_points_discount_applied_amount', 0 );
				}
			}
		}

		/**
		 * The function is used for append the variable point to the single product page as well as variable product support for purchased through points and for membership product
		 *
		 * @name mwb_wpr_append_variable_point
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_append_variable_point() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$response['result']                        = false;
			$response['message']                       = __( 'Error during various variation handling. Try Again!', 'woocommerce-ultimate-points-and-rewards' );
			$mwb_wpr_proceed_for_purchase_throgh_point = false;
			$points_calculation                        = '';
			$price                                     = '';
			$variation_id                              = isset( $_POST['variation_id'] ) ? sanitize_text_field( wp_unslash( $_POST['variation_id'] ) ) : '';
			$general_settings                          = get_option( 'mwb_wpr_settings_gallery', true );
			$mwb_wpr_restrict_pro_by_points            = isset( $general_settings['mwb_wpr_restrict_pro_by_points'] ) ? intval( $general_settings['mwb_wpr_restrict_pro_by_points'] ) : 0;
			$mwb_wpr_categ_list                        = is_array( $general_settings['mwb_wpr_restrictions_for_purchasing_cat'] ) && ! empty( $general_settings['mwb_wpr_restrictions_for_purchasing_cat'] ) ? $general_settings['mwb_wpr_restrictions_for_purchasing_cat'] : array();
			$user_id                                   = get_current_user_ID();
			if ( ! empty( $variation_id ) ) {
				$user_level                     = get_user_meta( $user_id, 'membership_level', true );
				$get_points                     = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
				$mwb_wpr_mem_expr               = get_user_meta( $user_id, 'membership_expiration', true );
				$membership_settings_array      = get_option( 'mwb_wpr_membership_settings', true );
				$mwb_wpr_membership_roles       = isset( $membership_settings_array['membership_roles'] ) && ! empty( $membership_settings_array['membership_roles'] ) ? $membership_settings_array['membership_roles'] : array();
				$today_date                     = date_i18n( 'Y-m-d' );
				$mwb_wpr_purchase_product_text  = isset( $general_settings['mwb_wpr_purchase_product_text'] ) ? $general_settings['mwb_wpr_purchase_product_text'] : __( 'Use your Points for purchasing this Product', 'woocommerce-ultimate-points-and-rewards' );
				$mwb_wpr_parent_id              = wp_get_post_parent_id( $variation_id );
				$general_settings               = get_option( 'mwb_wpr_settings_gallery', true );
				$enable_purchase_points         = isset( $general_settings['enable_purchase_points'] ) ? intval( $general_settings['enable_purchase_points'] ) : 0;
				$mwb_wpr_purchase_points        = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
				$new_price                      = 1;
				$mwb_wpr_product_purchase_price = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
				$mwb_wpr_restrict_pro_by_points = isset( $general_settings['mwb_wpr_restrict_pro_by_points'] ) ? intval( $general_settings['mwb_wpr_restrict_pro_by_points'] ) : 0;
				if ( ! empty( $mwb_wpr_parent_id ) && $mwb_wpr_parent_id > 0 ) {
					$check_enable  = get_post_meta( $mwb_wpr_parent_id, 'mwb_product_points_enable', 'no' );
					$check_disbale = get_post_meta( $mwb_wpr_parent_id, 'mwb_product_purchase_through_point_disable', 'no' );
					if ( empty( $check_disbale ) ) {
						$check_disbale = 'no';
					}
					if ( 'yes' === $check_enable ) {
						$mwb_wpr_variable_points = (int) get_post_meta( $variation_id, 'mwb_wpr_variable_points', true );
						if ( $mwb_wpr_variable_points > 0 ) {
							$response['result']          = true;
							$response['variable_points'] = $mwb_wpr_variable_points;
							$response['message']         = __( 'Successfully Assigned!', 'woocommerce-ultimate-points-and-rewards' );
						}
					}
					if ( $enable_purchase_points ) {
						if ( $mwb_wpr_restrict_pro_by_points ) {
							$terms = get_the_terms( $mwb_wpr_parent_id, 'product_cat' );
							if ( is_array( $terms ) && ! empty( $terms ) ) {
								foreach ( $terms as $term ) {
									$cat_id     = $term->term_id;
									$parent_cat = $term->parent;
									if ( isset( $mwb_wpr_categ_list ) && ! empty( $mwb_wpr_categ_list ) ) {
										if ( in_array( $cat_id, $mwb_wpr_categ_list ) || in_array( $parent_cat, $mwb_wpr_categ_list ) ) {
											$mwb_wpr_proceed_for_purchase_throgh_point = true;
											break;
										}
									} else {
										$mwb_wpr_proceed_for_purchase_throgh_point = false;
									}
								}
							}
						} else {
							$mwb_wpr_proceed_for_purchase_throgh_point = true;
						}
					}

					$variable_product = wc_get_product( $variation_id );
					$variable_price   = $variable_product->get_regular_price();
					$membership_settings_array = get_option( 'mwb_wpr_membership_settings', true );
					$exclude_sale_product      = isset( $membership_settings_array['exclude_sale_product'] ) ? intval( $membership_settings_array['exclude_sale_product'] ) : 0;
					$exclude = false;

					if ( $exclude_sale_product && $variable_product->is_on_sale() ) {
						$exclude = true;
					} else {
						$exclude = false;
					}
					$sale_price = $variable_product->get_sale_price();
					if ( isset( $user_level ) && ! empty( $user_level ) ) {
						if ( isset( $mwb_wpr_mem_expr ) && ! empty( $mwb_wpr_mem_expr ) && $today_date <= $mwb_wpr_mem_expr ) {
							if ( is_array( $mwb_wpr_membership_roles ) && ! empty( $mwb_wpr_membership_roles ) ) {
								foreach ( $mwb_wpr_membership_roles as $roles => $values ) {
									if ( $user_level == $roles ) {
										if ( true == $exclude ) {
											if ( true == $exclude ) {
												$new_price          = $sale_price;
												$price              = '<span class="price"><del><span class="woocommerce-Price-amount amount">' . wc_price( $variable_price ) . '</del> <ins><span class="woocommerce-Price-amount amount">' . wc_price( $new_price ) . '</span></ins></span>';
												$points_calculation = ceil( ( $new_price * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price );
											}
											$response['result_price']        = 'html';
											$response['variable_price_html'] = $price;
											$mwb_wpr_variable_pro_pur_pnt    = '<label for="mwb_wpr_pro_cost_to_points"><input type="checkbox" name="mwb_wpr_pro_cost_to_points" id="mwb_wpr_pro_cost_to_points" class="input-text" value="' . esc_attr( $points_calculation ) . '">' . esc_attr( $mwb_wpr_purchase_product_text ) . '</label><input type="hidden" name="mwb_wpr_hidden_points" class="mwb_wpr_hidden_points" value="' . esc_attr( $points_calculation ) . '"><p class="mwb_wpr_purchase_pro_point">' . __( 'Spend ', 'woocommerce-ultimate-points-and-rewards' ) . esc_attr( $points_calculation ) . __( ' Points for Purchasing this Product for Single Quantity', 'woocommerce-ultimate-points-and-rewards' ) . '</p><span class="mwb_wpr_notice"></span><div class="mwb_wpr_enter_some_points" style="display: none;"><input type="number" name="mwb_wpr_some_custom_points" id="mwb_wpr_some_custom_points" value="' . esc_attr( $points_calculation ) . '"></div>';
											if ( $enable_purchase_points && $mwb_wpr_proceed_for_purchase_throgh_point && 'no' === $check_disbale ) {
												if ( $get_points >= $points_calculation ) {
													$response['result_point']             = 'product_purchased_using_point';
													$response['variable_points_cal_html'] = $mwb_wpr_variable_pro_pur_pnt;
												} elseif ( $points_calculation > $get_points ) {
													$extra_need                           = $points_calculation - $get_points;
													$mwb_wpr_variable_pro_pur_pnt         = '<p class="mwb_wpr_purchase_pro_point">' . __( 'You need extra ', 'woocommerce-ultimate-points-and-rewards' ) . esc_attr( $extra_need ) . __( ' Points for get this product for free', 'woocommerce-ultimate-points-and-rewards' ) . '</p>';
													$response['result_point']             = 'product_purchased_using_point';
													$response['variable_points_cal_html'] = $mwb_wpr_variable_pro_pur_pnt;
												}
											}
										} elseif ( ! $this->check_exclude_sale_products( $variable_product ) ) {
											$terms = get_the_terms( $mwb_wpr_parent_id, 'product_cat' );
											if ( is_array( $terms ) && ! empty( $terms ) ) {
												foreach ( $terms as $term ) {
													$cat_id     = $term->term_id;
													$parent_cat = $term->parent;
													if ( in_array( $cat_id, $values['Prod_Categ'] ) || in_array( $parent_cat, $values['Prod_Categ'] ) ) {
														$new_price          = $variable_price - ( $variable_price * $values['Discount'] ) / 100;
														$price              = '<span class="price"><del><span class="woocommerce-Price-amount amount">' . wc_price( $variable_price ) . '</del> <ins><span class="woocommerce-Price-amount amount">' . wc_price( $new_price ) . '</span></ins></span>';
														$points_calculation = ceil( ( $new_price * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price );

														$response['result_price']        = 'html';
														$response['variable_price_html'] = $price;
														$mwb_wpr_variable_pro_pur_pnt    = '<label for="mwb_wpr_pro_cost_to_points"><input type="checkbox" name="mwb_wpr_pro_cost_to_points" id="mwb_wpr_pro_cost_to_points" class="input-text" value="' . esc_attr( $points_calculation ) . '">' . esc_attr( $mwb_wpr_purchase_product_text ) . '</label><input type="hidden" name="mwb_wpr_hidden_points" class="mwb_wpr_hidden_points" value="' . esc_attr( $points_calculation ) . '"><p class="mwb_wpr_purchase_pro_point">' . __( 'Spend ', 'woocommerce-ultimate-points-and-rewards' ) . esc_attr( $points_calculation ) . __( ' Points for Purchasing this Product for Single Quantity', 'woocommerce-ultimate-points-and-rewards' ) . '</p><span class="mwb_wpr_notice"></span><div class="mwb_wpr_enter_some_points" style="display: none;"><input type="number" name="mwb_wpr_some_custom_points" id="mwb_wpr_some_custom_points" value="' . esc_attr( $points_calculation ) . '"></div>';
														if ( $enable_purchase_points && $mwb_wpr_proceed_for_purchase_throgh_point && 'no' === $check_disbale ) {
															if ( $get_points >= $points_calculation ) {
																$response['result_point']             = 'product_purchased_using_point';
																$response['variable_points_cal_html'] = $mwb_wpr_variable_pro_pur_pnt;
															} elseif ( $enable_purchase_points && $points_calculation > $get_points ) {
																$extra_need                           = $points_calculation - $get_points;
																$mwb_wpr_variable_pro_pur_pnt         = '<p class="mwb_wpr_purchase_pro_point">' . __( 'You need extra ', 'woocommerce-ultimate-points-and-rewards' ) . esc_attr( $extra_need ) . __( ' Points for get this product for free', 'woocommerce-ultimate-points-and-rewards' ) . '</p>';
																$response['result_point']             = 'product_purchased_using_point';
																$response['variable_points_cal_html'] = $mwb_wpr_variable_pro_pur_pnt;
															}
														}
														break;
													}
												}
											}
										}
									}
								}
							}
						}
					} else {
						$points_calculation           = round( ( $variable_price * $mwb_wpr_purchase_points ) / $mwb_wpr_product_purchase_price );
						$mwb_wpr_variable_pro_pur_pnt = '<label for="mwb_wpr_pro_cost_to_points"><input type="checkbox" name="mwb_wpr_pro_cost_to_points" id="mwb_wpr_pro_cost_to_points" class="input-text" value="' . esc_attr( $points_calculation ) . '">' . esc_attr( $mwb_wpr_purchase_product_text ) . '</label><input type="hidden" name="mwb_wpr_hidden_points" class="mwb_wpr_hidden_points" value="' . esc_attr( $points_calculation ) . '"><p class="mwb_wpr_purchase_pro_point">' . __( 'Spend ', 'woocommerce-ultimate-points-and-rewards' ) . esc_attr( $points_calculation ) . __( ' Points for Purchasing this Product for Single Quantity', 'woocommerce-ultimate-points-and-rewards' ) . '</p><span class="mwb_wpr_notice"></span><div class="mwb_wpr_enter_some_points" style="display: none;"><input type="number" name="mwb_wpr_some_custom_points" id="mwb_wpr_some_custom_points" value="' . esc_attr( $points_calculation ) . '"></div>';
						if ( $enable_purchase_points && $mwb_wpr_proceed_for_purchase_throgh_point && 'no' === $check_disbale ) {
							if ( $get_points >= $points_calculation ) {
								$response['result_point']             = 'product_purchased_using_point';
								$response['variable_points_cal_html'] = $mwb_wpr_variable_pro_pur_pnt;
							} elseif ( $points_calculation > $get_points ) {
								$extra_need                           = $points_calculation - $get_points;
								$mwb_wpr_variable_pro_pur_pnt         = '<p class="mwb_wpr_purchase_pro_point">' . __( 'You need extra ', 'woocommerce-ultimate-points-and-rewards' ) . esc_attr( $extra_need ) . __( ' Points for get this product for free', 'woocommerce-ultimate-points-and-rewards' ) . '</p>';
								$response['result_point']             = 'product_purchased_using_point';
								$response['variable_points_cal_html'] = $mwb_wpr_variable_pro_pur_pnt;
							}
						}
					}
				}

				// MWB CUSTOM CODE.
				$enable_product_purchase_points = get_post_meta( $mwb_wpr_parent_id, 'mwb_product_purchase_points_only', true );
				$mwb_product_purchase_value     = get_post_meta( $variation_id, 'mwb_wpr_variable_points_purchase', true );

				if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {
					if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) ) {

						$response['purchase_pro_pnts_only'] = 'purchased_pro_points';
						$response['price_html']             = $mwb_product_purchase_value;

					}
				}
				// END OF MWB CUSTOM CODE.
			}
			echo json_encode( $response );
			wp_die();
		}

		/**
		 * WooCommerce Ultimate Points And Rewards.
		 *
		 * @since 1.0.0
		 */
		public function mwb_pro_purchase_points_only() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$response['result']             = false;
			$response['message']            = __( 'Error during various variation handling. Try Again!', 'woocommerce-ultimate-points-and-rewards' );
			$variation_id                   = isset( $_POST['variation_id'] ) ? sanitize_text_field( wp_unslash( $_POST['variation_id'] ) ) : '';
			$mwb_wpr_parent_id              = wp_get_post_parent_id( $variation_id );
			$enable_product_purchase_points = get_post_meta( $mwb_wpr_parent_id, 'mwb_product_purchase_points_only', true );
			$mwb_product_purchase_value     = get_post_meta( $variation_id, 'mwb_wpr_variable_points_purchase', true );

			if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {
				if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) ) {
					$response['result']                 = true;
					$response['purchase_pro_pnts_only'] = 'purchased_pro_points';
					$response['price_html']             = $mwb_product_purchase_value;
				}
			}
			echo json_encode( $response );
			wp_die();
		}

		/**
		 * The function is used for checking the product is variable or not?
		 *
		 * @param      object $product       Data.
		 * @name mwb_wpr_check_whether_product_is_variable
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_check_whether_product_is_variable( $product ) {
			if ( isset( $product ) && ! empty( $product ) ) {
				if ( $product->is_type( 'variable' ) && $product->has_child() ) {
					return true;
				} else {
					return false;
				}
			}
		}

		/**
		 * The function is used for set the cookie for referee
		 *
		 * @name mwb_wpr_referral_link_using_cookie
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_referral_link_using_cookie() {
			if ( ! is_admin() ) {
				if ( ! is_user_logged_in() ) {
					$mwb_wpr_ref_link_expiry = get_option( 'mwb_wpr_ref_link_expiry', 1 );
					if ( isset( $_GET['pkey'] ) && ! empty( $_GET['pkey'] ) ) {
						$referral_link = trim( sanitize_text_field( wp_unslash( $_GET['pkey'] ) ) );
						if ( isset( $mwb_wpr_ref_link_expiry ) && ! empty( $mwb_wpr_ref_link_expiry ) && ! empty( $referral_link ) ) {
							setcookie( 'mwb_wpr_cookie_set', $referral_link, time() + ( 86400 * $mwb_wpr_ref_link_expiry ), '/' );
						}
					}
				}
			}
		}

		/**
		 * The function is used for destroy the cookie
		 *
		 * @name mwb_wpr_destroy_cookie
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_destroy_cookie() {
			if ( isset( $_COOKIE['mwb_wpr_cookie_set'] ) && ! empty( $_COOKIE['mwb_wpr_cookie_set'] ) ) {
				setcookie( 'mwb_wpr_cookie_set', '', time() - 3600, '/' );
			}
		}

		/**
		 * This function is used to add the html boxes for "Redemption on Cart sub-total"
		 *
		 * @name mwb_wgm_woocommerce_cart_coupon
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_cart_coupon() {
			// check if shortcode exists then return.
			$wps_wpr_cart_page_section = get_option( 'wps_wpr_cart_page_section', '' );
			if ( 1 == $wps_wpr_cart_page_section ) {
				$content = get_the_content();
				if ( ! empty( $content ) ) {
					if ( true == strpos( $content, '[Wps_Cart_Page_Section' ) ) {
						return;
					}
				}
			}

			$mwb_wpr_custom_points_on_cart = get_option( 'mwb_wpr_custom_points_on_cart', 0 );
			if ( 1 == $mwb_wpr_custom_points_on_cart ) {
				$user_id    = get_current_user_ID();
				$get_points = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );

				if ( isset( $user_id ) && ! empty( $user_id ) ) {
					?>
					<div class="mwb_wpr_apply_custom_points">
						<input type="number" name="mwb_cart_points" class="input-text" id="mwb_cart_points" value="" placeholder="<?php esc_attr_e( 'Points', 'woocommerce-ultimate-points-and-rewards' ); ?>"/>
						<input type="button" name="mwb_cart_points_apply" data-point="<?php echo esc_attr( $get_points ); ?>" data-id="<?php echo esc_attr( $user_id ); ?>" class="button mwb_cart_points_apply" id="mwb_cart_points_apply" value="<?php esc_attr_e( 'Apply Points', 'woocommerce-ultimate-points-and-rewards' ); ?>"/>
					</div>	
					<?php
				}
			}
		}

		/**
		 * This function is used to apply fee on cart total
		 *
		 * @name mwb_wpr_apply_fee_on_cart_subtotal
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_apply_fee_on_cart_subtotal() {

			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$response['result']  = false;
			$response['message'] = __( 'Can not redeem!', 'woocommerce-ultimate-points-and-rewards' );

			$get_points      = get_user_meta( get_current_user_id(), 'mwb_wpr_points', true );
			$get_points      = ! empty( $get_points ) && $get_points > 0 ? $get_points : 0;
			$mwb_cart_points = isset( $_POST['mwb_cart_points'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_cart_points'] ) ) : '';

			if ( $get_points > 0 && $mwb_cart_points > 0 ) {
				if ( $get_points >= $mwb_cart_points ) {

					WC()->session->set( 'mwb_cart_points', $mwb_cart_points );
					$response['result']  = true;
					$response['message'] = __( 'Custom Point has been applied Successfully!', 'woocommerce-ultimate-points-and-rewards' );
				} else {
					$response['result']  = false;
					$response['message'] = __( 'Please enter some valid points!', 'woocommerce-ultimate-points-and-rewards' );
				}
			} else {

				$response['result']  = false;
				$response['message'] = __( 'Invalid points!', 'woocommerce-ultimate-points-and-rewards' );
			}
			echo json_encode( $response );
			wp_die();
		}

		/**
		 * This function is used to apply custom points on Cart Total
		 *
		 * @param      object $cart       Data.
		 * @name mwb_wpr_woocommerce_cart_custom_points
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_cart_custom_points( $cart ) {
			$user_id                       = get_current_user_ID();
			$mwb_wpr_custom_points_on_cart = get_option( 'mwb_wpr_custom_points_on_cart', 0 );
			if ( isset( $user_id ) && ! empty( $user_id ) && 1 == $mwb_wpr_custom_points_on_cart ) {

				$mwb_wpr_cart_points_rate = get_option( 'mwb_wpr_cart_points_rate', 1 );
				$mwb_wpr_cart_price_rate  = get_option( 'mwb_wpr_cart_price_rate', 1 );

				if ( ! empty( WC()->session->get( 'mwb_cart_points' ) ) ) {
					
					$mwb_existing_points          = get_user_meta( get_current_user_ID(), 'mwb_wpr_points', true );
					$mwb_wpr_points               = WC()->session->get( 'mwb_cart_points' );
					$product_purchase_only_amount = 0;

					// if purchase through points only has been applied than manage points here ( from product edit page ).
					if ( ! empty( $cart ) ) {
						foreach ( $cart->get_cart() as $key => $value ) {

							$mwb_product_purchase_points_only  = get_post_meta( $value['product_id'], 'mwb_product_purchase_points_only', true );
							if ( 'yes' === $mwb_product_purchase_points_only ) {

								$mwb_points_product_purchase_value = get_post_meta( $value['product_id'], 'mwb_points_product_purchase_value', true );
								$product_purchase_only_amount      += (int) $mwb_points_product_purchase_value * $value['quantity'];
							}
						}
					}
					if ( $product_purchase_only_amount > 0 ) {

						$mwb_existing_points = (int) $mwb_existing_points - $product_purchase_only_amount;
					}

					// manage points when points discount and cart discount applied at the same time.
					$mwb_existing_points                          = ! empty( $mwb_existing_points ) ? $mwb_existing_points : 0;
					$mwb_par_check_points_discount_applied_amount = ! empty( get_option( 'mwb_par_check_points_discount_applied_amount' ) ) ? get_option( 'mwb_par_check_points_discount_applied_amount' ) : 0;
					$mwb_existing_points                          = (int) $mwb_existing_points - $mwb_par_check_points_discount_applied_amount;

					// check if applied cart discount is > than existing points then assign existing points.
					if ( $mwb_wpr_points > $mwb_existing_points ) {
						$mwb_wpr_points = $mwb_existing_points;
					}
					$mwb_fee_on_cart = (int) ( $mwb_wpr_points * $mwb_wpr_cart_price_rate / $mwb_wpr_cart_points_rate );

					// calculating purchase through points and shippig amount.
					$cart_shipping_amount   = 0;
					$cart_content_tax       = 0;
					if ( ! empty( $cart ) ) {

						$cart_shipping_amount = (int) ! empty( $cart->get_shipping_total() ) ? $cart->get_shipping_total() : 0;
						$cart_content_tax     = (int) ! empty( $cart->get_cart_contents_tax() ) ? $cart->get_cart_contents_tax() : 0;
					}

					// add cart subtotal amount shipping amount.
					$cart__subtotal = 0;
					$cart__subtotal = $cart->subtotal + $cart_shipping_amount;
					$cart__subtotal = $cart__subtotal - $cart_content_tax;
					$cart__subtotal = $cart__subtotal - $mwb_par_check_points_discount_applied_amount;

					// check if applied points is greater than cart subtotal than assigned cart points.
					if ( $mwb_fee_on_cart > (int) $cart__subtotal ) {

						$mwb_fee_on_cart = $cart__subtotal;
					}
					$mwb_fee_on_cart = apply_filters( 'mwb_par_show_conversion_price', $mwb_fee_on_cart );
					$cart->add_fee( 'Cart Discount', -$mwb_fee_on_cart, true, '' );
				}
			}
		}

		/**
		 * This function is used to add notices over cart page
		 *
		 * @name mwb_wpr_woocommerce_before_cart_contents
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_before_cart_contents() {
			$mwb_wpr_custom_points_on_cart = get_option( 'mwb_wpr_custom_points_on_cart', 0 );
			$mwb_wpr_notification_color    = get_option( 'mwb_wpr_notification_color', '#55b3a5' );
			$mwb_wpr_cart_points_rate      = get_option( 'mwb_wpr_cart_points_rate', 1 );
			$mwb_wpr_cart_price_rate       = get_option( 'mwb_wpr_cart_price_rate', 1 );
			$user_id                       = get_current_user_ID();
			if ( 1 == $mwb_wpr_custom_points_on_cart && isset( $user_id ) && ! empty( $user_id ) ) {
				?>
				<div class="woocommerce-message wps_wpr_message_for_redemption__wrapper"><?php esc_attr_e( 'Here is the Discount Rule for applying your points to Cart sub-total : ', 'woocommerce-ultimate-points-and-rewards' ); ?>
					<?php echo esc_attr( $mwb_wpr_cart_points_rate ) . esc_html__( ' Points', 'woocommerce-ultimate-points-and-rewards' ) . ' = ' . wp_kses_post( wc_price( apply_filters( 'mwb_par_show_conversion_price', $mwb_wpr_cart_price_rate ) ) ); ?>
				</div>
				<div class="woocommerce-error" id="mwb_wpr_cart_points_notice" style="display: none;"></div>
				<div class="woocommerce-message" id="mwb_wpr_cart_points_success" style="display: none;"></div>
				<?php
			}
			if ( $this->is_order_conversion_enabled() ) {
				$order_conversion_rate = $this->order_conversion_rate();
				?>
				<div class="woocommerce-message" id="mwb_wpr_order_notice" style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>">
					<?php esc_attr_e( 'Place Order And Earn Something in Return', 'woocommerce-ultimate-points-and-rewards' ); ?>
					<p style="background-color: <?php echo esc_attr( $mwb_wpr_notification_color ); ?>">
						<?php
						esc_attr_e( 'Conversion Rate: ' );
						echo wp_kses_post( wc_price( apply_filters( 'mwb_par_show_conversion_price', $order_conversion_rate['Value'] ) ) ) . ' = ' . esc_attr( $order_conversion_rate['Points'] );
						esc_attr_e( ' Points', 'woocommerce-ultimate-points-and-rewards' );
						?>
					</p>
					
				</div>
				<?php
			}

			// If user is already awarded by Order points, then return from here.
			$user_id                      = get_current_user_id();
			$wps_wpr_order_points_awarded = get_user_meta( $user_id, 'wps_wpr_order_points_awarded', '' );
			if ( ! empty( $wps_wpr_order_points_awarded ) || 'done' == $wps_wpr_order_points_awarded ) {
				return;
			}

			// Show message on cart for user to know how much he/she will earn when reach order limit.
			$wps_wpr_enable_order__rewards_points = get_option( 'wps_wpr_enable_order__rewards_points', '' );
			$wps_wpr_number_of_order              = get_option( 'wps_wpr_number_of_order', 1 );
			$wps_wpr_order__rewards_points        = get_option( 'wps_wpr_order__rewards_points', 1 );
			$wps_wpr_enable_order_notice          = get_option( 'wps_wpr_enable_order_notice', '' );
			$wps_wpr_order_message_color          = get_option( 'wps_wpr_order_message_color', '' );
			$mwb_wpr_cart__page_messages          = get_option( 'mwb_wpr_cart__page_messages', '' );
			$mwb_wpr_cart__page_messages          = ! empty( $mwb_wpr_cart__page_messages ) && ! is_null( $mwb_wpr_cart__page_messages ) ? $mwb_wpr_cart__page_messages : 'Place [ORDER] order and earn [POINTS] Points in return';
			$order_count                          = 0;

			// Check order setting enable or not.
			if ( ! empty( $wps_wpr_enable_order__rewards_points ) && 1 == $wps_wpr_enable_order__rewards_points ) {
				if ( ! empty( $wps_wpr_enable_order_notice ) && 1 == $wps_wpr_enable_order_notice ) {

					// Get all user completed order.
					$wps_customer_orders = wc_get_orders(
						array(
							'post_type'   => array( 'shop_order' ),
							'post_status' => array( 'wc-completed' ),
							'numberposts' => -1,
							'customer_id' => $user_id,
						)
					);

					// Get user order count.
					if ( ! empty( $wps_customer_orders ) && ! is_null( $wps_customer_orders ) ) {
						$order_count = count( $wps_customer_orders );
					}

					// Replace order and points shortcode with order count and order rewards points.
					$mwb_wpr_cart__page_messages = str_replace( '[ORDER]', ( $wps_wpr_number_of_order - $order_count ), $mwb_wpr_cart__page_messages );
					$mwb_wpr_cart__page_messages = str_replace( '[POINTS]', $wps_wpr_order__rewards_points, $mwb_wpr_cart__page_messages );

					?>
					<!-- Show awards discount notice -->
					<div class="woocommerce-message" id="mwb_wpr_order_notice" style="background-color: <?php echo esc_attr( $wps_wpr_order_message_color ); ?>">
						<p style="background-color: <?php echo esc_attr( $wps_wpr_order_message_color ); ?>"><?php echo wp_kses_post( $mwb_wpr_cart__page_messages ); ?></p>
					</div>
					<?php
				}
			}

		}

		/**
		 * This function is used to add Remove button along with Cart Discount Fee
		 *
		 * @param      object $cart_totals_fee_html       Data.
		 * @param      object $fee       Data.
		 * @name mwb_wpr_woocommerce_cart_totals_fee_html
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_cart_totals_fee_html( $cart_totals_fee_html, $fee ) {
			if ( isset( $fee ) && ! empty( $fee ) ) {
				$fee_name = $fee->name;
				if ( isset( $fee_name ) && 'Cart Discount' === $fee_name ) {
					$cart_totals_fee_html = $cart_totals_fee_html . '<a href="javascript:;" id="mwb_wpr_remove_cart_point">' . __( '[Remove]', 'woocommerce-ultimate-points-and-rewards' ) . '</a>';
				}
			}
			return $cart_totals_fee_html;
		}

		/**
		 * This function is used to Remove Cart Discount Fee
		 *
		 * @name mwb_wpr_remove_cart_point
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_remove_cart_point() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$response['result']  = false;
			$response['message'] = __( 'Failed to Remove Cart  Discount', 'woocommerce-ultimate-points-and-rewards' );

			if ( ! empty( WC()->session->get( 'mwb_cart_points' ) ) ) {
				WC()->session->__unset( 'mwb_cart_points' );
				$response['result']  = true;
				$response['message'] = __( 'Successfully Removed Cart Discount', 'woocommerce-ultimate-points-and-rewards' );
			}
			echo json_encode( $response );
			wp_die();
		}

		/**
		 * This function is used to show the notices for Order Total Points fetaure
		 *
		 * @name mwb_wpr_woocommerce_before_main_content
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_before_main_content() {
			if ( $this->is_order_conversion_enabled() ) {
				$mwb_wpr_notification_color = get_option( 'mwb_wpr_notification_color', '#55b3a5' );
				$order_conversion_rate      = $this->order_conversion_rate();
				?>
				<div class="woocommerce-message" id="mwb_wpr_order_notice" style="background-color:<?php echo esc_attr( $mwb_wpr_notification_color ); ?>">
					<?php esc_attr_e( 'Place Order And Earn Something in Return', 'woocommerce-ultimate-points-and-rewards' ); ?>
					<p style="background-color:<?php echo esc_attr( $mwb_wpr_notification_color ); ?>">
						<?php
						esc_attr_e( 'Conversion Rate: ', 'woocommerce-ultimate-points-and-rewards' );
						echo wp_kses_post( wc_price( apply_filters( 'mwb_par_show_conversion_price', $order_conversion_rate['Value'] ) ) ) . ' = ' . esc_attr( $order_conversion_rate['Points'] );
						esc_attr_e( 'Points', 'woocommerce-ultimate-points-and-rewards' );
						?>
					</p>
				</div>
				<?php
			}
		}

		/**
		 * This function is used to check the order conversion feature is enabled or not
		 *
		 * @name is_order_conversion_enabled
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function is_order_conversion_enabled() {
			$enable                     = false;
			$coupon_settings_array      = get_option( 'mwb_wpr_coupons_gallery', array() );
			$is_order_conversion_enable = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_enable'] ) ? $coupon_settings_array['mwb_wpr_coupon_conversion_enable'] : 0;
			if ( $is_order_conversion_enable ) {
				$enable = true;
			}
			return $enable;
		}

		/**
		 * This function is used to return you the conversion rate of Order Total
		 *
		 * @name order_conversion_rate
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function order_conversion_rate() {
			$coupon_settings_array        = get_option( 'mwb_wpr_coupons_gallery', array() );
			$order_conversion_rate_value  = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_price'] ) ? $coupon_settings_array['mwb_wpr_coupon_conversion_price'] : 1;
			$order_conversion_rate_points = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) ? $coupon_settings_array['mwb_wpr_coupon_conversion_points'] : 1;
			$order_conversion_rate        = array(
				'Value'  => $order_conversion_rate_value,
				'Points' => $order_conversion_rate_points,
			);
			return $order_conversion_rate;
		}

		/**
		 * This function is used to handle the point on cancellation of orders dynamically
		 *
		 * @param      string $order_id       Data.
		 * @param      string $old_status       Data.
		 * @param      string $new_status       Data.
		 * @name mwb_wpr_woocommerce_order_status_cancel
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_order_status_cancel( $order_id, $old_status, $new_status ) {

			$order                  = wc_get_order( $order_id );
			$coupon_amount_deducted = get_post_meta( $order_id, 'mwb_par_coupon_amount_deducted', true );
			if ( empty( $coupon_amount_deducted ) ) {
				foreach ( $order->get_items('coupon') as $item_id => $item ) {

					$this->mwb_wpr_woocommerce_order_add_coupon_woo_latest_version( $item_id, $item );
					update_post_meta( $order_id, 'mwb_par_coupon_amount_deducted', 'deduct' );
				}
			}

			if ( $old_status != $new_status ) {
				if ( 'completed' === $old_status && 'refunded' === $new_status ) {

					$user_id = $order->get_user_id();
					$user    = get_user_by( 'ID', $user_id );
					// ========Start Return amount into the coupon========
					$user_log = get_user_meta( $user_id, 'mwb_wpr_user_log', true );
					$coupons  = $order->get_items( 'coupon' );
					if ( is_array( $coupons ) && ! empty( $user_log ) ) {
						foreach ( $coupons as $item_id => $item ) :
							foreach ( $user_log as $key => $value ) {
								if ( in_array( strtoupper( $item->get_code() ), $value ) ) {
									$coupon_obj                = new WC_Coupon( $item->get_code() );
									$coupon_id                 = $coupon_obj->get_id();
									$couponamont               = get_post_meta( $coupon_id, 'coupon_amount', true );
									$order_discount_tax_amount = wc_get_order_item_meta( $item_id, 'discount_amount_tax', true );

									$coupon_amount_before_use = get_post_meta( $coupon_id, 'coupon_amount_before_use', true );
									if ( empty( $coupon_amount_before_use ) ) {
										$coupon_amount_before_use = 0;
									}
									$total_discount = $order_discount_tax_amount + $item->get_discount();

									if ( $coupon_amount_before_use < $total_discount ) {
										$couponamont = $coupon_amount_before_use;
									} else {
										$couponamont = $couponamont + $total_discount;
									}
									// ======Decrese Usages Limit========
									$usage_limit = get_post_meta( $coupon_id, 'usage_limit', true );
									if ( ! empty( $usage_limit ) && $usage_limit >= 1 ) {
										--$usage_limit;
										update_post_meta( $coupon_id, 'usage_limit', $usage_limit );
									}
									// ======Update Coupon Amount========
									if ( ! empty( $couponamont ) ) {
										update_post_meta( $coupon_id, 'coupon_amount', $couponamont );
										$couponamont = 0;
									}
								}
							}
						endforeach;
					}

					// ========End Return amount into the coupon========
					$user_email                       = $user->user_email;
					$mwb_wpr_notificatin_array        = get_option( 'mwb_wpr_notificatin_array', true );
					$general_settings                 = get_option( 'mwb_wpr_settings_gallery', true );
					$mwb_wpr_coupon_conversion_value  = get_option( 'mwb_wpr_coupons_gallery', array() );
					$mwb_wpr_coupon_conversion_price  = $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_price'];
					$mwb_wpr_coupon_conversion_points = $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_points'];
					$mwb_wpr_purchase_points          = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
					$mwb_wpr_product_purchase_price   = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
					$deduction_of_points              = get_user_meta( $user_id, 'points_details', true );
					$today_date                       = date_i18n( 'Y-m-d h:i:sa' );
					$total_points                     = '';

					foreach ( $order->get_items() as $item_id => $item ) {
						$woo_ver = WC()->version;
						if ( $woo_ver < '3.0.0' ) {
							$item_quantity = $order->get_item_meta( $item_id, '_qty', true );
							if ( isset( $item['item_meta']['Points'] ) && ! empty( $item['item_meta']['Points'] ) ) {
								$is_refunded = wc_get_order_item_meta( $item_id, 'refund_points', true );
								if ( ! isset( $is_refunded ) || 'yes' !== $is_refunded ) {
									$get_points   = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
									$deduct_point = $item['item_meta']['Points'][0];
									$total_points = $get_points - $deduct_point;
									if ( isset( $deduction_of_points['deduction_of_points'] ) && ! empty( $deduction_of_points['deduction_of_points'] ) ) {

										$deduction_arr                                = array();
										$deduction_arr                                = array(
											'deduction_of_points' => $deduct_point,
											'date' => $today_date,
										);
										$deduction_of_points['deduction_of_points'][] = $deduction_arr;
									} else {
										if ( ! is_array( $deduction_of_points ) ) {
											$deduction_of_points = array();
										}
										$deduction_arr                                = array(
											'deduction_of_points' => $deduct_point,
											'date' => $today_date,
										);
										$deduction_of_points['deduction_of_points'][] = $deduction_arr;
									}
									update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
									update_user_meta( $user_id, 'points_details', $deduction_of_points );
									wc_update_order_item_meta( $item_id, 'refund_points', 'yes', $prev_value = '' );
									if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
										$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
										$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] : '';
										$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] : '';
										$mwb_wpr_email_discription  = str_replace( '[DEDUCTEDPOINT]', $deduct_point, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_points, $mwb_wpr_email_discription );
										$user                       = get_user_by( 'email', $user_email );
										$user_name                  = $user->user_firstname;
										$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
										if ( $mwb_wpr_notificatin_enable ) {
											$headers = array( 'Content-Type: text/html; charset=UTF-8' );
											wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
										}
									}
								}
							}

							if ( isset( $item['item_meta']['Purchasing Option'] ) && ! empty( $item['item_meta']['Purchasing Option'] ) ) {
								$is_refunded = wc_get_order_item_meta( $item_id, 'refund_purchased_point', true );
								if ( ! isset( $is_refunded ) || 'yes' !== $is_refunded ) {
									$get_points       = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
									$return_pur_point = $item['item_meta']['Purchasing Option'][0];

									$total_return_points = $get_points + $return_pur_point;
									if ( isset( $deduction_of_points['return_pur_points'] ) && ! empty( $deduction_of_points['return_pur_points'] ) ) {
										$return_arr                                 = array();
										$return_arr                                 = array(
											'return_pur_points' => $return_pur_point,
											'date' => $today_date,
										);
										$deduction_of_points['return_pur_points'][] = $return_arr;
									} else {
										if ( ! is_array( $deduction_of_points ) ) {
											$deduction_of_points = array();
										}
										$return_arr                                 = array(
											'return_pur_points' => $return_pur_point,
											'date' => $today_date,
										);
										$deduction_of_points['return_pur_points'][] = $return_arr;
									}
									update_user_meta( $user_id, 'mwb_wpr_points', $total_return_points );
									update_user_meta( $user_id, 'points_details', $deduction_of_points );
									wc_update_order_item_meta( $item_id, 'refund_purchased_point', 'yes', $prev_value = '' );
									if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
										$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
										$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] : '';
										$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] : '';
										$mwb_wpr_email_discription  = str_replace( '[RETURNPOINT]', $return_pur_point, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_return_points, $mwb_wpr_email_discription );
										$user                       = get_user_by( 'email', $user_email );
										$user_name                  = $user->user_firstname;
										$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
										if ( $mwb_wpr_notificatin_enable ) {
											$headers = array( 'Content-Type: text/html; charset=UTF-8' );
											wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
										}
									}
								}
							}
						} else {
							$item_quantity = wc_get_order_item_meta( $item_id, '_qty', true );
							$mwb_wpr_items = $item->get_meta_data();
							if ( is_array( $mwb_wpr_items ) && ! empty( $mwb_wpr_items ) ) {
								foreach ( $mwb_wpr_items as $key => $mwb_wpr_value ) {
									if ( isset( $mwb_wpr_value->key ) && ! empty( $mwb_wpr_value->key ) && ( 'Points' === $mwb_wpr_value->key ) ) {
										$is_refunded = wc_get_order_item_meta( $item_id, 'refund_points', true );
										if ( ! isset( $is_refunded ) || 'yes' !== $is_refunded ) {
											$get_points   = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
											$deduct_point = $mwb_wpr_value->value;
											$total_points = $get_points - $deduct_point;
											if ( isset( $deduction_of_points['deduction_of_points'] ) && ! empty( $deduction_of_points['deduction_of_points'] ) ) {

												$deduction_arr                                = array();
												$deduction_arr                                = array(
													'deduction_of_points' => $deduct_point,
													'date' => $today_date,
												);
												$deduction_of_points['deduction_of_points'][] = $deduction_arr;
											} else {
												$deduction_arr                                = array();
												$deduction_arr                                = array(
													'deduction_of_points' => $deduct_point,
													'date' => $today_date,
												);
												$deduction_of_points['deduction_of_points'][] = $deduction_arr;
											}
											update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
											update_user_meta( $user_id, 'points_details', $deduction_of_points );
											wc_update_order_item_meta( $item_id, 'refund_points', 'yes', $prev_value = '' );
											if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
												$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
												$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] : '';
												$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] : '';
												$mwb_wpr_email_discription  = str_replace( '[DEDUCTEDPOINT]', $deduct_point, $mwb_wpr_email_discription );
												$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_points, $mwb_wpr_email_discription );
												$user                       = get_user_by( 'email', $user_email );
												$user_name                  = $user->user_firstname;
												$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
												if ( $mwb_wpr_notificatin_enable ) {
													$headers = array( 'Content-Type: text/html; charset=UTF-8' );
													wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
												}
											}
										}
									}
								}
							}
						}
					}

					// hpos.
					$item_conversion_id_set = mwb_par_hpos_get_meta_data( $order_id, "$order_id#item_conversion_id", true );
					$order_total            = $order->get_total();
					if ( ! empty( $item_conversion_id_set ) && 'set' === $item_conversion_id_set ) {
						$get_points    = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
						$all_refunds   = $order->get_refunds();
						$refund_item   = $all_refunds[0];
						$refund_amount = $refund_item->get_amount();
						// hpos.
						$deduct_currency_spent = mwb_par_hpos_get_meta_data( $order_id, 'mwb_wpr_per_currency_awarded_points', true );
						$remaining_points      = $get_points - $deduct_currency_spent;
						if ( isset( $deduction_of_points['deduction_currency_spent'] ) && ! empty( $deduction_of_points['deduction_currency_spent'] ) ) {
							$currency_arr                                      = array();
							$currency_arr                                      = array(
								'deduction_currency_spent' => $deduct_currency_spent,
								'date'                     => $today_date,
							);
							$deduction_of_points['deduction_currency_spent'][] = $currency_arr;
						} else {
							$currency_arr                                      = array();
							$currency_arr                                      = array(
								'deduction_currency_spent' => $deduct_currency_spent,
								'date'                     => $today_date,
							);
							$deduction_of_points['deduction_currency_spent'][] = $currency_arr;
						}
						update_user_meta( $user_id, 'mwb_wpr_points', $remaining_points );
						update_user_meta( $user_id, 'points_details', $deduction_of_points );
						if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
							$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
							$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_subject'] : '';
							$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_description'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_description'] : '';
							$mwb_wpr_email_discription  = str_replace( '[DEDUCTEDPOINT]', $deduct_currency_spent, $mwb_wpr_email_discription );
							$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $remaining_points, $mwb_wpr_email_discription );
							$user                       = get_user_by( 'email', $user_email );
							$user_name                  = $user->user_firstname;
							$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
							if ( $mwb_wpr_notificatin_enable ) {
								$headers = array( 'Content-Type: text/html; charset=UTF-8' );
								wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
							}
						}
					}

					// Refund amount of Point Discount.
					if ( isset( $order ) && ! empty( $order ) ) {
						// hpos.
						$is_refunded = mwb_par_hpos_get_meta_data( $order_id, 'mwb_point_discount', true );
						if ( ! isset( $is_refunded ) || 'Refunded' !== $is_refunded ) {
							$general_settings               = get_option( 'mwb_wpr_settings_gallery', true );
							$mwb_wpr_purchase_points        = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
							$mwb_wpr_product_purchase_price = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
							$deduction_of_points            = get_user_meta( $user_id, 'points_details', true );
							$order_fees                     = $order->get_fees();
							$get_points                     = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
							if ( ! empty( $order_fees ) ) {
								foreach ( $order_fees as $fee_item_id => $fee_item ) {
									$fee_id     = $fee_item_id;
									$fee_name   = $fee_item->get_name();
									if ( ! empty( $fee_name ) && 'Point Discount' === $fee_name ) {
										// Now deduct the fee amount from user account as the point.
										// hpos.
										$fee_to_point = mwb_par_hpos_get_meta_data( $order_id, 'mwb_par_purchase_through_points_amount', true );
										$total_point  = $get_points + $fee_to_point;
										if ( isset( $deduction_of_points['return_pur_points'] ) && ! empty( $deduction_of_points['return_pur_points'] ) ) {
											$return_arr                                 = array(
												'return_pur_points' => $fee_to_point,
												'date' => $today_date,
											);
											$deduction_of_points['return_pur_points'][] = $return_arr;
										} else {
											if ( ! is_array( $deduction_of_points ) ) {
												$deduction_of_points = array();
											}
											$return_arr                                 = array(
												'return_pur_points' => $fee_to_point,
												'date' => $today_date,
											);
											$deduction_of_points['return_pur_points'][] = $return_arr;
										}
										update_user_meta( $user_id, 'mwb_wpr_points', $total_point );
										update_user_meta( $user_id, 'points_details', $deduction_of_points );
										// hpos.
										mwb_par_hpos_update_meta_data( $order_id, 'mwb_point_discount', 'Refunded' );
										if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
											$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
											$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] : '';
											$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] : '';
											$mwb_wpr_email_discription  = str_replace( '[RETURNPOINT]', $fee_to_point, $mwb_wpr_email_discription );
											$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_point, $mwb_wpr_email_discription );
											$user                       = get_user_by( 'email', $user_email );
											$user_name                  = $user->user_firstname;
											$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
											if ( $mwb_wpr_notificatin_enable ) {
												$headers = array( 'Content-Type: text/html; charset=UTF-8' );
												wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
											}
										}
									}
								}
							}
						}
					}
				}

				if ( 'completed' === $old_status && 'cancelled' === $new_status ) {
					$order   = wc_get_order( $order_id );
					$user_id = $order->get_user_id();
					// ========Start Return amount into the coupon========
					$user_log = get_user_meta( $user_id, 'mwb_wpr_user_log', true );
					$coupons  = $order->get_items( 'coupon' );
					if ( is_array( $coupons ) && ! empty( $user_log ) ) {
						foreach ( $coupons as $item_id => $item ) :
							foreach ( $user_log as $key => $value ) {
								if ( in_array( strtoupper( $item->get_code() ), $value ) ) {
									$coupon_obj                = new WC_Coupon( $item->get_code() );
									$coupon_id                 = $coupon_obj->get_id();
									$couponamont               = get_post_meta( $coupon_id, 'coupon_amount', true );
									$order_discount_tax_amount = wc_get_order_item_meta( $item_id, 'discount_amount_tax', true );
									$coupon_amount_before_use  = get_post_meta( $coupon_id, 'coupon_amount_before_use', true );
									if ( empty( $coupon_amount_before_use ) ) {
										$coupon_amount_before_use = 0;
									}
									$total_discount = $order_discount_tax_amount + $item->get_discount();

									if ( $coupon_amount_before_use < $total_discount ) {
										$couponamont = $coupon_amount_before_use;
									} else {
										$couponamont = $couponamont + $total_discount;
									}
									// ======Decrese Usages Limit========
									$usage_limit = get_post_meta( $coupon_id, 'usage_limit', true );
									if ( ! empty( $usage_limit ) && $usage_limit >= 1 ) {
										--$usage_limit;
										update_post_meta( $coupon_id, 'usage_limit', $usage_limit );
									}
									// ======Update Coupon Amount========
									if ( ! empty( $couponamont ) ) {
										update_post_meta( $coupon_id, 'coupon_amount', $couponamont );
										$couponamont = 0;
									}
								}
							}
						endforeach;
					}

					// ========End Return amount into the coupon========
					$user                             = get_user_by( 'ID', $user_id );
					$user_email                       = $user->user_email;
					$mwb_wpr_notificatin_array        = get_option( 'mwb_wpr_notificatin_array', true );
					$general_settings                 = get_option( 'mwb_wpr_settings_gallery', true );
					$mwb_wpr_coupon_conversion_value  = get_option( 'mwb_wpr_coupons_gallery', array() );
					$mwb_wpr_coupon_conversion_price  = $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_price'];
					$mwb_wpr_coupon_conversion_points = $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_points'];
					$mwb_wpr_purchase_points          = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
					$mwb_wpr_product_purchase_price   = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
					$deduct_bcz_cancel                = get_user_meta( $user_id, 'points_details', true );
					$today_date                       = date_i18n( 'Y-m-d h:i:sa' );
					$total_points                     = '';

					foreach ( $order->get_items() as $item_id => $item ) {
						$woo_ver       = WC()->version;
						$item_quantity = wc_get_order_item_meta( $item_id, '_qty', true );
						$mwb_wpr_items = $item->get_meta_data();
						if ( is_array( $mwb_wpr_items ) && ! empty( $mwb_wpr_items ) ) {
							foreach ( $mwb_wpr_items as $key => $mwb_wpr_value ) {
								if ( isset( $mwb_wpr_value->key ) && ! empty( $mwb_wpr_value->key ) && ( 'Points' === $mwb_wpr_value->key ) ) {
									$is_cancelled = wc_get_order_item_meta( $item_id, 'cancel points', true );
									if ( ! isset( $is_cancelled ) || 'yes' !== $is_cancelled ) {
										$get_points   = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
										$deduct_point = $mwb_wpr_value->value;
										$total_points = $get_points - $deduct_point;
										if ( isset( $deduct_bcz_cancel['deduct_bcz_cancel'] ) && ! empty( $deduct_bcz_cancel['deduct_bcz_cancel'] ) ) {
											$deduction_arr                            = array(
												'deduct_bcz_cancel' => $deduct_point,
												'date' => $today_date,
											);
											$deduct_bcz_cancel['deduct_bcz_cancel'][] = $deduction_arr;
										} else {
											if ( ! is_array( $deduct_bcz_cancel ) ) {
												$deduct_bcz_cancel = array();
											}
											$deduction_arr                            = array(
												'deduct_bcz_cancel' => $deduct_point,
												'date' => $today_date,
											);
											$deduct_bcz_cancel['deduct_bcz_cancel'][] = $deduction_arr;
										}
										update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
										update_user_meta( $user_id, 'points_details', $deduct_bcz_cancel );
										wc_update_order_item_meta( $item_id, 'cancel points', 'yes', $prev_value = '' );
										if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
											$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
											$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] : '';
											$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] : '';
											$mwb_wpr_email_discription  = str_replace( '[DEDUCTEDPOINT]', $deduct_point, $mwb_wpr_email_discription );
											$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_points, $mwb_wpr_email_discription );
											$user                       = get_user_by( 'email', $user_email );
											$user_name                  = $user->user_firstname;
											$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
											if ( $mwb_wpr_notificatin_enable ) {
												$headers = array( 'Content-Type: text/html; charset=UTF-8' );
												wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
											}
										}
									}
								}
							}
						}
					}

					// For Per Currency Spent Point Conversion (Cancellation).
					// hpos.
					$item_conversion_id_set = mwb_par_hpos_get_meta_data( $order_id, "$order_id#item_conversion_id", true );
					$is_cancelled           = mwb_par_hpos_get_meta_data( $order_id, 'points_returned', true );
					if ( ! isset( $is_cancelled ) || 'yes' !== $is_cancelled ) {
						if ( ! empty( $item_conversion_id_set ) && 'set' === $item_conversion_id_set ) {
							$get_points            = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
							$order_total           = $order->get_total();
							// hpos.
							$deduct_currency_spent = mwb_par_hpos_get_meta_data( $order_id, 'mwb_wpr_per_currency_awarded_points', true );
							$remaining_points      = $get_points - $deduct_currency_spent;
							if ( isset( $deduct_bcz_cancel['deduct_currency_pnt_cancel'] ) && ! empty( $deduct_bcz_cancel['deduct_currency_pnt_cancel'] ) ) {
								$currency_arr                                      = array(
									'deduct_currency_pnt_cancel' => $deduct_currency_spent,
									'date' => $today_date,
								);
								$deduct_bcz_cancel['deduct_currency_pnt_cancel'][] = $currency_arr;
							} else {
								if ( ! is_array( $deduct_bcz_cancel ) ) {
									$deduct_bcz_cancel = array();
								}
								$currency_arr                                      = array(
									'deduct_currency_pnt_cancel' => $deduct_currency_spent,
									'date' => $today_date,
								);
								$deduct_bcz_cancel['deduct_currency_pnt_cancel'][] = $currency_arr;
							}
							update_user_meta( $user_id, 'mwb_wpr_points', $remaining_points );
							update_user_meta( $user_id, 'points_details', $deduct_bcz_cancel );
							// hpos.
							mwb_par_hpos_update_meta_data( $order_id, 'points_returned', 'yes' );
							if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
								$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
								$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_subject'] : '';
								$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_description'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_description'] : '';
								$mwb_wpr_email_discription  = str_replace( '[DEDUCTEDPOINT]', $deduct_currency_spent, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $remaining_points, $mwb_wpr_email_discription );
								$user                       = get_user_by( 'email', $user_email );
								$user_name                  = $user->user_firstname;
								$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
								if ( $mwb_wpr_notificatin_enable ) {
									$headers = array( 'Content-Type: text/html; charset=UTF-8' );
									wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
								}
							}
						}
					}

					// Return Points on Cancellation Order (Product Purchasedby using Points).
					if ( isset( $order ) && ! empty( $order ) ) {
						// hpos.
						$is_refunded = mwb_par_hpos_get_meta_data( $order_id, 'points_discount', true );
						if ( ! isset( $is_refunded ) || 'Refunded' !== $is_refunded ) {
							$general_settings               = get_option( 'mwb_wpr_settings_gallery', true );
							$mwb_wpr_purchase_points        = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
							$mwb_wpr_product_purchase_price = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
							$order_fees                     = $order->get_fees();
							$get_points                     = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
							if ( ! empty( $order_fees ) ) {
								foreach ( $order_fees as $fee_item_id => $fee_item ) {
									$fee_id     = $fee_item_id;
									$fee_name   = $fee_item->get_name();
									if ( ! empty( $fee_name ) && 'Point Discount' === $fee_name ) {
										// Now deduct the fee amount from user account as the point.
										// hpos.
										$fee_to_point = mwb_par_hpos_get_meta_data( $order_id, 'mwb_par_purchase_through_points_amount', true );
										$total_point  = $get_points + $fee_to_point;
										if ( isset( $deduct_bcz_cancel['pur_points_cancel'] ) && ! empty( $deduct_bcz_cancel['pur_points_cancel'] ) ) {
											$return_arr                               = array(
												'pur_points_cancel' => $fee_to_point,
												'date' => $today_date,
											);
											$deduct_bcz_cancel['pur_points_cancel'][] = $return_arr;
										} else {
											if ( ! is_array( $deduct_bcz_cancel ) ) {
												$deduct_bcz_cancel = array();
											}
											$return_arr                               = array(
												'pur_points_cancel' => $fee_to_point,
												'date' => $today_date,
											);
											$deduct_bcz_cancel['pur_points_cancel'][] = $return_arr;
										}
										update_user_meta( $user_id, 'mwb_wpr_points', $total_point );
										update_user_meta( $user_id, 'points_details', $deduct_bcz_cancel );
										// hpos.
										mwb_par_hpos_update_meta_data( $order_id, 'points_discount', 'Refunded' );
										if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
											$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
											$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] : '';
											$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] : '';
											$mwb_wpr_email_discription  = str_replace( '[RETURNPOINT]', $fee_to_point, $mwb_wpr_email_discription );
											$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_point, $mwb_wpr_email_discription );
											$user                       = get_user_by( 'email', $user_email );
											$user_name                  = $user->user_firstname;
											$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
											if ( $mwb_wpr_notificatin_enable ) {
												$headers = array( 'Content-Type: text/html; charset=UTF-8' );
												wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
											}
										}
									}
								}
							}
						}
					}
				}

				// Cart/Checkout page applied points refund here.
				$mwb_wpr_status_array = array( 'processing', 'on-hold', 'pending', 'completed' );
				if ( in_array( $old_status, $mwb_wpr_status_array, true ) && ( 'cancelled' === $new_status || 'refunded' === $new_status ) ) {
					$order   = wc_get_order( $order_id );
					$user_id = $order->get_user_id();

					if ( isset( $user_id ) && ! empty( $user_id ) ) {
						$user            = get_user_by( 'ID', $user_id );
						$user_points_log = get_user_meta( $user_id, 'points_details', true );
						$user_points_log = ! empty( $user_points_log ) && is_array( $user_points_log ) ? $user_points_log : array();

						if ( array_key_exists( 'cart_subtotal_point', $user_points_log ) ) {
							$today_date = date_i18n( 'Y-m-d h:i:sa' );
							// hpos.
							$mwb_check_applied_points = mwb_par_hpos_get_meta_data( $order_id, 'mwb_cart_discount#$fee_id', true );

							if ( ! empty( $user_points_log ) && is_array( $user_points_log ) ) {
								foreach ( $user_points_log['cart_subtotal_point'] as $key => $values ) {
									// hpos.
									$mwb_wpr_cart_refunded = mwb_par_hpos_get_meta_data( $order_id, 'mwb_wpr_cart_refunded', true );
									if ( empty( $mwb_wpr_cart_refunded ) || 'done' != $mwb_wpr_cart_refunded ) {

										if ( $values['cart_subtotal_point'] == $mwb_check_applied_points ) {
											$mwb_value_to_refund = $values['cart_subtotal_point'];
											$get_points          = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
											$get_points          = ! empty( $get_points ) ? $get_points : 0;
											$total_points        = $get_points + $mwb_value_to_refund;

											if ( isset( $user_points_log['refund_applied_cart_point'] ) && ! empty( $user_points_log['refund_applied_cart_point'] ) ) {
												$cart_array = array(
													'refund_applied_cart_point' => $mwb_value_to_refund,
													'date'                      => $today_date,
												);
												$user_points_log['refund_applied_cart_point'][] = $cart_array;
											} else {
												if ( ! is_array( $user_points_log ) ) {
													$user_points_log = array();
												}
												$cart_array = array(
													'refund_applied_cart_point' => $mwb_value_to_refund,
													'date'                      => $today_date,
												);
												$user_points_log['refund_applied_cart_point'][] = $cart_array;
											}
											update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
											update_user_meta( $user_id, 'points_details', $user_points_log );
											// hpos.
											mwb_par_hpos_update_meta_data( $order_id, 'mwb_wpr_cart_refunded', 'done' );
										}
									}
								}
							}
						}
					}
				}
			}
		}

		/**
		 * This function is used to handle the tax calculation when Fee is applying on Cart
		 *
		 * @param      object $fee_taxes       Data.
		 * @param      object $fee       Data.
		 * @param      object $object       Data.
		 * @name mwb_wpr_fee_tax_calculation
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_wpr_fee_tax_calculation( $fee_taxes, $fee, $object ) {
			if ( 'point-discount' === $fee->object->id || 'cart-discount' === $fee->object->id ) {
				foreach ( $fee_taxes as $key => $value ) {
					$fee_taxes[ $key ] = 0;
				}
			}
			return $fee_taxes;
		}

		/**
		 * WooCommerce Ultimate Points And Rewards save tab settings.
		 *
		 * @param      string $validate       Data.
		 * @param      string $product_id       Data.
		 * @param      string $quantity       Data.
		 * @since 1.0.0
		 */
		public function mwb_wpr_woocommerce_add_to_cart_validation( $validate, $product_id, $quantity ) {
			$_product                       = wc_get_product( $product_id );
			$enable_product_purchase_points = get_post_meta( $product_id, 'mwb_product_purchase_points_only', true );
			$mwb_product_purchase_value     = (int) get_post_meta( $product_id, 'mwb_points_product_purchase_value', true );
			$prod_type                      = $_product->get_type();
			$user                           = wp_get_current_user();
			$user_id                        = $user->ID;
			$get_points                     = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );

			if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {
				if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) && ( 'simple' === $prod_type ) ) {
					if ( ! is_user_logged_in() ) {
						$validate = false;
						wc_add_notice( __( 'You must Logged in to purchase this product', 'woocommerce-ultimate-points-and-rewards' ), 'error' );
						return $validate;
					} elseif ( ( $mwb_product_purchase_value * $quantity ) > $get_points ) {
						$validate = false;
						wc_add_notice( __( "You don't have sufficient point to purchase this product", 'woocommerce-ultimate-points-and-rewards' ), 'error' );
						return $validate;
					}
				} elseif ( $this->mwb_wpr_check_whether_product_is_variable( $_product ) ) {
					$variation_id                   = isset( $_POST['variation_id'] ) ? sanitize_text_field( wp_unslash( $_POST['variation_id'] ) ) : '';
					$mwb_wpr_parent_id              = wp_get_post_parent_id( $variation_id );//phpcs:enable.
					$enable_product_purchase_points = get_post_meta( $mwb_wpr_parent_id, 'mwb_product_purchase_points_only', true );
					$mwb_product_purchase_value     = get_post_meta( $variation_id, 'mwb_wpr_variable_points_purchase', true );
					if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {

						if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) ) {
							if ( ! is_user_logged_in() ) {
								$validate = false;
								wc_add_notice( __( 'You must Logged in to purchase this product', 'woocommerce-ultimate-points-and-rewards' ), 'error' );
								return $validate;
							} elseif ( ( $mwb_product_purchase_value * $quantity ) > $get_points ) {
								$validate = false;
								wc_add_notice( __( "You don't have sufficient point to purchase this product", 'woocommerce-ultimate-points-and-rewards' ), 'error' );
								return $validate;
							}
						}
					}
				}
			}
			$cart_content       = WC()->cart->get_cart();
			$purchas_meta_point = 0;
			if ( ! empty( $cart_content ) ) {
				foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {

					if ( isset( $cart_item['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] ) && ! empty( $cart_item['product_meta']['meta_data']['mwb_wpr_purchase_point_only'] ) ) {

						$purchas_meta_point      += $cart_item['product_meta']['meta_data']['mwb_wpr_purchase_point_only'];
						$total_point_to_purchased = $purchas_meta_point + ( $mwb_product_purchase_value * $quantity );
						if ( $total_point_to_purchased > $get_points ) {

							$validate = false;
							wc_add_notice( __( "You have already used your points, Now you don't have much!", 'woocommerce-ultimate-points-and-rewards' ), 'error' );
							return $validate;
						}
					}
				}
			}
			return $validate;
		}

		/**
		 * WooCommerce Ultimate Points And Rewards save tab settings.
		 *
		 * @param      string $val_price       Data.
		 * @param      object $product       Data.
		 * @since 1.0.0
		 */
		public function mwb_woocommerce_variable_price_html( $val_price, $product ) {

			$variations = $product->get_available_variations();
			$var_data   = array();
			$wps_points = esc_html__( ' Points', 'woocommerce-ultimate-points-and-rewards' );

			foreach ( $variations as $key => $variation ) {

				foreach ( $variation as $key => $variation_id ) {
					if ( 'variation_id' === $key ) {
						$mwb_wpr_parent_id              = wp_get_post_parent_id( $variation_id );
						$enable_product_purchase_points = get_post_meta( $mwb_wpr_parent_id, 'mwb_product_purchase_points_only', true );
						$mwb_product_purchase_value     = get_post_meta( $variation_id, 'mwb_wpr_variable_points_purchase', true );
						if ( isset( $enable_product_purchase_points ) && 'yes' === $enable_product_purchase_points ) {

							if ( isset( $mwb_product_purchase_value ) && ! empty( $mwb_product_purchase_value ) ) {

								$var_data[] = $mwb_product_purchase_value;
							}
						}
					}
				}
			}

			if ( isset( $var_data ) && ! empty( $var_data ) ) {
				$min_value = min( $var_data );
				$max_value = max( $var_data );
			}

			if ( isset( $min_value ) && isset( $max_value ) && ! empty( $max_value ) && ! empty( $min_value ) ) {
				if ( $min_value == $max_value ) {

					$val_price = '<p class="price"><span class="woocommerce-Price-amount amount"><span class="woocommerce-Price-currencySymbol"></span>' . esc_html( $min_value ) . '</span><span>' . esc_html( $wps_points ) . '</span></p>';
					return $val_price;
				} else {
					$val_price = '<p class="price"><span class="woocommerce-Price-amount amount"><span class="woocommerce-Price-currencySymbol"></span>' . esc_html( $min_value ) . '</span><span>' . esc_html( $wps_points ) . '</span> – <span class="woocommerce-Price-amount amount"><span class="woocommerce-Price-currencySymbol"></span>' . esc_html( $max_value ) . '</span><span>' . esc_html( $wps_points ) . '</span></p>';
					return $val_price;
				}
			} else {
				return $val_price;
			}
		}
		// End of Custom Work.

		/**
		 * This function is used to allow customer can apply points during checkout
		 *
		 * @param      string $path       Data.
		 * @param      string $template_name       Data.
		 * @name mwb_overwrite_form_temp
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_overwrite_form_temp( $path, $template_name ) {
			$mwb_wpr_apply_points_checkout = get_option( 'mwb_wpr_apply_points_checkout', 0 );
			if ( 1 == $mwb_wpr_apply_points_checkout ) {
				if ( 'checkout/form-coupon.php' === $template_name ) {

					return MWB_WPR_DIRPATH . 'woocommerce/checkout/form-coupon.php';
				}
			}
			return $path;
		}

		/**
		 * This function is used to check whether the exclude product is enable or not for Membership Discount { if enable then sale product will not be having the membership discount anymore as they are already having some discounts }
		 *
		 * @param      object $products      Data.
		 * @name check_exclude_sale_products
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function check_exclude_sale_products( $products ) {

			$membership_settings_array = get_option( 'mwb_wpr_membership_settings', true );
			$exclude_sale_product      = isset( $membership_settings_array['exclude_sale_product'] ) ? intval( $membership_settings_array['exclude_sale_product'] ) : 0;
			$exclude                   = false;

			if ( $exclude_sale_product && $products->is_on_sale() ) {
				$exclude = true;
			} else {
				$exclude = false;
			}
			return $exclude;
		}

		/**
		 * This function updates cart contents before adding into the cart.
		 *
		 * @param [mixed] $cart_contents Data.
		 * @return $cart_contents.
		 */
		public function mwb_wpr_woocommerce_content_change( $cart_contents ) {

			if ( ! empty( $cart_contents ) ) {
				foreach ( $cart_contents as $key => $value ) {

					$product      = wc_get_product( $cart_contents[ $key ]['product_id'] );
					$check_enable = get_post_meta( $cart_contents[ $key ]['product_id'], 'mwb_product_points_enable', 'no' );

					if ( 'yes' === $check_enable ) {
						if ( $product->get_type() == 'variable' ) {

							if ( isset( $cart_contents[ $key ]['variation_id'] ) && ! empty( $cart_contents[ $key ]['variation_id'] ) ) {

								$get_product_points = get_post_meta( $cart_contents[ $key ]['variation_id'], 'mwb_wpr_variable_points', 1 );

								$cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpm_points'] = (int) $get_product_points * (int) ( $cart_contents[ $key ]['quantity'] );

							}
						} else {
							if ( isset( $cart_contents[ $key ]['product_id'] ) && ! empty( $cart_contents[ $key ]['product_id'] ) ) {
								$get_product_points = get_post_meta( $cart_contents[ $key ]['product_id'], 'mwb_points_product_value', 1 );

								$cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpm_points'] = (int) $get_product_points * (int) ( $cart_contents[ $key ]['quantity'] );
							}
						}
					} else {
						unset( $cart_contents[ $key ]['product_meta']['meta_data']['mwb_wpm_points'] );
					}
				}
			}
			return $cart_contents;
		}

		/**
		 * Loads the Notify Me Popup HTML
		 *
		 * @since    1.0.0
		 */
		public function notify_user_load_popup_html() {
			if ( ! is_admin() ) {
				include_once plugin_dir_path( __FILE__ ) . 'modal/notify-user-popup.php';
			}
		}

		/**
		 * This function is used to create shortcode to view apply point section on cart and checkout page.
		 *
		 * @return void
		 */
		public function mwb_wpr_generate_shortcode() {
			$wps_wpr_cart_page_section     = get_option( 'wps_wpr_cart_page_section', '' );
			$wps_wpr_checkout_page_section = get_option( 'wps_wpr_checkout_page_section', '' );
			// check cart page enable.
			if ( 1 == $wps_wpr_cart_page_section ) {
				add_shortcode( 'Wps_Cart_Page_Section', array( $this, 'mwb_wpr_cart_and_checkout_page_shortcode' ) );
			}
			// check checkout page enable.
			if ( 1 == $wps_wpr_checkout_page_section ) {
				add_shortcode( 'Wps_Checkout_Page_Section', array( $this, 'mwb_wpr_show_checkout_page_shortcode' ) );
			}
			// daily login point funtion call.
			$this->mwb_wpr_update_account_on_daily_login();
			// shortcode to show points log.
			add_shortcode( 'MWB_POINTS_LOG', array( $this, 'mwb_show_points_logs' ) );
			// shortcode to show user referral link.
			add_shortcode( 'MWB_REFERRAL_LINK', array( $this, 'mwb_show_referral_links' ) );

			// calling function to manage points.
			$this->mwb_wpr_manage_session_points();
		}

		/**
		 * This function is used to add shortcode on cart page.
		 *
		 * @return string
		 */
		public function mwb_wpr_cart_and_checkout_page_shortcode() {
			ob_start();

			if ( is_cart() ) {
				$mwb_wpr_custom_points_on_cart = get_option( 'mwb_wpr_custom_points_on_cart', 0 );
				if ( 1 == $mwb_wpr_custom_points_on_cart ) {
					$user_id    = get_current_user_ID();
					$get_points = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );

					if ( isset( $user_id ) && ! empty( $user_id ) ) {
						?>
						<div class="mwb_wpr_apply_custom_points">
							<input type="number" name="mwb_cart_points" class="input-text" id="mwb_cart_points" value="" placeholder="<?php esc_attr_e( 'Points', 'woocommerce-ultimate-points-and-rewards' ); ?>"/>
							<input type="button" name="mwb_cart_points_apply" data-point="<?php echo esc_attr( $get_points ); ?>" data-id="<?php echo esc_attr( $user_id ); ?>" class="button mwb_cart_points_apply" id="mwb_cart_points_apply" value="<?php esc_attr_e( 'Apply Points', 'woocommerce-ultimate-points-and-rewards' ); ?>"/>
						</div>	
						<?php
					}
				}
			}
			return ob_get_clean();
		}

		/**
		 * This function is used to show shortcode on checkout page.
		 *
		 * @return string
		 */
		public function mwb_wpr_show_checkout_page_shortcode() {
			ob_start();

			if ( is_checkout() && ! is_wc_endpoint_url( 'order-received' ) ) {
				$user_id = get_current_user_ID();
				if ( isset( $user_id ) && ! empty( $user_id ) ) {

					$get_points               = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
					$mwb_wpr_cart_points_rate = get_option( 'mwb_wpr_cart_points_rate', 1 );
					$mwb_wpr_cart_price_rate  = get_option( 'mwb_wpr_cart_price_rate', 1 );
					$conversion               = ( $get_points * $mwb_wpr_cart_price_rate / $mwb_wpr_cart_points_rate );
					if ( 'on' == get_option( 'mwb_apply_points_on_checkout_page_with_arg' ) ) {
						?>
						<div class="custom_point_checkout mwb_apply_checkout">
						<?php
					} else {
						?>
						<div class="custom_point_checkout woocommerce-info">
						<?php
					}
					?>
						<input type="number" name="mwb_cart_points" class="input-text" id="mwb_cart_points" value="" placeholder="<?php esc_attr_e( 'Points', 'woocommerce-ultimate-points-and-rewards' ); ?>"/>
						<input type="button" name="mwb_cart_points_apply" data-point="<?php echo esc_html( $get_points ); ?>" data-id="<?php echo esc_attr( $user_id ); ?>"" class="button mwb_cart_points_apply" id="mwb_cart_points_apply" value="<?php esc_html_e( 'Apply Points', 'woocommerce-ultimate-points-and-rewards' ); ?>"/>
						<p><?php echo esc_html( $get_points ) . esc_html__( ' Points', 'woocommerce-ultimate-points-and-rewards' ) . ' = ' . wp_kses_post( wc_price( apply_filters( 'mwb_par_show_conversion_price', $conversion ) ) ); ?></p>
					</div>
					<?php
				}
			}
			return ob_get_clean();
		}

		/**
		 * This function is used to give points on user daily visit login.
		 *
		 * @return void
		 */
		public function mwb_wpr_update_account_on_daily_login() {
			// if user not login then retrun from here.
			if ( ! is_user_logged_in() ) {
				return;
			}

			// get daily login settings values.
			$today_date                  = date_i18n( 'Y-m-d h:i:sa' );
			$user_id                     = get_current_user_id();
			$mwb_user_points             = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			$daily_point_log             = get_user_meta( $user_id, 'points_details', true );
			$mwb_wpr_settings_gallery    = get_option( 'mwb_wpr_settings_gallery', array() );
			$mwb_wpr_settings_gallery    = ! empty( $mwb_wpr_settings_gallery ) && is_array( $mwb_wpr_settings_gallery ) ? $mwb_wpr_settings_gallery : array();
			$mwb_wpr_enable_daily_login  = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_enable_daily_login'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_enable_daily_login'] : 0;
			$mwb_wpr_daily__login_points = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_daily__login_points'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_daily__login_points'] : 1;

			if ( 1 == $mwb_wpr_enable_daily_login ) {

				// check if transient is set than return from here.
				if ( get_transient( 'mwb_wpr_daily__login_points_' . $user_id ) ) {
					return;
				}
				if ( ! headers_sent() && did_action( 'wp_loaded' ) ) {
					set_transient( 'mwb_wpr_daily__login_points_' . $user_id, true, DAY_IN_SECONDS );
				}

				if ( empty( $mwb_user_points ) || $mwb_user_points < 0 ) {
					$mwb_user_points = 0;
				}

				$mwb_updated_points = (int) $mwb_wpr_daily__login_points + $mwb_user_points;
				if ( isset( $daily_point_log['daily__login'] ) && ! empty( $daily_point_log['daily__login'] ) ) {
					$daily_login_arr = array(
						'daily__login' => $mwb_wpr_daily__login_points,
						'date'         => $today_date,
					);
					$daily_point_log['daily__login'][] = $daily_login_arr;

				} else {
					if ( ! is_array( $daily_point_log ) ) {
						$daily_point_log = array();
					}
					$daily_login_arr = array(
						'daily__login' => $mwb_wpr_daily__login_points,
						'date'         => $today_date,
					);

					$daily_point_log['daily__login'][] = $daily_login_arr;
				}
				update_user_meta( $user_id, 'mwb_wpr_points', $mwb_updated_points );
				update_user_meta( $user_id, 'points_details', $daily_point_log );
				$user                      = get_user_by( 'ID', $user_id );
				$user_email                = $user->user_email;
				$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );

				if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
					$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
					$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_daily_login_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_daily_login_email_subject'] : '';
					$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_daily_login_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_daily_login_email_discription_custom_id'] : '';
					$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_wpr_daily__login_points, $mwb_wpr_email_discription );
					$mwb_wpr_email_discription  = str_replace( '[Total Points]', $mwb_updated_points, $mwb_wpr_email_discription );
					$user                       = get_user_by( 'email', $user_email );
					$user_name                  = $user->user_firstname;
					$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );

					if ( $mwb_wpr_notificatin_enable ) {
						$headers = array( 'Content-Type: text/html; charset=UTF-8' );
						wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
					}
				}
			}
		}

		/**
		 * This function is used to show button on checkout page when Avada theme is activated.
		 *
		 * @param string $checkout checkout.
		 * @return void
		 */
		public function mwb_wpr_add_apply_form_form( $checkout ) {

			$user_id = get_current_user_ID();
			if ( isset( $user_id ) && ! empty( $user_id ) ) {

				// check if shortcode exists then return.
				$wps_wpr_checkout_page_section = get_option( 'wps_wpr_checkout_page_section', '' );
				if ( 1 == $wps_wpr_checkout_page_section ) {
					$content = get_the_content();
					if ( ! empty( $content ) ) {
						if ( true == strpos( $content, '[Wps_Checkout_Page_Section' ) ) {
							return;
						}
					}
				}

				$get_points               = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
				$mwb_wpr_cart_points_rate = get_option( 'mwb_wpr_cart_points_rate', 1 );
				$mwb_wpr_cart_price_rate  = get_option( 'mwb_wpr_cart_price_rate', 1 );
				$conversion               = ( $get_points * $mwb_wpr_cart_price_rate / $mwb_wpr_cart_points_rate );

				if ( 'Avada' == wp_get_theme()->Name ) {
					if ( 'on' == get_option( 'mwb_apply_points_on_checkout_page_with_arg' ) ) {
						?>
						<div class="custom_point_checkout mwb_apply_checkout">
						<?php
					} else {
						?>
						<div class="custom_point_checkout woocommerce-info">
						<?php
					}
					?>
						<input type="number" name="mwb_cart_points" class="input-text" id="mwb_cart_points" value="" placeholder="<?php esc_attr_e( 'Points', 'woocommerce-ultimate-points-and-rewards' ); ?>"/>
						<input type="button" name="mwb_cart_points_apply" data-point="<?php echo esc_html( $get_points ); ?>" data-id="<?php echo esc_attr( $user_id ); ?>"" class="button mwb_cart_points_apply" id="mwb_cart_points_apply" value="<?php esc_html_e( 'Apply Points', 'woocommerce-ultimate-points-and-rewards' ); ?>"/>
						<p><?php echo esc_html( $get_points ) . esc_html__( ' Points', 'woocommerce-ultimate-points-and-rewards' ) . ' = ' . wp_kses_post( wc_price( apply_filters( 'mwb_par_show_conversion_price', $conversion ) ) ); ?></p>
						</div>
					<?php
				}
			}
		}

		/**
		 * This function is used to get user rewards points on the basis on his no. of order place.
		 *
		 * @return void
		 */
		public function mwb_wpr_awarded_user_number_order_place() {
			// if user is not logged in then return from here.
			if ( ! is_user_logged_in() ) {
				return;
			}

			// if user awarded then return from here.
			$user_id                      = get_current_user_id();
			$wps_wpr_order_points_awarded = get_user_meta( $user_id, 'wps_wpr_order_points_awarded', '' );
			if ( ! empty( $wps_wpr_order_points_awarded ) || 'done' == $wps_wpr_order_points_awarded ) {
				return;
			}

			// get order rewards settings.
			$wps_wpr_enable_order__rewards_points = get_option( 'wps_wpr_enable_order__rewards_points', '' );
			$wps_wpr_number_of_order              = get_option( 'wps_wpr_number_of_order', '' );
			$wps_wpr_order__rewards_points        = get_option( 'wps_wpr_order__rewards_points', '' );
			$today_date                           = date_i18n( 'Y-m-d h:i:sa' );

			// check settings enable or not.
			if ( ! empty( $wps_wpr_enable_order__rewards_points ) && 1 == $wps_wpr_enable_order__rewards_points ) {

				// get particular user completed order.
				$customer_orders = wc_get_orders(
					array(
						'post_type'   => array( 'shop_order' ),
						'post_status' => array( 'wc-completed' ),
						'numberposts' => -1,
						'customer_id' => $user_id,
					)
				);

				// check user order.
				if ( ! empty( $customer_orders ) && ! is_null( $customer_orders ) ) {
					$wps_wpr_number_of_order       = ! empty( $wps_wpr_number_of_order ) && ! is_null( $wps_wpr_number_of_order ) ? $wps_wpr_number_of_order : 0;
					$wps_wpr_order__rewards_points = ! empty( $wps_wpr_order__rewards_points ) && ! is_null( $wps_wpr_order__rewards_points ) ? $wps_wpr_order__rewards_points : 0;

					// get user completed order count.
					if ( count( $customer_orders ) >= $wps_wpr_number_of_order ) {
						$order_awarded_points = get_user_meta( $user_id, 'points_details', true );
						$order_awarded_points = ! empty( $order_awarded_points ) && is_array( $order_awarded_points ) ? $order_awarded_points : array();
						$user_total_points    = get_user_meta( $user_id, 'mwb_wpr_points', true );
						$user_total_points    = ! empty( $user_total_points ) && ! is_null( $user_total_points ) ? $user_total_points : 0;
						$updated_points       = (int) $user_total_points + $wps_wpr_order__rewards_points;

						// create log for order rewards points.
						if ( isset( $order_awarded_points['reward__order_points'] ) && ! empty( $order_awarded_points['reward__order_points'] ) ) {
							$daily_login_arr = array(
								'reward__order_points' => $wps_wpr_order__rewards_points,
								'date'         => $today_date,
							);
							$order_awarded_points['reward__order_points'][] = $daily_login_arr;

						} else {
							if ( ! is_array( $order_awarded_points ) ) {
								$order_awarded_points = array();
							}
							$daily_login_arr = array(
								'reward__order_points' => $wps_wpr_order__rewards_points,
								'date'         => $today_date,
							);

							$order_awarded_points['reward__order_points'][] = $daily_login_arr;
						}

						// update user total points, update user logs.
						update_user_meta( $user_id, 'mwb_wpr_points', $updated_points );
						update_user_meta( $user_id, 'points_details', $order_awarded_points );
						update_user_meta( $user_id, 'wps_wpr_order_points_awarded', 'done' );

						$user                      = get_user_by( 'ID', $user_id );
						$user_email                = $user->user_email;
						$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );

						// send mail to notify user for getting order rewards points.
						if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
							$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
							$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_daily_login_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_daily_login_email_subject'] : '';
							$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_daily_login_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_daily_login_email_discription_custom_id'] : '';
							$mwb_wpr_email_discription  = str_replace( '[Points]', $wps_wpr_order__rewards_points, $mwb_wpr_email_discription );
							$mwb_wpr_email_discription  = str_replace( '[Total Points]', $updated_points, $mwb_wpr_email_discription );
							$user                       = get_user_by( 'email', $user_email );
							$user_name                  = $user->user_firstname;
							$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );

							if ( $mwb_wpr_notificatin_enable ) {
								$headers = array( 'Content-Type: text/html; charset=UTF-8' );
								wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
							}
						}
					}
				}
			}
		}

		/**
		 * This function is used to show points logs.
		 *
		 * @return ob_get_clean
		 */
		public function mwb_show_points_logs() {
			ob_start();
			$user_ID = get_current_user_ID();
			$user    = new WP_User( $user_ID );
			require plugin_dir_path( __FILE__ ) . 'mwb-wpr-points-log-template.php';
			return ob_get_clean();
		}

		/**
		 * This function is used to show referral links.
		 *
		 * @return ob_get_clean
		 */
		public function mwb_show_referral_links() {
			ob_start();
			$site_url            = site_url();
			$mwb_points_referral = get_user_meta( get_current_user_id(), 'mwb_points_referral', true );
			?>
			<p class="mwb_wpr_heading"><?php echo esc_html_e( 'Referral Link', 'woocommerce-ultimate-points-and-rewards' ); ?></p>
			<div class="mwb_account_wrapper mwb_referral_link_shortcode">
				<fieldset class="mwb_wpr_each_section">
					<div class="mwb_wpr_refrral_code_copy">
						<p id="mwb_wpr_copy"><code><?php echo esc_url( $site_url ) . '?pkey=' . esc_attr( $mwb_points_referral ); ?></code></p>
						<button class="mwb_wpr_btn_copy mwb_tooltip" data-clipboard-target="#mwb_wpr_copy" aria-label="copied">
						<span class="mwb_tooltiptext"><?php esc_html_e( 'Copy', 'woocommerce-ultimate-points-and-rewards' ); ?></span>
						<img src="<?php echo esc_url( MWB_WPR_URL ) . 'assets/images/copy.png'; ?>" alt="Copy to clipboard"></button>
					</div>
				</fieldset>
			</div>
			<?php
			return ob_get_clean();
		}

		/** +++++ Wallet Compatibility ++++++ */

		/**
		 * This function is used to show wallet content on account page.
		 *
		 * @param  int $user_id user_id.
		 * @return void
		 */
		public function mwb_wpr_render_wallet_content( $user_id ) {

			if ( is_plugin_active( 'wallet-system-for-woocommerce/wallet-system-for-woocommerce.php' ) && ! empty( get_option( 'wps_wsfw_enable' ) ) ) {
				$mwb_wpr_settings_gallery = get_option( 'mwb_wpr_settings_gallery', array() );
				// wallet compatible settings.
				$mwb_wpr_enable_wallet_settings   = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_enable_wallet_settings'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_enable_wallet_settings'] : 'off';
				$mwb_wpr_wallet_conversion_points = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_wallet_conversion_points'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_wallet_conversion_points'] : '1';
				$mwb_wpr_wallet_conversion_price  = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_wallet_conversion_price'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_wallet_conversion_price'] : '1';

				if ( 'on' === $mwb_wpr_enable_wallet_settings ) {
					?>
					<p class="mwb_wpr_heading"><?php echo esc_html_e( 'Convert Points in to Wallet Currency', 'woocommerce-ultimate-points-and-rewards' ); ?></p>
					<div class="mwb_account_wrapper mwb_referral_link_shortcode">
						<fieldset class="mwb_wpr_each_section">
							<div class="mwb_wpr_refrral_code_copy">
								<div id="mwb_wpr_wallet_conversion_rate"><?php echo esc_html__( 'Points Conversion : ', 'woocommerce-ultimate-points-and-rewards' ) . esc_html( $mwb_wpr_wallet_conversion_points ) . esc_html__( ' Points', 'woocommerce-ultimate-points-and-rewards' ) . ' = ' . wp_kses_post( wc_price( $mwb_wpr_wallet_conversion_price ) ); ?></div>
								<div id="mwb_wpr_wallet_enter_points"><?php esc_html_e( 'Enter Your Points : ' ); ?></div>
								<div id="mwb_wpr_wallet_redeem_buttons">
									<input type="number" min="1" id="mwb_wpr_redeem_points_amount">
									<div class="mwb_button_and_image_wrapper">
										<input type="button" id="mwb_wpr_transfer_points_to_wallet" value="<?php esc_html_e( 'Redeem Points', 'woocommerce-ultimate-points-and-rewards' ); ?>" data-id="<?php echo esc_html( $user_id ); ?>">
										<img class="mwb_points_transfer_wallet" src="<?php echo esc_url( MWB_WPR_URL ) . 'assets/images/loading.gif'; ?>">
									</div>
								</div>
								<p id="mwb_wpr_show_wallet_messages_while_transfer"></p>
							</div>
						</fieldset>
					</div>
					<?php
				}
			}
		}

		/**
		 * This function is used to render subscription renewal message for user acknowledgment.
		 *
		 * @param string $user_id user id.
		 * @return void
		 */
		public function mwb_wpr_render_subs_message( $user_id ) {
			if ( is_plugin_active( 'subscriptions-for-woocommerce/subscriptions-for-woocommerce.php' ) ) {

				// subscription compatible settings.
				$mwb_wpr_settings_gallery     = get_option( 'mwb_wpr_settings_gallery', array() );
				$mwb_wpr_settings_gallery     = ! empty( $mwb_wpr_settings_gallery ) && is_array( $mwb_wpr_settings_gallery ) ? $mwb_wpr_settings_gallery : array();
				$mwb_wpr_enable_subs_settings = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_enable_subs_settings'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_enable_subs_settings'] : 'off';
				$mwb_wpr_subs_renewal_points  = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_subs_renewal_points'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_subs_renewal_points'] : '1';
				$mwb_wpr_show_renewal_notice  = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_show_renewal_notice'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_show_renewal_notice'] : 'off';
				$mwb_wpr_renewal_notice       = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_renewal_notice'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_renewal_notice'] : '';

				if ( ! empty( $mwb_wpr_renewal_notice ) ) {

					$mwb_wpr_renewal_notice = str_replace( '[Points]', $mwb_wpr_subs_renewal_points, $mwb_wpr_renewal_notice );
				}

				if ( 'on' === $mwb_wpr_enable_subs_settings ) {
					if ( 'on' === $mwb_wpr_show_renewal_notice ) {
						?>
						<p class="mwb_wpr_heading"><?php echo esc_html_e( 'Subscription Renewal Message :', 'woocommerce-ultimate-points-and-rewards' ); ?></p>
						<div class="mwb_account_wrapper mwb_referral_link_shortcode">
							<fieldset class="mwb_wpr_each_section">
								<div class="mwb_wpr_refrral_code_copy">
									<div id="mwb_wpr_wallet_redeem_buttons"><?php echo esc_html( $mwb_wpr_renewal_notice ); ?></div>
								</div>
							</fieldset>
						</div>
						<?php
					}
				}
			}
		}

		/**
		 * This function is used to transfer points to wallet.
		 *
		 * @return void
		 */
		public function mwb_wpr_tranfer_points_to_wallet() {

			check_ajax_referer( 'mwb-wpr-verify-nonce', 'nonce' );
			$response            = array();
			$mwb_transfer_points = ! empty( $_POST['mwb_transfer_points'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_transfer_points'] ) ) : '0';
			$user_id             = ! empty( $_POST['user_id'] ) ? sanitize_text_field( wp_unslash( $_POST['user_id'] ) ) : '';
			$response['result']  = false;
			$response['message'] = esc_html__( 'Not transferred !!', 'woocommerce-ultimate-points-and-rewards' );

			// check if entered value empty.
			if ( ! empty( $mwb_transfer_points ) && $mwb_transfer_points > 0 ) {

				$wps_points = get_user_meta( $user_id, 'mwb_wpr_points', true );
				$wps_points = ! empty( $wps_points ) && $wps_points > 0 ? $wps_points : 0;

				// check user existing points is greater than entered points.
				if ( $wps_points > 0 && $wps_points >= $mwb_transfer_points ) {

					// wallet compatible settings.
					$mwb_wpr_settings_gallery         = get_option( 'mwb_wpr_settings_gallery', array() );
					$mwb_wpr_wallet_conversion_points = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_wallet_conversion_points'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_wallet_conversion_points'] : '1';
					$mwb_wpr_wallet_conversion_price  = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_wallet_conversion_price'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_wallet_conversion_price'] : '1';
					$wps_wpr_wallet_roundoff          = ceil( ( $mwb_transfer_points / $mwb_wpr_wallet_conversion_points ) * $mwb_wpr_wallet_conversion_price );

					// check calculated amount is greater than zero.
					if ( $wps_wpr_wallet_roundoff > 0 ) {

						$points_log     = get_user_meta( $user_id, 'points_details', true );
						$points_log     = ! empty( $points_log ) && is_array( $points_log ) ? $points_log : array();
						$wps_wallet     = get_user_meta( $user_id, 'wps_wallet', true );
						$wps_wallet     = ! empty( $wps_wallet ) && $wps_wallet > 0 ? $wps_wallet : 0;
						$wps_new_wallet = (int) $wps_wallet + $wps_wpr_wallet_roundoff;
						$wps_new_points = (int) $wps_points - $mwb_transfer_points;

						// creating points logs.
						if ( isset( $points_log['points_transfer_to_wallet'] ) && ! empty( $points_log['points_transfer_to_wallet'] ) ) {

							$points_log_arr = array();
							$points_log_arr = array(
								'points_transfer_to_wallet' => $mwb_transfer_points,
								'date'                      => gmdate( 'Y-m-d' ),
							);
							$points_log['points_transfer_to_wallet'][] = $points_log_arr;
						} else {

							if ( ! is_array( $points_log ) ) {
								$points_log = array();
							}

							$points_log_arr = array();
							$points_log_arr = array(
								'points_transfer_to_wallet' => $mwb_transfer_points,
								'date'                      => gmdate( 'Y-m-d' ),
							);
							$points_log['points_transfer_to_wallet'][] = $points_log_arr;
						}

						// Generate wallet transaction history.
						$transaction_data = array(
							'user_id'          => $user_id,
							'amount'           => $wps_wpr_wallet_roundoff,
							'currency'         => get_woocommerce_currency(),
							'payment_method'   => 'manual',
							'transaction_type' => 'points conversion to amount',
							'order_id'         => '',
							'note'             => 'Through Points and rewards',
						);

						// check if class is exist then transfer points in to wallet.
						if ( class_exists( 'Wallet_System_For_Woocommerce' ) ) {

							$wps_par_wallet_payment_gateway = new Wallet_System_For_Woocommerce();
							update_user_meta( $user_id, 'wps_wallet', $wps_new_wallet );
							update_user_meta( $user_id, 'mwb_wpr_points', $wps_new_points );
							update_user_meta( $user_id, 'points_details', $points_log );
							$wps_par_wallet_payment_gateway->insert_transaction_data_in_table( $transaction_data );

							$response['result']  = true;
							$response['message'] = esc_html__( 'Successfully Transferred', 'woocommerce-ultimate-points-and-rewards' );
						} else {

							$response['result']  = false;
							$response['message'] = esc_html__( 'Wallet Plugin is not activated', 'woocommerce-ultimate-points-and-rewards' );
						}
					} else {

						$response['result']  = false;
						$response['message'] = esc_html__( 'Invalid Amounts', 'woocommerce-ultimate-points-and-rewards' );
					}
				} else {

					$response['result']  = false;
					$response['message'] = esc_html__( 'You have insufficient points', 'woocommerce-ultimate-points-and-rewards' );
				}
			}
			wp_send_json( $response );
			wp_die();
		}

		// WOOCS.
		/**
		 * This function is used to show converted price.
		 *
		 * @param string $amounts amount.
		 * @return string
		 */
		public function mwb_par_conversion_price_callback( $amounts ) {
			if ( class_exists( 'WOOCS' ) ) {

				global $WOOCS;
				$amount = $WOOCS->woocs_exchange_value( $amounts );
				return round( $amount );
			} else {

				return round( $amounts );
			}
		}

		/**
		 * This function is used to convert price in to base price.
		 *
		 * @param  string $price prices.
		 * @return string
		 */
		public function mwb_par_convert_diffrent_currency_base_price_callback( $price ) {
			if ( class_exists( 'WOOCS' ) ) {
				global $WOOCS;
				$amount = 0;

				if ( $WOOCS->is_multiple_allowed ) {
					$currrent = $WOOCS->current_currency;
					if ( $currrent != $WOOCS->default_currency ) {

						$currencies = $WOOCS->get_currencies();
						$rate       = $currencies[ $currrent ]['rate'];
						$amount     = $price / ( $rate );
						return round( $amount );
					} else {

						return round( $price );
					}
				}
			}
			return round( $price );
		}

		/**
		 * This function is used to convert in to base currency when currency are same.
		 *
		 * @param  string $order_total order_total.
		 * @param  string $order_id    order_id.
		 * @return string
		 */
		public function mwb_par_convert_same_currency_base_price_callback( $order_total, $order_id ) {
			if ( class_exists( 'WOOCS' ) ) {
				global $WOOCS;
				$wps_currency = get_post_meta( $order_id, '_order_currency', true );
				if ( $wps_currency == $WOOCS->default_currency ) {

					$currencies  = $WOOCS->get_currencies();
					$rate        = $currencies[ $wps_currency ]['rate'];
					$order_total = round( $order_total / ( $rate ) );
				}
			}
			return $order_total;
		}

		/**
		 * This function is to manage session points, when admin.
		 * remove points from user account and user want to place order.
		 *
		 * @return void
		 */
		public function mwb_wpr_manage_session_points() {

			if ( is_user_logged_in() ) {

				$exist_points = (int) get_user_meta( get_current_user_id(), 'mwb_wpr_points', true );
				if ( null !== WC() ) {

					if ( isset( WC()->session ) && WC()->session->has_session() ) {
						if ( ! empty( WC()->session->get( 'mwb_cart_points' ) ) ) {

							$applied_points = (int) WC()->session->get( 'mwb_cart_points' );
							if ( $exist_points <= 0 ) {

								WC()->session->__unset( 'mwb_cart_points' );
							} elseif ( $applied_points > $exist_points ) {

								WC()->session->set( 'mwb_cart_points', $exist_points );
							}
						}
					}
				}
			}
		}

		/**
		 * This function is used to enqueue cart block js.
		 *
		 * @return void
		 */
		public function mwb_wpr_enqueue_cart_block() {

			wp_register_style( 'wp-mwb-wpr-cart-checkout-css', MWB_WPR_URL . 'assets/css/public/woocommerce-ultimate-points-cart-checkout-block.css', array(), '2.7.1' );
			wp_enqueue_style( 'wp-mwb-wpr-cart-checkout-css' );
			wp_register_script( 'wp-mwb-wpr-cart-checkout-js', MWB_WPR_URL . 'assets/js/public/woocommerce-ultimate-points-cart-checkout-block.js', array(), '2.7.1', true );
			wp_enqueue_script( 'wp-mwb-wpr-cart-checkout-js' );
		}
	}

	/**
	 * Check whether the WPR (Parent Plugin) is enable or not
	 *
	 * @return boolean
	 */
	function is_mwb_wpr_enabled() {
		$enable           = false;
		$general_settings = get_option( 'mwb_wpr_settings_gallery', true );
		$enable_mwb_wpr   = isset( $general_settings['enable_mwb_wpr'] ) ? intval( $general_settings['enable_mwb_wpr'] ) : 0;
		if ( $enable_mwb_wpr ) {
			$enable = true;
		}
		return $enable;
	}

	/**
	 * Check whether the Signup feature is enable or not
	 *
	 * @name is_signup_enabled()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function is_signup_enabled() {
		$enable            = false;
		$general_settings  = get_option( 'mwb_wpr_settings_gallery', true );
		$enable_mwb_signup = isset( $general_settings['enable_mwb_signup'] ) ? intval( $general_settings['enable_mwb_signup'] ) : 0;
		if ( $enable_mwb_signup ) {
			$enable = true;
		}
		return $enable;
	}

	/**
	 * Get the Signup Value
	 *
	 * @name get_signup_value()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function get_signup_value() {
		$general_settings = get_option( 'mwb_wpr_settings_gallery', true );
		$mwb_signup_value = isset( $general_settings['mwb_signup_value'] ) ? intval( $general_settings['mwb_signup_value'] ) : 1;
		return $mwb_signup_value;
	}

	/**
	 * Check whether the Order Conversion Feature is enable or not
	 *
	 * @name is_order_conversion_enabled()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function is_order_conversion_enabled() {
		$enable                     = false;
		$coupon_settings_array      = get_option( 'mwb_wpr_coupons_gallery', array() );
		$is_order_conversion_enable = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_enable'] ) ? $coupon_settings_array['mwb_wpr_coupon_conversion_enable'] : 0;
		if ( $is_order_conversion_enable ) {
			$enable = true;
		}
		return $enable;
	}

	/**
	 * Return the conversion Rate for Per Currency Spent Feature
	 *
	 * @name order_conversion_rate()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function order_conversion_rate() {
		$coupon_settings_array        = get_option( 'mwb_wpr_coupons_gallery', array() );
		$order_conversion_rate_value  = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_price'] ) ? $coupon_settings_array['mwb_wpr_coupon_conversion_price'] : 1;
		$order_conversion_rate_points = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) ? $coupon_settings_array['mwb_wpr_coupon_conversion_points'] : 1;
		$order_conversion_rate        = array(
			'Value'  => $order_conversion_rate_value,
			'Points' => $order_conversion_rate_points,
		);
		return $order_conversion_rate;
	}

	/**
	 * Return the value having the currency sign
	 *
	 * @param string $value value.
	 * @return string
	 */
	function value_return_in_currency( $value ) {
		if ( empty( $value ) ) {
			$value = 0;
		}
		return wc_price( $value );
	}

	/**
	 * Check the Review Reward is enabled or not
	 *
	 * @name is_review_reward_enabled()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function is_review_reward_enabled() {
		$general_settings = get_option( 'mwb_wpr_settings_gallery', true );
		$enable           = false;
		if ( isset( $general_settings['enable_mwb_comment'] ) && 1 == $general_settings['enable_mwb_comment'] ) {
			$enable = true;
		}
		return $enable;
	}

	/**
	 * Return the Reward Point for Review
	 *
	 * @name reward_review()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function reward_review() {
		$general_settings      = get_option( 'mwb_wpr_settings_gallery', true );
		$mwb_wpr_comment_value = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;
		return $mwb_wpr_comment_value;
	}

	/**
	 * Check whether the Referral Feature is enabled or not
	 *
	 * @name is_referral_is_enabled()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function is_referral_is_enabled() {
		$general_settings = get_option( 'mwb_wpr_settings_gallery', true );
		$enable_mwb_refer = isset( $general_settings['enable_mwb_refer'] ) ? intval( $general_settings['enable_mwb_refer'] ) : 0;
		return $enable_mwb_refer;
	}

	/**
	 * Return the Referral Link of User
	 *
	 * @param int $user_id user_id.
	 * @return string
	 */
	function get_referral_link( $user_id ) {
		$referral_link = get_user_meta( $user_id, 'mwb_points_referral', true );
		return $referral_link;
	}

	/**
	 * Check whether the Product Purchase using Points feature is enabled or not
	 *
	 * @name is_purchase_product_using_points_enabled()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function is_purchase_product_using_points_enabled() {
		$enable                 = false;
		$general_settings       = get_option( 'mwb_wpr_settings_gallery', true );
		$enable_purchase_points = isset( $general_settings['enable_purchase_points'] ) ? intval( $general_settings['enable_purchase_points'] ) : 0;
		if ( $enable_purchase_points ) {
			$enable = true;
		}
		return $enable;
	}

	/**
	 * Returns the Conversion rate of  Product Purchase using Points
	 *
	 * @name purchase_product_using_pnt_rate()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function purchase_product_using_pnt_rate() {
		$general_settings                   = get_option( 'mwb_wpr_settings_gallery', true );
		$mwb_wpr_purchase_points            = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null != $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
		$mwb_wpr_product_purchase_price     = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null != $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
		$product_purchasing_conversion_rate = array(
			'Currency' => $mwb_wpr_product_purchase_price,
			'Points'   => $mwb_wpr_purchase_points,
		);
		return $product_purchasing_conversion_rate;
	}

	/**
	 * Returns the Conversion rate of any feature in proper format
	 *
	 * @param int    $points points.
	 * @param string $currency currency.
	 * @return string
	 */
	function return_conversion_rate( $points, $currency ) {
		$point    = ( isset( $points ) && null != $points ) ? $points : 1;
		$currency = ( isset( $currency ) && null != $currency ) ? $currency : 1;
		$currency = value_return_in_currency( $currency );
		return $currency . ' = ' . $point . __( ' Point', 'woocommerce-ultimate-points-and-rewards' );
	}

	/**
	 * Check whether the Apply Point on Cart is enabled or not
	 *
	 * @name is_apply_point_on_cart_enabled()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function is_apply_point_on_cart_enabled() {
		$enable                        = false;
		$mwb_wpr_custom_points_on_cart = get_option( 'mwb_wpr_custom_points_on_cart', 0 );
		if ( $mwb_wpr_custom_points_on_cart ) {
			$enable = true;
		}
		return $enable;
	}

	/**
	 * Returns the Conversion rate of Apply Point on Cart
	 *
	 * @name apply_point_on_cart_rate()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function apply_point_on_cart_rate() {
		$mwb_wpr_cart_points_rate = get_option( 'mwb_wpr_cart_points_rate', 1 );
		$mwb_wpr_cart_price_rate  = get_option( 'mwb_wpr_cart_price_rate', 1 );
		$point_on_cart_rate       = array(
			'Currency' => $mwb_wpr_cart_price_rate,
			'Points'   => $mwb_wpr_cart_points_rate,
		);
		return $point_on_cart_rate;
	}

	/**
	 * Check whether the Convert Points into Coupon is enabled or not
	 *
	 * @name is_convert_points_to_coupon_enabled()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function is_convert_points_to_coupon_enabled() {
		$enable                            = true;
		$mwb_wpr_disable_coupon_generation = get_option( 'mwb_wpr_disable_coupon_generation', 0 );
		if ( $mwb_wpr_disable_coupon_generation ) {
			$enable = false;
		}
		return $enable;
	}

	/**
	 * Returns the Conversion rate of Convert Points into Coupons
	 *
	 * @name convert_points_to_coupons_rate()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function convert_points_to_coupons_rate() {
		$coupon_settings                = get_option( 'mwb_wpr_coupons_gallery', array() );
		$coupon_redeem_price            = ( isset( $coupon_settings['coupon_redeem_price'] ) && null != $coupon_settings['coupon_redeem_price'] ) ? $coupon_settings['coupon_redeem_price'] : 1;
		$coupon_redeem_points           = ( isset( $coupon_settings['coupon_redeem_points'] ) && null != $coupon_settings['coupon_redeem_points'] ) ? intval( $coupon_settings['coupon_redeem_points'] ) : 1;
		$convert_points_to_coupons_rate = array(
			'Currency' => $coupon_redeem_price,
			'Points'   => $coupon_redeem_points,
		);
		return $convert_points_to_coupons_rate;
	}

	/**
	 * Check whether the Referral Purchase Point is enabled or not
	 *
	 * @name is_referral_purchase_enabled()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function is_referral_purchase_enabled() {
		$enable                       = false;
		$general_settings             = get_option( 'mwb_wpr_settings_gallery', true );
		$mwb_referral_purchase_enable = isset( $general_settings['mwb_referral_purchase_enable'] ) ? intval( $general_settings['mwb_referral_purchase_enable'] ) : 0;
		if ( $mwb_referral_purchase_enable ) {
			$enable = true;
		}
		return $enable;
	}

	/**
	 * Returns the referral purchase amount
	 *
	 * @name get_referral_purchase_reward()
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function get_referral_purchase_reward() {
		$general_settings            = get_option( 'mwb_wpr_settings_gallery', true );
		$mwb_referral_purchase_value = isset( $general_settings['mwb_referral_purchase_value'] ) ? intval( $general_settings['mwb_referral_purchase_value'] ) : 1;
		return $mwb_referral_purchase_value;
	}

	/**
	 * Check whether the Only Referral Purchase Point Feature is enable or not
	 *
	 * @return boolean
	 */
	function is_only_referral_purchase_enabled() {
		$enable                 = false;
		$general_settings       = get_option( 'mwb_wpr_settings_gallery', true );
		$only_referral_purchase = isset( $general_settings['mwb_wpr_general_refer_value_disable'] ) ? intval( $general_settings['mwb_wpr_general_refer_value_disable'] ) : 0;
		if ( $only_referral_purchase ) {
			$enable = true;
		}
		return $enable;
	}

	$GLOBALS['MWB_WPR_Front_End'] = new MWB_WPR_Front_End();
}
